pub struct canJoinReturn {
pub allowed: bool,
}Expand description
Container type for the return parameters of the canJoin(uint64,address) function.
Fields
allowed: boolTrait Implementations
Sourceimpl Clone for canJoinReturn
impl Clone for canJoinReturn
Sourcefn clone(&self) -> canJoinReturn
fn clone(&self) -> canJoinReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for canJoinReturn
impl Debug for canJoinReturn
Sourceimpl Default for canJoinReturn
impl Default for canJoinReturn
Sourcefn default() -> canJoinReturn
fn default() -> canJoinReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for canJoinReturn
impl<'de> Deserialize<'de> for canJoinReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<canJoinReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<canJoinReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for canJoinReturn
Sourceimpl Hash for canJoinReturn
impl Hash for canJoinReturn
Sourceimpl PartialEq for canJoinReturn
impl PartialEq for canJoinReturn
Sourcefn eq(&self, other: &canJoinReturn) -> bool
fn eq(&self, other: &canJoinReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for canJoinReturn
impl Serialize for canJoinReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for canJoinReturn