pub struct canLeaveCall {
pub serviceId: u64,
pub operator: Address,
}Expand description
Function with signature canLeave(uint64,address) and selector 0xe518de76.
function canLeave(uint64 serviceId, address operator) external view returns (bool allowed);Fields
serviceId: u64operator: AddressTrait Implementations
Sourceimpl Clone for canLeaveCall
impl Clone for canLeaveCall
Sourcefn clone(&self) -> canLeaveCall
fn clone(&self) -> canLeaveCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for canLeaveCall
impl Debug for canLeaveCall
Sourceimpl Default for canLeaveCall
impl Default for canLeaveCall
Sourcefn default() -> canLeaveCall
fn default() -> canLeaveCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for canLeaveCall
impl<'de> Deserialize<'de> for canLeaveCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<canLeaveCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<canLeaveCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for canLeaveCall
Sourceimpl Hash for canLeaveCall
impl Hash for canLeaveCall
Sourceimpl PartialEq for canLeaveCall
impl PartialEq for canLeaveCall
Sourcefn eq(&self, other: &canLeaveCall) -> bool
fn eq(&self, other: &canLeaveCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for canLeaveCall
impl Serialize for canLeaveCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for canLeaveCall
impl SolCall for canLeaveCall
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<canLeaveCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<canLeaveCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<canLeaveCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<canLeaveCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<canLeaveCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> canLeaveCall
fn new<'a>( tuple: <<canLeaveCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> canLeaveCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<canLeaveCall as SolCall>::Return,
) -> <canLeaveCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<canLeaveCall as SolCall>::Return, ) -> <canLeaveCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<canLeaveCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<canLeaveCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<canLeaveCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<canLeaveCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for canLeaveCall