pub struct canLeaveReturn {
pub allowed: bool,
}Expand description
Container type for the return parameters of the canLeave(uint64,address) function.
Fields
allowed: boolTrait Implementations
Sourceimpl Clone for canLeaveReturn
impl Clone for canLeaveReturn
Sourcefn clone(&self) -> canLeaveReturn
fn clone(&self) -> canLeaveReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for canLeaveReturn
impl Debug for canLeaveReturn
Sourceimpl Default for canLeaveReturn
impl Default for canLeaveReturn
Sourcefn default() -> canLeaveReturn
fn default() -> canLeaveReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for canLeaveReturn
impl<'de> Deserialize<'de> for canLeaveReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<canLeaveReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<canLeaveReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for canLeaveReturn
Sourceimpl Hash for canLeaveReturn
impl Hash for canLeaveReturn
Sourceimpl PartialEq for canLeaveReturn
impl PartialEq for canLeaveReturn
Sourcefn eq(&self, other: &canLeaveReturn) -> bool
fn eq(&self, other: &canLeaveReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for canLeaveReturn
impl Serialize for canLeaveReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for canLeaveReturn