pub struct forceRemoveAllowsBelowMinCall {
pub serviceId: u64,
}Expand description
Function with signature forceRemoveAllowsBelowMin(uint64) and selector 0xf3e28f32.
function forceRemoveAllowsBelowMin(uint64 serviceId) external view returns (bool ok);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for forceRemoveAllowsBelowMinCall
impl Clone for forceRemoveAllowsBelowMinCall
Sourcefn clone(&self) -> forceRemoveAllowsBelowMinCall
fn clone(&self) -> forceRemoveAllowsBelowMinCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for forceRemoveAllowsBelowMinCall
impl Default for forceRemoveAllowsBelowMinCall
Sourcefn default() -> forceRemoveAllowsBelowMinCall
fn default() -> forceRemoveAllowsBelowMinCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for forceRemoveAllowsBelowMinCall
impl<'de> Deserialize<'de> for forceRemoveAllowsBelowMinCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<forceRemoveAllowsBelowMinCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<forceRemoveAllowsBelowMinCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for forceRemoveAllowsBelowMinCall
Sourceimpl Hash for forceRemoveAllowsBelowMinCall
impl Hash for forceRemoveAllowsBelowMinCall
Sourceimpl PartialEq for forceRemoveAllowsBelowMinCall
impl PartialEq for forceRemoveAllowsBelowMinCall
Sourcefn eq(&self, other: &forceRemoveAllowsBelowMinCall) -> bool
fn eq(&self, other: &forceRemoveAllowsBelowMinCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for forceRemoveAllowsBelowMinCall
impl Serialize for forceRemoveAllowsBelowMinCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for forceRemoveAllowsBelowMinCall
impl SolCall for forceRemoveAllowsBelowMinCall
Sourceconst SIGNATURE: &'static str = "forceRemoveAllowsBelowMin(uint64)"
const SIGNATURE: &'static str = "forceRemoveAllowsBelowMin(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<forceRemoveAllowsBelowMinCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<forceRemoveAllowsBelowMinCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<forceRemoveAllowsBelowMinCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<forceRemoveAllowsBelowMinCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<forceRemoveAllowsBelowMinCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> forceRemoveAllowsBelowMinCall
fn new<'a>( tuple: <<forceRemoveAllowsBelowMinCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> forceRemoveAllowsBelowMinCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <forceRemoveAllowsBelowMinCall as SolCall>::Token<'_>
fn tokenize(&self) -> <forceRemoveAllowsBelowMinCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<forceRemoveAllowsBelowMinCall as SolCall>::Return,
) -> <forceRemoveAllowsBelowMinCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<forceRemoveAllowsBelowMinCall as SolCall>::Return, ) -> <forceRemoveAllowsBelowMinCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<forceRemoveAllowsBelowMinCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<forceRemoveAllowsBelowMinCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<forceRemoveAllowsBelowMinCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<forceRemoveAllowsBelowMinCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for forceRemoveAllowsBelowMinCall