pub struct forceRemoveAllowsBelowMinReturn {
pub ok: bool,
}Expand description
Container type for the return parameters of the forceRemoveAllowsBelowMin(uint64) function.
Fields
ok: boolTrait Implementations
Sourceimpl Clone for forceRemoveAllowsBelowMinReturn
impl Clone for forceRemoveAllowsBelowMinReturn
Sourcefn clone(&self) -> forceRemoveAllowsBelowMinReturn
fn clone(&self) -> forceRemoveAllowsBelowMinReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for forceRemoveAllowsBelowMinReturn
impl Default for forceRemoveAllowsBelowMinReturn
Sourcefn default() -> forceRemoveAllowsBelowMinReturn
fn default() -> forceRemoveAllowsBelowMinReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for forceRemoveAllowsBelowMinReturn
impl<'de> Deserialize<'de> for forceRemoveAllowsBelowMinReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<forceRemoveAllowsBelowMinReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<forceRemoveAllowsBelowMinReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for forceRemoveAllowsBelowMinReturn
Sourceimpl PartialEq for forceRemoveAllowsBelowMinReturn
impl PartialEq for forceRemoveAllowsBelowMinReturn
Sourcefn eq(&self, other: &forceRemoveAllowsBelowMinReturn) -> bool
fn eq(&self, other: &forceRemoveAllowsBelowMinReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for forceRemoveAllowsBelowMinReturn
impl Serialize for forceRemoveAllowsBelowMinReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for forceRemoveAllowsBelowMinReturn