pub struct getHeartbeatIntervalCall {
pub serviceId: u64,
}Expand description
Function with signature getHeartbeatInterval(uint64) and selector 0x0068080b.
function getHeartbeatInterval(uint64 serviceId) external view returns (bool useDefault, uint64 interval);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for getHeartbeatIntervalCall
impl Clone for getHeartbeatIntervalCall
Sourcefn clone(&self) -> getHeartbeatIntervalCall
fn clone(&self) -> getHeartbeatIntervalCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getHeartbeatIntervalCall
impl Debug for getHeartbeatIntervalCall
Sourceimpl Default for getHeartbeatIntervalCall
impl Default for getHeartbeatIntervalCall
Sourcefn default() -> getHeartbeatIntervalCall
fn default() -> getHeartbeatIntervalCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getHeartbeatIntervalCall
impl<'de> Deserialize<'de> for getHeartbeatIntervalCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatIntervalCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatIntervalCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getHeartbeatIntervalCall
Sourceimpl Hash for getHeartbeatIntervalCall
impl Hash for getHeartbeatIntervalCall
Sourceimpl PartialEq for getHeartbeatIntervalCall
impl PartialEq for getHeartbeatIntervalCall
Sourcefn eq(&self, other: &getHeartbeatIntervalCall) -> bool
fn eq(&self, other: &getHeartbeatIntervalCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getHeartbeatIntervalCall
impl Serialize for getHeartbeatIntervalCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getHeartbeatIntervalCall
impl SolCall for getHeartbeatIntervalCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getHeartbeatIntervalCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getHeartbeatIntervalCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = getHeartbeatIntervalReturn
type Return = getHeartbeatIntervalReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Bool, Uint<64>)
type ReturnTuple<'a> = (Bool, Uint<64>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getHeartbeatIntervalCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getHeartbeatIntervalCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getHeartbeatIntervalCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getHeartbeatIntervalCall
fn new<'a>( tuple: <<getHeartbeatIntervalCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getHeartbeatIntervalCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getHeartbeatIntervalCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getHeartbeatIntervalCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getHeartbeatIntervalCall as SolCall>::Return,
) -> <getHeartbeatIntervalCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getHeartbeatIntervalCall as SolCall>::Return, ) -> <getHeartbeatIntervalCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getHeartbeatIntervalCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getHeartbeatIntervalCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getHeartbeatIntervalCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getHeartbeatIntervalCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for getHeartbeatIntervalCall