pub struct getHeartbeatIntervalReturn {
pub useDefault: bool,
pub interval: u64,
}Expand description
Container type for the return parameters of the getHeartbeatInterval(uint64) function.
Fields
useDefault: boolinterval: u64Trait Implementations
Sourceimpl Clone for getHeartbeatIntervalReturn
impl Clone for getHeartbeatIntervalReturn
Sourcefn clone(&self) -> getHeartbeatIntervalReturn
fn clone(&self) -> getHeartbeatIntervalReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getHeartbeatIntervalReturn
impl Debug for getHeartbeatIntervalReturn
Sourceimpl Default for getHeartbeatIntervalReturn
impl Default for getHeartbeatIntervalReturn
Sourcefn default() -> getHeartbeatIntervalReturn
fn default() -> getHeartbeatIntervalReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getHeartbeatIntervalReturn
impl<'de> Deserialize<'de> for getHeartbeatIntervalReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatIntervalReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatIntervalReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getHeartbeatIntervalReturn
Sourceimpl Hash for getHeartbeatIntervalReturn
impl Hash for getHeartbeatIntervalReturn
Sourceimpl PartialEq for getHeartbeatIntervalReturn
impl PartialEq for getHeartbeatIntervalReturn
Sourcefn eq(&self, other: &getHeartbeatIntervalReturn) -> bool
fn eq(&self, other: &getHeartbeatIntervalReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getHeartbeatIntervalReturn
impl Serialize for getHeartbeatIntervalReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getHeartbeatIntervalReturn