pub struct getHeartbeatThresholdCall {
pub serviceId: u64,
}Expand description
Function with signature getHeartbeatThreshold(uint64) and selector 0x92cbb78e.
function getHeartbeatThreshold(uint64 serviceId) external view returns (bool useDefault, uint8 threshold);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for getHeartbeatThresholdCall
impl Clone for getHeartbeatThresholdCall
Sourcefn clone(&self) -> getHeartbeatThresholdCall
fn clone(&self) -> getHeartbeatThresholdCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getHeartbeatThresholdCall
impl Debug for getHeartbeatThresholdCall
Sourceimpl Default for getHeartbeatThresholdCall
impl Default for getHeartbeatThresholdCall
Sourcefn default() -> getHeartbeatThresholdCall
fn default() -> getHeartbeatThresholdCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getHeartbeatThresholdCall
impl<'de> Deserialize<'de> for getHeartbeatThresholdCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatThresholdCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatThresholdCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getHeartbeatThresholdCall
Sourceimpl Hash for getHeartbeatThresholdCall
impl Hash for getHeartbeatThresholdCall
Sourceimpl PartialEq for getHeartbeatThresholdCall
impl PartialEq for getHeartbeatThresholdCall
Sourcefn eq(&self, other: &getHeartbeatThresholdCall) -> bool
fn eq(&self, other: &getHeartbeatThresholdCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getHeartbeatThresholdCall
impl Serialize for getHeartbeatThresholdCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getHeartbeatThresholdCall
impl SolCall for getHeartbeatThresholdCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getHeartbeatThresholdCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getHeartbeatThresholdCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = getHeartbeatThresholdReturn
type Return = getHeartbeatThresholdReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Bool, Uint<8>)
type ReturnTuple<'a> = (Bool, Uint<8>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getHeartbeatThresholdCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getHeartbeatThresholdCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getHeartbeatThresholdCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getHeartbeatThresholdCall
fn new<'a>( tuple: <<getHeartbeatThresholdCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getHeartbeatThresholdCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getHeartbeatThresholdCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getHeartbeatThresholdCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getHeartbeatThresholdCall as SolCall>::Return,
) -> <getHeartbeatThresholdCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getHeartbeatThresholdCall as SolCall>::Return, ) -> <getHeartbeatThresholdCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getHeartbeatThresholdCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getHeartbeatThresholdCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getHeartbeatThresholdCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getHeartbeatThresholdCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for getHeartbeatThresholdCall