pub struct getHeartbeatThresholdReturn {
pub useDefault: bool,
pub threshold: u8,
}Expand description
Container type for the return parameters of the getHeartbeatThreshold(uint64) function.
Fields
useDefault: boolthreshold: u8Trait Implementations
Sourceimpl Clone for getHeartbeatThresholdReturn
impl Clone for getHeartbeatThresholdReturn
Sourcefn clone(&self) -> getHeartbeatThresholdReturn
fn clone(&self) -> getHeartbeatThresholdReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getHeartbeatThresholdReturn
impl Debug for getHeartbeatThresholdReturn
Sourceimpl Default for getHeartbeatThresholdReturn
impl Default for getHeartbeatThresholdReturn
Sourcefn default() -> getHeartbeatThresholdReturn
fn default() -> getHeartbeatThresholdReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getHeartbeatThresholdReturn
impl<'de> Deserialize<'de> for getHeartbeatThresholdReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatThresholdReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatThresholdReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getHeartbeatThresholdReturn
Sourceimpl Hash for getHeartbeatThresholdReturn
impl Hash for getHeartbeatThresholdReturn
Sourceimpl PartialEq for getHeartbeatThresholdReturn
impl PartialEq for getHeartbeatThresholdReturn
Sourcefn eq(&self, other: &getHeartbeatThresholdReturn) -> bool
fn eq(&self, other: &getHeartbeatThresholdReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getHeartbeatThresholdReturn
impl Serialize for getHeartbeatThresholdReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getHeartbeatThresholdReturn