pub struct getMinOperatorStakeReturn {
pub useDefault: bool,
pub minStake: Uint<256, 4>,
}Expand description
Container type for the return parameters of the getMinOperatorStake() function.
Fields
useDefault: boolminStake: Uint<256, 4>Trait Implementations
Sourceimpl Clone for getMinOperatorStakeReturn
impl Clone for getMinOperatorStakeReturn
Sourcefn clone(&self) -> getMinOperatorStakeReturn
fn clone(&self) -> getMinOperatorStakeReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getMinOperatorStakeReturn
impl Debug for getMinOperatorStakeReturn
Sourceimpl Default for getMinOperatorStakeReturn
impl Default for getMinOperatorStakeReturn
Sourcefn default() -> getMinOperatorStakeReturn
fn default() -> getMinOperatorStakeReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getMinOperatorStakeReturn
impl<'de> Deserialize<'de> for getMinOperatorStakeReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getMinOperatorStakeReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getMinOperatorStakeReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getMinOperatorStakeReturn
Sourceimpl Hash for getMinOperatorStakeReturn
impl Hash for getMinOperatorStakeReturn
Sourceimpl PartialEq for getMinOperatorStakeReturn
impl PartialEq for getMinOperatorStakeReturn
Sourcefn eq(&self, other: &getMinOperatorStakeReturn) -> bool
fn eq(&self, other: &getMinOperatorStakeReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getMinOperatorStakeReturn
impl Serialize for getMinOperatorStakeReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getMinOperatorStakeReturn