pub struct getRequiredResultCountReturn {
pub required: u32,
}Expand description
Container type for the return parameters of the getRequiredResultCount(uint64,uint8) function.
Fields
required: u32Trait Implementations
Sourceimpl Clone for getRequiredResultCountReturn
impl Clone for getRequiredResultCountReturn
Sourcefn clone(&self) -> getRequiredResultCountReturn
fn clone(&self) -> getRequiredResultCountReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getRequiredResultCountReturn
impl Debug for getRequiredResultCountReturn
Sourceimpl Default for getRequiredResultCountReturn
impl Default for getRequiredResultCountReturn
Sourcefn default() -> getRequiredResultCountReturn
fn default() -> getRequiredResultCountReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getRequiredResultCountReturn
impl<'de> Deserialize<'de> for getRequiredResultCountReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getRequiredResultCountReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getRequiredResultCountReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getRequiredResultCountReturn
Sourceimpl Hash for getRequiredResultCountReturn
impl Hash for getRequiredResultCountReturn
Sourceimpl PartialEq for getRequiredResultCountReturn
impl PartialEq for getRequiredResultCountReturn
Sourcefn eq(&self, other: &getRequiredResultCountReturn) -> bool
fn eq(&self, other: &getRequiredResultCountReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getRequiredResultCountReturn
impl Serialize for getRequiredResultCountReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getRequiredResultCountReturn