pub struct getSlashingWindowCall {
pub serviceId: u64,
}Expand description
Function with signature getSlashingWindow(uint64) and selector 0x3fdadfcc.
function getSlashingWindow(uint64 serviceId) external view returns (bool useDefault, uint64 window);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for getSlashingWindowCall
impl Clone for getSlashingWindowCall
Sourcefn clone(&self) -> getSlashingWindowCall
fn clone(&self) -> getSlashingWindowCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getSlashingWindowCall
impl Debug for getSlashingWindowCall
Sourceimpl Default for getSlashingWindowCall
impl Default for getSlashingWindowCall
Sourcefn default() -> getSlashingWindowCall
fn default() -> getSlashingWindowCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getSlashingWindowCall
impl<'de> Deserialize<'de> for getSlashingWindowCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashingWindowCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashingWindowCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getSlashingWindowCall
Sourceimpl Hash for getSlashingWindowCall
impl Hash for getSlashingWindowCall
Sourceimpl PartialEq for getSlashingWindowCall
impl PartialEq for getSlashingWindowCall
Sourcefn eq(&self, other: &getSlashingWindowCall) -> bool
fn eq(&self, other: &getSlashingWindowCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getSlashingWindowCall
impl Serialize for getSlashingWindowCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getSlashingWindowCall
impl SolCall for getSlashingWindowCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getSlashingWindowCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getSlashingWindowCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = getSlashingWindowReturn
type Return = getSlashingWindowReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Bool, Uint<64>)
type ReturnTuple<'a> = (Bool, Uint<64>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getSlashingWindowCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getSlashingWindowCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getSlashingWindowCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getSlashingWindowCall
fn new<'a>( tuple: <<getSlashingWindowCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getSlashingWindowCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getSlashingWindowCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getSlashingWindowCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getSlashingWindowCall as SolCall>::Return,
) -> <getSlashingWindowCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getSlashingWindowCall as SolCall>::Return, ) -> <getSlashingWindowCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getSlashingWindowCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getSlashingWindowCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getSlashingWindowCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getSlashingWindowCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for getSlashingWindowCall