pub struct getSlashingWindowReturn {
pub useDefault: bool,
pub window: u64,
}Expand description
Container type for the return parameters of the getSlashingWindow(uint64) function.
Fields
useDefault: boolwindow: u64Trait Implementations
Sourceimpl Clone for getSlashingWindowReturn
impl Clone for getSlashingWindowReturn
Sourcefn clone(&self) -> getSlashingWindowReturn
fn clone(&self) -> getSlashingWindowReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getSlashingWindowReturn
impl Debug for getSlashingWindowReturn
Sourceimpl Default for getSlashingWindowReturn
impl Default for getSlashingWindowReturn
Sourcefn default() -> getSlashingWindowReturn
fn default() -> getSlashingWindowReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getSlashingWindowReturn
impl<'de> Deserialize<'de> for getSlashingWindowReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashingWindowReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashingWindowReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getSlashingWindowReturn
Sourceimpl Hash for getSlashingWindowReturn
impl Hash for getSlashingWindowReturn
Sourceimpl PartialEq for getSlashingWindowReturn
impl PartialEq for getSlashingWindowReturn
Sourcefn eq(&self, other: &getSlashingWindowReturn) -> bool
fn eq(&self, other: &getSlashingWindowReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getSlashingWindowReturn
impl Serialize for getSlashingWindowReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getSlashingWindowReturn