pub struct onApproveCall {
pub operator: Address,
pub requestId: u64,
pub stakingPercent: u8,
}Expand description
Function with signature onApprove(address,uint64,uint8) and selector 0xb159eb34.
function onApprove(address operator, uint64 requestId, uint8 stakingPercent) external payable;Fields
operator: AddressrequestId: u64stakingPercent: u8Trait Implementations
Sourceimpl Clone for onApproveCall
impl Clone for onApproveCall
Sourcefn clone(&self) -> onApproveCall
fn clone(&self) -> onApproveCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onApproveCall
impl Debug for onApproveCall
Sourceimpl Default for onApproveCall
impl Default for onApproveCall
Sourcefn default() -> onApproveCall
fn default() -> onApproveCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onApproveCall
impl<'de> Deserialize<'de> for onApproveCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onApproveCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onApproveCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onApproveCall
Sourceimpl Hash for onApproveCall
impl Hash for onApproveCall
Sourceimpl PartialEq for onApproveCall
impl PartialEq for onApproveCall
Sourcefn eq(&self, other: &onApproveCall) -> bool
fn eq(&self, other: &onApproveCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onApproveCall
impl Serialize for onApproveCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onApproveCall
impl SolCall for onApproveCall
Sourceconst SIGNATURE: &'static str = "onApprove(address,uint64,uint8)"
const SIGNATURE: &'static str = "onApprove(address,uint64,uint8)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<64>, Uint<8>)
type Parameters<'a> = (Address, Uint<64>, Uint<8>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onApproveCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onApproveCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onApproveReturn
type Return = onApproveReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onApproveCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onApproveCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onApproveCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onApproveCall
fn new<'a>( tuple: <<onApproveCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onApproveCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<onApproveCall as SolCall>::Return,
) -> <onApproveCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onApproveCall as SolCall>::Return, ) -> <onApproveCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onApproveCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onApproveCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onApproveCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onApproveCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onApproveCall