pub struct onJobResultCall {
pub serviceId: u64,
pub job: u8,
pub jobCallId: u64,
pub operator: Address,
pub inputs: Bytes,
pub outputs: Bytes,
}Expand description
Function with signature onJobResult(uint64,uint8,uint64,address,bytes,bytes) and selector 0xc40c80d1.
function onJobResult(uint64 serviceId, uint8 job, uint64 jobCallId, address operator, bytes memory inputs, bytes memory outputs) external payable;Fields
serviceId: u64job: u8jobCallId: u64operator: Addressinputs: Bytesoutputs: BytesTrait Implementations
Sourceimpl Clone for onJobResultCall
impl Clone for onJobResultCall
Sourcefn clone(&self) -> onJobResultCall
fn clone(&self) -> onJobResultCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onJobResultCall
impl Debug for onJobResultCall
Sourceimpl Default for onJobResultCall
impl Default for onJobResultCall
Sourcefn default() -> onJobResultCall
fn default() -> onJobResultCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onJobResultCall
impl<'de> Deserialize<'de> for onJobResultCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onJobResultCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onJobResultCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onJobResultCall
Sourceimpl Hash for onJobResultCall
impl Hash for onJobResultCall
Sourceimpl PartialEq for onJobResultCall
impl PartialEq for onJobResultCall
Sourcefn eq(&self, other: &onJobResultCall) -> bool
fn eq(&self, other: &onJobResultCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onJobResultCall
impl Serialize for onJobResultCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onJobResultCall
impl SolCall for onJobResultCall
Sourceconst SIGNATURE: &'static str = "onJobResult(uint64,uint8,uint64,address,bytes,bytes)"
const SIGNATURE: &'static str = "onJobResult(uint64,uint8,uint64,address,bytes,bytes)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<8>, Uint<64>, Address, Bytes, Bytes)
type Parameters<'a> = (Uint<64>, Uint<8>, Uint<64>, Address, Bytes, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onJobResultCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onJobResultCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onJobResultReturn
type Return = onJobResultReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onJobResultCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onJobResultCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onJobResultCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onJobResultCall
fn new<'a>( tuple: <<onJobResultCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onJobResultCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<onJobResultCall as SolCall>::Return,
) -> <onJobResultCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onJobResultCall as SolCall>::Return, ) -> <onJobResultCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onJobResultCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onJobResultCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onJobResultCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onJobResultCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onJobResultCall