pub struct onRegisterCall {
pub operator: Address,
pub registrationInputs: Bytes,
}Expand description
Function with signature onRegister(address,bytes) and selector 0x67793cc6.
function onRegister(address operator, bytes memory registrationInputs) external payable;Fields
operator: AddressregistrationInputs: BytesTrait Implementations
Sourceimpl Clone for onRegisterCall
impl Clone for onRegisterCall
Sourcefn clone(&self) -> onRegisterCall
fn clone(&self) -> onRegisterCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onRegisterCall
impl Debug for onRegisterCall
Sourceimpl Default for onRegisterCall
impl Default for onRegisterCall
Sourcefn default() -> onRegisterCall
fn default() -> onRegisterCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onRegisterCall
impl<'de> Deserialize<'de> for onRegisterCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onRegisterCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onRegisterCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onRegisterCall
Sourceimpl Hash for onRegisterCall
impl Hash for onRegisterCall
Sourceimpl PartialEq for onRegisterCall
impl PartialEq for onRegisterCall
Sourcefn eq(&self, other: &onRegisterCall) -> bool
fn eq(&self, other: &onRegisterCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onRegisterCall
impl Serialize for onRegisterCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onRegisterCall
impl SolCall for onRegisterCall
Sourcetype Parameters<'a> = (Address, Bytes)
type Parameters<'a> = (Address, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onRegisterCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onRegisterCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onRegisterReturn
type Return = onRegisterReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onRegisterCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onRegisterCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onRegisterCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onRegisterCall
fn new<'a>( tuple: <<onRegisterCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onRegisterCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<onRegisterCall as SolCall>::Return,
) -> <onRegisterCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onRegisterCall as SolCall>::Return, ) -> <onRegisterCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onRegisterCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onRegisterCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onRegisterCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onRegisterCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onRegisterCall