pub struct onRejectCall {
pub operator: Address,
pub requestId: u64,
}Expand description
Function with signature onReject(address,uint64) and selector 0xc9cd4a18.
function onReject(address operator, uint64 requestId) external;Fields
operator: AddressrequestId: u64Trait Implementations
Sourceimpl Clone for onRejectCall
impl Clone for onRejectCall
Sourcefn clone(&self) -> onRejectCall
fn clone(&self) -> onRejectCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onRejectCall
impl Debug for onRejectCall
Sourceimpl Default for onRejectCall
impl Default for onRejectCall
Sourcefn default() -> onRejectCall
fn default() -> onRejectCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onRejectCall
impl<'de> Deserialize<'de> for onRejectCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onRejectCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onRejectCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onRejectCall
Sourceimpl Hash for onRejectCall
impl Hash for onRejectCall
Sourceimpl PartialEq for onRejectCall
impl PartialEq for onRejectCall
Sourcefn eq(&self, other: &onRejectCall) -> bool
fn eq(&self, other: &onRejectCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onRejectCall
impl Serialize for onRejectCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onRejectCall
impl SolCall for onRejectCall
Sourcetype Parameters<'a> = (Address, Uint<64>)
type Parameters<'a> = (Address, Uint<64>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onRejectCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onRejectCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onRejectReturn
type Return = onRejectReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onRejectCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onRejectCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onRejectCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onRejectCall
fn new<'a>( tuple: <<onRejectCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onRejectCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<onRejectCall as SolCall>::Return,
) -> <onRejectCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onRejectCall as SolCall>::Return, ) -> <onRejectCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onRejectCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onRejectCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onRejectCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onRejectCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onRejectCall