pub struct onServiceInitializedCall {
pub blueprintId: u64,
pub requestId: u64,
pub serviceId: u64,
pub owner: Address,
pub permittedCallers: Vec<Address>,
pub ttl: u64,
}Expand description
Function with signature onServiceInitialized(uint64,uint64,uint64,address,address[],uint64) and selector 0x82a1ece4.
function onServiceInitialized(uint64 blueprintId, uint64 requestId, uint64 serviceId, address owner, address[] memory permittedCallers, uint64 ttl) external;Fields
blueprintId: u64requestId: u64serviceId: u64owner: AddresspermittedCallers: Vec<Address>ttl: u64Trait Implementations
Sourceimpl Clone for onServiceInitializedCall
impl Clone for onServiceInitializedCall
Sourcefn clone(&self) -> onServiceInitializedCall
fn clone(&self) -> onServiceInitializedCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onServiceInitializedCall
impl Debug for onServiceInitializedCall
Sourceimpl Default for onServiceInitializedCall
impl Default for onServiceInitializedCall
Sourcefn default() -> onServiceInitializedCall
fn default() -> onServiceInitializedCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onServiceInitializedCall
impl<'de> Deserialize<'de> for onServiceInitializedCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onServiceInitializedCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onServiceInitializedCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onServiceInitializedCall
Sourceimpl Hash for onServiceInitializedCall
impl Hash for onServiceInitializedCall
Sourceimpl PartialEq for onServiceInitializedCall
impl PartialEq for onServiceInitializedCall
Sourcefn eq(&self, other: &onServiceInitializedCall) -> bool
fn eq(&self, other: &onServiceInitializedCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onServiceInitializedCall
impl Serialize for onServiceInitializedCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onServiceInitializedCall
impl SolCall for onServiceInitializedCall
Sourceconst SIGNATURE: &'static str = "onServiceInitialized(uint64,uint64,uint64,address,address[],uint64)"
const SIGNATURE: &'static str = "onServiceInitialized(uint64,uint64,uint64,address,address[],uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>, Uint<64>, Address, Array<Address>, Uint<64>)
type Parameters<'a> = (Uint<64>, Uint<64>, Uint<64>, Address, Array<Address>, Uint<64>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onServiceInitializedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onServiceInitializedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onServiceInitializedReturn
type Return = onServiceInitializedReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onServiceInitializedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onServiceInitializedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onServiceInitializedCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onServiceInitializedCall
fn new<'a>( tuple: <<onServiceInitializedCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onServiceInitializedCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <onServiceInitializedCall as SolCall>::Token<'_>
fn tokenize(&self) -> <onServiceInitializedCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<onServiceInitializedCall as SolCall>::Return,
) -> <onServiceInitializedCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onServiceInitializedCall as SolCall>::Return, ) -> <onServiceInitializedCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onServiceInitializedCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onServiceInitializedCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onServiceInitializedCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onServiceInitializedCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onServiceInitializedCall