pub struct onServiceTerminationCall {
pub serviceId: u64,
pub owner: Address,
}Expand description
Function with signature onServiceTermination(uint64,address) and selector 0xa24e8a90.
function onServiceTermination(uint64 serviceId, address owner) external;Fields
serviceId: u64owner: AddressTrait Implementations
Sourceimpl Clone for onServiceTerminationCall
impl Clone for onServiceTerminationCall
Sourcefn clone(&self) -> onServiceTerminationCall
fn clone(&self) -> onServiceTerminationCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onServiceTerminationCall
impl Debug for onServiceTerminationCall
Sourceimpl Default for onServiceTerminationCall
impl Default for onServiceTerminationCall
Sourcefn default() -> onServiceTerminationCall
fn default() -> onServiceTerminationCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onServiceTerminationCall
impl<'de> Deserialize<'de> for onServiceTerminationCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onServiceTerminationCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onServiceTerminationCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onServiceTerminationCall
Sourceimpl Hash for onServiceTerminationCall
impl Hash for onServiceTerminationCall
Sourceimpl PartialEq for onServiceTerminationCall
impl PartialEq for onServiceTerminationCall
Sourcefn eq(&self, other: &onServiceTerminationCall) -> bool
fn eq(&self, other: &onServiceTerminationCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onServiceTerminationCall
impl Serialize for onServiceTerminationCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onServiceTerminationCall
impl SolCall for onServiceTerminationCall
Sourceconst SIGNATURE: &'static str = "onServiceTermination(uint64,address)"
const SIGNATURE: &'static str = "onServiceTermination(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onServiceTerminationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onServiceTerminationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onServiceTerminationReturn
type Return = onServiceTerminationReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onServiceTerminationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onServiceTerminationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onServiceTerminationCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onServiceTerminationCall
fn new<'a>( tuple: <<onServiceTerminationCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onServiceTerminationCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <onServiceTerminationCall as SolCall>::Token<'_>
fn tokenize(&self) -> <onServiceTerminationCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<onServiceTerminationCall as SolCall>::Return,
) -> <onServiceTerminationCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onServiceTerminationCall as SolCall>::Return, ) -> <onServiceTerminationCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onServiceTerminationCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onServiceTerminationCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onServiceTerminationCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onServiceTerminationCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onServiceTerminationCall