pub struct onSlashCall {
pub serviceId: u64,
pub offender: Bytes,
pub slashPercent: u8,
}Expand description
Function with signature onSlash(uint64,bytes,uint8) and selector 0x7e14b919.
function onSlash(uint64 serviceId, bytes memory offender, uint8 slashPercent) external;Fields
serviceId: u64offender: BytesslashPercent: u8Trait Implementations
Sourceimpl Clone for onSlashCall
impl Clone for onSlashCall
Sourcefn clone(&self) -> onSlashCall
fn clone(&self) -> onSlashCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onSlashCall
impl Debug for onSlashCall
Sourceimpl Default for onSlashCall
impl Default for onSlashCall
Sourcefn default() -> onSlashCall
fn default() -> onSlashCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onSlashCall
impl<'de> Deserialize<'de> for onSlashCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onSlashCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onSlashCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onSlashCall
Sourceimpl Hash for onSlashCall
impl Hash for onSlashCall
Sourceimpl PartialEq for onSlashCall
impl PartialEq for onSlashCall
Sourcefn eq(&self, other: &onSlashCall) -> bool
fn eq(&self, other: &onSlashCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onSlashCall
impl Serialize for onSlashCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onSlashCall
impl SolCall for onSlashCall
Sourcetype Parameters<'a> = (Uint<64>, Bytes, Uint<8>)
type Parameters<'a> = (Uint<64>, Bytes, Uint<8>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onSlashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onSlashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onSlashReturn
type Return = onSlashReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onSlashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onSlashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onSlashCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onSlashCall
fn new<'a>( tuple: <<onSlashCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onSlashCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<onSlashCall as SolCall>::Return,
) -> <onSlashCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onSlashCall as SolCall>::Return, ) -> <onSlashCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onSlashCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onSlashCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onSlashCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onSlashCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onSlashCall