pub struct onUnregisterCall {
pub operator: Address,
}Expand description
Function with signature onUnregister(address) and selector 0x151a4576.
function onUnregister(address operator) external;Fields
operator: AddressTrait Implementations
Sourceimpl Clone for onUnregisterCall
impl Clone for onUnregisterCall
Sourcefn clone(&self) -> onUnregisterCall
fn clone(&self) -> onUnregisterCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onUnregisterCall
impl Debug for onUnregisterCall
Sourceimpl Default for onUnregisterCall
impl Default for onUnregisterCall
Sourcefn default() -> onUnregisterCall
fn default() -> onUnregisterCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onUnregisterCall
impl<'de> Deserialize<'de> for onUnregisterCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onUnregisterCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onUnregisterCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onUnregisterCall
Sourceimpl Hash for onUnregisterCall
impl Hash for onUnregisterCall
Sourceimpl PartialEq for onUnregisterCall
impl PartialEq for onUnregisterCall
Sourcefn eq(&self, other: &onUnregisterCall) -> bool
fn eq(&self, other: &onUnregisterCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onUnregisterCall
impl Serialize for onUnregisterCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onUnregisterCall
impl SolCall for onUnregisterCall
Sourcetype Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onUnregisterCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onUnregisterCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onUnregisterReturn
type Return = onUnregisterReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onUnregisterCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onUnregisterCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onUnregisterCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onUnregisterCall
fn new<'a>( tuple: <<onUnregisterCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onUnregisterCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<onUnregisterCall as SolCall>::Return,
) -> <onUnregisterCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onUnregisterCall as SolCall>::Return, ) -> <onUnregisterCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onUnregisterCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onUnregisterCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onUnregisterCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onUnregisterCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onUnregisterCall