pub struct queryDeveloperPaymentAddressCall {
pub serviceId: u64,
}Expand description
Function with signature queryDeveloperPaymentAddress(uint64) and selector 0x08179f35.
function queryDeveloperPaymentAddress(uint64 serviceId) external view returns (address developerPaymentAddress);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for queryDeveloperPaymentAddressCall
impl Clone for queryDeveloperPaymentAddressCall
Sourcefn clone(&self) -> queryDeveloperPaymentAddressCall
fn clone(&self) -> queryDeveloperPaymentAddressCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for queryDeveloperPaymentAddressCall
impl Default for queryDeveloperPaymentAddressCall
Sourcefn default() -> queryDeveloperPaymentAddressCall
fn default() -> queryDeveloperPaymentAddressCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for queryDeveloperPaymentAddressCall
impl<'de> Deserialize<'de> for queryDeveloperPaymentAddressCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<queryDeveloperPaymentAddressCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<queryDeveloperPaymentAddressCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for queryDeveloperPaymentAddressCall
Sourceimpl PartialEq for queryDeveloperPaymentAddressCall
impl PartialEq for queryDeveloperPaymentAddressCall
Sourcefn eq(&self, other: &queryDeveloperPaymentAddressCall) -> bool
fn eq(&self, other: &queryDeveloperPaymentAddressCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for queryDeveloperPaymentAddressCall
impl Serialize for queryDeveloperPaymentAddressCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for queryDeveloperPaymentAddressCall
impl SolCall for queryDeveloperPaymentAddressCall
Sourceconst SIGNATURE: &'static str = "queryDeveloperPaymentAddress(uint64)"
const SIGNATURE: &'static str = "queryDeveloperPaymentAddress(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<queryDeveloperPaymentAddressCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<queryDeveloperPaymentAddressCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Address,)
type ReturnTuple<'a> = (Address,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<queryDeveloperPaymentAddressCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<queryDeveloperPaymentAddressCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<queryDeveloperPaymentAddressCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> queryDeveloperPaymentAddressCall
fn new<'a>( tuple: <<queryDeveloperPaymentAddressCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> queryDeveloperPaymentAddressCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <queryDeveloperPaymentAddressCall as SolCall>::Token<'_>
fn tokenize(&self) -> <queryDeveloperPaymentAddressCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<queryDeveloperPaymentAddressCall as SolCall>::Return,
) -> <queryDeveloperPaymentAddressCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<queryDeveloperPaymentAddressCall as SolCall>::Return, ) -> <queryDeveloperPaymentAddressCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<queryDeveloperPaymentAddressCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<queryDeveloperPaymentAddressCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<queryDeveloperPaymentAddressCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<queryDeveloperPaymentAddressCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for queryDeveloperPaymentAddressCall