pub struct queryDeveloperPaymentAddressReturn {
pub developerPaymentAddress: Address,
}Expand description
Container type for the return parameters of the queryDeveloperPaymentAddress(uint64) function.
Fields
developerPaymentAddress: AddressTrait Implementations
Sourceimpl Clone for queryDeveloperPaymentAddressReturn
impl Clone for queryDeveloperPaymentAddressReturn
Sourcefn clone(&self) -> queryDeveloperPaymentAddressReturn
fn clone(&self) -> queryDeveloperPaymentAddressReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for queryDeveloperPaymentAddressReturn
impl Default for queryDeveloperPaymentAddressReturn
Sourcefn default() -> queryDeveloperPaymentAddressReturn
fn default() -> queryDeveloperPaymentAddressReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for queryDeveloperPaymentAddressReturn
impl<'de> Deserialize<'de> for queryDeveloperPaymentAddressReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<queryDeveloperPaymentAddressReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<queryDeveloperPaymentAddressReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for queryDeveloperPaymentAddressReturn
Sourceimpl PartialEq for queryDeveloperPaymentAddressReturn
impl PartialEq for queryDeveloperPaymentAddressReturn
Sourcefn eq(&self, other: &queryDeveloperPaymentAddressReturn) -> bool
fn eq(&self, other: &queryDeveloperPaymentAddressReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for queryDeveloperPaymentAddressReturn
impl Serialize for queryDeveloperPaymentAddressReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for queryDeveloperPaymentAddressReturn