pub struct queryDisputeOriginCall {
pub serviceId: u64,
}Expand description
Function with signature queryDisputeOrigin(uint64) and selector 0x14b4df4c.
function queryDisputeOrigin(uint64 serviceId) external view returns (address disputeOrigin);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for queryDisputeOriginCall
impl Clone for queryDisputeOriginCall
Sourcefn clone(&self) -> queryDisputeOriginCall
fn clone(&self) -> queryDisputeOriginCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for queryDisputeOriginCall
impl Debug for queryDisputeOriginCall
Sourceimpl Default for queryDisputeOriginCall
impl Default for queryDisputeOriginCall
Sourcefn default() -> queryDisputeOriginCall
fn default() -> queryDisputeOriginCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for queryDisputeOriginCall
impl<'de> Deserialize<'de> for queryDisputeOriginCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<queryDisputeOriginCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<queryDisputeOriginCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for queryDisputeOriginCall
Sourceimpl Hash for queryDisputeOriginCall
impl Hash for queryDisputeOriginCall
Sourceimpl PartialEq for queryDisputeOriginCall
impl PartialEq for queryDisputeOriginCall
Sourcefn eq(&self, other: &queryDisputeOriginCall) -> bool
fn eq(&self, other: &queryDisputeOriginCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for queryDisputeOriginCall
impl Serialize for queryDisputeOriginCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for queryDisputeOriginCall
impl SolCall for queryDisputeOriginCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<queryDisputeOriginCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<queryDisputeOriginCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Address,)
type ReturnTuple<'a> = (Address,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<queryDisputeOriginCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<queryDisputeOriginCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<queryDisputeOriginCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> queryDisputeOriginCall
fn new<'a>( tuple: <<queryDisputeOriginCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> queryDisputeOriginCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <queryDisputeOriginCall as SolCall>::Token<'_>
fn tokenize(&self) -> <queryDisputeOriginCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<queryDisputeOriginCall as SolCall>::Return,
) -> <queryDisputeOriginCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<queryDisputeOriginCall as SolCall>::Return, ) -> <queryDisputeOriginCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<queryDisputeOriginCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<queryDisputeOriginCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<queryDisputeOriginCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<queryDisputeOriginCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for queryDisputeOriginCall