pub struct querySlashingOriginReturn {
pub slashingOrigin: Address,
}Expand description
Container type for the return parameters of the querySlashingOrigin(uint64) function.
Fields
slashingOrigin: AddressTrait Implementations
Sourceimpl Clone for querySlashingOriginReturn
impl Clone for querySlashingOriginReturn
Sourcefn clone(&self) -> querySlashingOriginReturn
fn clone(&self) -> querySlashingOriginReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for querySlashingOriginReturn
impl Debug for querySlashingOriginReturn
Sourceimpl Default for querySlashingOriginReturn
impl Default for querySlashingOriginReturn
Sourcefn default() -> querySlashingOriginReturn
fn default() -> querySlashingOriginReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for querySlashingOriginReturn
impl<'de> Deserialize<'de> for querySlashingOriginReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<querySlashingOriginReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<querySlashingOriginReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for querySlashingOriginReturn
Sourceimpl Hash for querySlashingOriginReturn
impl Hash for querySlashingOriginReturn
Sourceimpl PartialEq for querySlashingOriginReturn
impl PartialEq for querySlashingOriginReturn
Sourcefn eq(&self, other: &querySlashingOriginReturn) -> bool
fn eq(&self, other: &querySlashingOriginReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for querySlashingOriginReturn
impl Serialize for querySlashingOriginReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for querySlashingOriginReturn