pub struct removeBlueprintForOperatorCall {
pub operator: Address,
pub blueprintId: u64,
}Expand description
Function with signature removeBlueprintForOperator(address,uint64) and selector 0xd106de35.
function removeBlueprintForOperator(address operator, uint64 blueprintId) external;Fields
operator: AddressblueprintId: u64Trait Implementations
Sourceimpl Clone for removeBlueprintForOperatorCall
impl Clone for removeBlueprintForOperatorCall
Sourcefn clone(&self) -> removeBlueprintForOperatorCall
fn clone(&self) -> removeBlueprintForOperatorCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for removeBlueprintForOperatorCall
impl Default for removeBlueprintForOperatorCall
Sourcefn default() -> removeBlueprintForOperatorCall
fn default() -> removeBlueprintForOperatorCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for removeBlueprintForOperatorCall
impl<'de> Deserialize<'de> for removeBlueprintForOperatorCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<removeBlueprintForOperatorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<removeBlueprintForOperatorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for removeBlueprintForOperatorCall
Sourceimpl PartialEq for removeBlueprintForOperatorCall
impl PartialEq for removeBlueprintForOperatorCall
Sourcefn eq(&self, other: &removeBlueprintForOperatorCall) -> bool
fn eq(&self, other: &removeBlueprintForOperatorCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for removeBlueprintForOperatorCall
impl Serialize for removeBlueprintForOperatorCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for removeBlueprintForOperatorCall
impl SolCall for removeBlueprintForOperatorCall
Sourceconst SIGNATURE: &'static str = "removeBlueprintForOperator(address,uint64)"
const SIGNATURE: &'static str = "removeBlueprintForOperator(address,uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<64>)
type Parameters<'a> = (Address, Uint<64>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<removeBlueprintForOperatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<removeBlueprintForOperatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = removeBlueprintForOperatorReturn
type Return = removeBlueprintForOperatorReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<removeBlueprintForOperatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<removeBlueprintForOperatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<removeBlueprintForOperatorCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> removeBlueprintForOperatorCall
fn new<'a>( tuple: <<removeBlueprintForOperatorCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> removeBlueprintForOperatorCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <removeBlueprintForOperatorCall as SolCall>::Token<'_>
fn tokenize(&self) -> <removeBlueprintForOperatorCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<removeBlueprintForOperatorCall as SolCall>::Return,
) -> <removeBlueprintForOperatorCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<removeBlueprintForOperatorCall as SolCall>::Return, ) -> <removeBlueprintForOperatorCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<removeBlueprintForOperatorCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<removeBlueprintForOperatorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<removeBlueprintForOperatorCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<removeBlueprintForOperatorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for removeBlueprintForOperatorCall