pub struct addMetricDefinitionCall {
pub serviceId: u64,
pub name: String,
pub minValue: Uint<256, 4>,
pub maxValue: Uint<256, 4>,
pub required: bool,
}Expand description
Function with signature addMetricDefinition(uint64,string,uint256,uint256,bool) and selector 0xae470a85.
function addMetricDefinition(uint64 serviceId, string memory name, uint256 minValue, uint256 maxValue, bool required) external;Fields
serviceId: u64name: StringminValue: Uint<256, 4>maxValue: Uint<256, 4>required: boolTrait Implementations
Sourceimpl Clone for addMetricDefinitionCall
impl Clone for addMetricDefinitionCall
Sourcefn clone(&self) -> addMetricDefinitionCall
fn clone(&self) -> addMetricDefinitionCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for addMetricDefinitionCall
impl Debug for addMetricDefinitionCall
Sourceimpl Default for addMetricDefinitionCall
impl Default for addMetricDefinitionCall
Sourcefn default() -> addMetricDefinitionCall
fn default() -> addMetricDefinitionCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for addMetricDefinitionCall
impl<'de> Deserialize<'de> for addMetricDefinitionCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<addMetricDefinitionCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<addMetricDefinitionCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for addMetricDefinitionCall
impl Hash for addMetricDefinitionCall
Sourceimpl PartialEq for addMetricDefinitionCall
impl PartialEq for addMetricDefinitionCall
Sourceimpl Serialize for addMetricDefinitionCall
impl Serialize for addMetricDefinitionCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for addMetricDefinitionCall
impl SolCall for addMetricDefinitionCall
Sourceconst SIGNATURE: &'static str = "addMetricDefinition(uint64,string,uint256,uint256,bool)"
const SIGNATURE: &'static str = "addMetricDefinition(uint64,string,uint256,uint256,bool)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, String, Uint<256>, Uint<256>, Bool)
type Parameters<'a> = (Uint<64>, String, Uint<256>, Uint<256>, Bool)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<addMetricDefinitionCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<addMetricDefinitionCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = addMetricDefinitionReturn
type Return = addMetricDefinitionReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<addMetricDefinitionCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<addMetricDefinitionCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<addMetricDefinitionCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> addMetricDefinitionCall
fn new<'a>( tuple: <<addMetricDefinitionCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> addMetricDefinitionCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <addMetricDefinitionCall as SolCall>::Token<'_>
fn tokenize(&self) -> <addMetricDefinitionCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<addMetricDefinitionCall as SolCall>::Return,
) -> <addMetricDefinitionCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<addMetricDefinitionCall as SolCall>::Return, ) -> <addMetricDefinitionCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<addMetricDefinitionCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<addMetricDefinitionCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<addMetricDefinitionCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<addMetricDefinitionCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for addMetricDefinitionCall
impl StructuralPartialEq for addMetricDefinitionCall