pub struct enableCustomMetricsCall {
pub serviceId: u64,
pub enabled: bool,
}Expand description
Function with signature enableCustomMetrics(uint64,bool) and selector 0xf9107f3b.
function enableCustomMetrics(uint64 serviceId, bool enabled) external;Fields
serviceId: u64enabled: boolTrait Implementations
Sourceimpl Clone for enableCustomMetricsCall
impl Clone for enableCustomMetricsCall
Sourcefn clone(&self) -> enableCustomMetricsCall
fn clone(&self) -> enableCustomMetricsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for enableCustomMetricsCall
impl Debug for enableCustomMetricsCall
Sourceimpl Default for enableCustomMetricsCall
impl Default for enableCustomMetricsCall
Sourcefn default() -> enableCustomMetricsCall
fn default() -> enableCustomMetricsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for enableCustomMetricsCall
impl<'de> Deserialize<'de> for enableCustomMetricsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<enableCustomMetricsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<enableCustomMetricsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for enableCustomMetricsCall
impl Hash for enableCustomMetricsCall
Sourceimpl PartialEq for enableCustomMetricsCall
impl PartialEq for enableCustomMetricsCall
Sourceimpl Serialize for enableCustomMetricsCall
impl Serialize for enableCustomMetricsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for enableCustomMetricsCall
impl SolCall for enableCustomMetricsCall
Sourceconst SIGNATURE: &'static str = "enableCustomMetrics(uint64,bool)"
const SIGNATURE: &'static str = "enableCustomMetrics(uint64,bool)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Bool)
type Parameters<'a> = (Uint<64>, Bool)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<enableCustomMetricsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<enableCustomMetricsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = enableCustomMetricsReturn
type Return = enableCustomMetricsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<enableCustomMetricsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<enableCustomMetricsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<enableCustomMetricsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> enableCustomMetricsCall
fn new<'a>( tuple: <<enableCustomMetricsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> enableCustomMetricsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <enableCustomMetricsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <enableCustomMetricsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<enableCustomMetricsCall as SolCall>::Return,
) -> <enableCustomMetricsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<enableCustomMetricsCall as SolCall>::Return, ) -> <enableCustomMetricsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<enableCustomMetricsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<enableCustomMetricsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<enableCustomMetricsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<enableCustomMetricsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for enableCustomMetricsCall
impl StructuralPartialEq for enableCustomMetricsCall