pub struct getHeartbeatConfigCall {
pub serviceId: u64,
}Expand description
Function with signature getHeartbeatConfig(uint64) and selector 0x0758236f.
function getHeartbeatConfig(uint64 serviceId) external view returns (HeartbeatConfig memory);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for getHeartbeatConfigCall
impl Clone for getHeartbeatConfigCall
Sourcefn clone(&self) -> getHeartbeatConfigCall
fn clone(&self) -> getHeartbeatConfigCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getHeartbeatConfigCall
impl Debug for getHeartbeatConfigCall
Sourceimpl Default for getHeartbeatConfigCall
impl Default for getHeartbeatConfigCall
Sourcefn default() -> getHeartbeatConfigCall
fn default() -> getHeartbeatConfigCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getHeartbeatConfigCall
impl<'de> Deserialize<'de> for getHeartbeatConfigCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatConfigCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatConfigCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getHeartbeatConfigCall
impl Hash for getHeartbeatConfigCall
Sourceimpl PartialEq for getHeartbeatConfigCall
impl PartialEq for getHeartbeatConfigCall
Sourceimpl Serialize for getHeartbeatConfigCall
impl Serialize for getHeartbeatConfigCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getHeartbeatConfigCall
impl SolCall for getHeartbeatConfigCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getHeartbeatConfigCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getHeartbeatConfigCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (HeartbeatConfig,)
type ReturnTuple<'a> = (HeartbeatConfig,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getHeartbeatConfigCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getHeartbeatConfigCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getHeartbeatConfigCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getHeartbeatConfigCall
fn new<'a>( tuple: <<getHeartbeatConfigCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getHeartbeatConfigCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getHeartbeatConfigCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getHeartbeatConfigCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getHeartbeatConfigCall as SolCall>::Return,
) -> <getHeartbeatConfigCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getHeartbeatConfigCall as SolCall>::Return, ) -> <getHeartbeatConfigCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getHeartbeatConfigCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getHeartbeatConfigCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getHeartbeatConfigCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getHeartbeatConfigCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getHeartbeatConfigCall
impl StructuralPartialEq for getHeartbeatConfigCall