pub struct getHeartbeatConfigReturn {
pub _0: <HeartbeatConfig as SolType>::RustType,
}Expand description
Container type for the return parameters of the getHeartbeatConfig(uint64) function.
Fields
_0: <HeartbeatConfig as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getHeartbeatConfigReturn
impl Clone for getHeartbeatConfigReturn
Sourcefn clone(&self) -> getHeartbeatConfigReturn
fn clone(&self) -> getHeartbeatConfigReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getHeartbeatConfigReturn
impl Debug for getHeartbeatConfigReturn
Sourceimpl Default for getHeartbeatConfigReturn
impl Default for getHeartbeatConfigReturn
Sourcefn default() -> getHeartbeatConfigReturn
fn default() -> getHeartbeatConfigReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getHeartbeatConfigReturn
impl<'de> Deserialize<'de> for getHeartbeatConfigReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatConfigReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getHeartbeatConfigReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getHeartbeatConfigReturn
Sourceimpl Hash for getHeartbeatConfigReturn
impl Hash for getHeartbeatConfigReturn
Sourceimpl PartialEq for getHeartbeatConfigReturn
impl PartialEq for getHeartbeatConfigReturn
Sourcefn eq(&self, other: &getHeartbeatConfigReturn) -> bool
fn eq(&self, other: &getHeartbeatConfigReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getHeartbeatConfigReturn
impl Serialize for getHeartbeatConfigReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getHeartbeatConfigReturn