pub struct getMetricDefinitionsReturn {
pub _0: Vec<<MetricDefinition as SolType>::RustType>,
}Expand description
Container type for the return parameters of the getMetricDefinitions(uint64) function.
Fields
_0: Vec<<MetricDefinition as SolType>::RustType>Trait Implementations
Sourceimpl Clone for getMetricDefinitionsReturn
impl Clone for getMetricDefinitionsReturn
Sourcefn clone(&self) -> getMetricDefinitionsReturn
fn clone(&self) -> getMetricDefinitionsReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getMetricDefinitionsReturn
impl Debug for getMetricDefinitionsReturn
Sourceimpl Default for getMetricDefinitionsReturn
impl Default for getMetricDefinitionsReturn
Sourcefn default() -> getMetricDefinitionsReturn
fn default() -> getMetricDefinitionsReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getMetricDefinitionsReturn
impl<'de> Deserialize<'de> for getMetricDefinitionsReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getMetricDefinitionsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getMetricDefinitionsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getMetricDefinitionsReturn
Sourceimpl Hash for getMetricDefinitionsReturn
impl Hash for getMetricDefinitionsReturn
Sourceimpl PartialEq for getMetricDefinitionsReturn
impl PartialEq for getMetricDefinitionsReturn
Sourcefn eq(&self, other: &getMetricDefinitionsReturn) -> bool
fn eq(&self, other: &getMetricDefinitionsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getMetricDefinitionsReturn
impl Serialize for getMetricDefinitionsReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getMetricDefinitionsReturn