pub struct getMetricValueCall {
pub serviceId: u64,
pub operator: Address,
pub metricName: String,
}Expand description
Function with signature getMetricValue(uint64,address,string) and selector 0xd551162c.
function getMetricValue(uint64 serviceId, address operator, string memory metricName) external view returns (uint256);Fields
serviceId: u64operator: AddressmetricName: StringTrait Implementations
Sourceimpl Clone for getMetricValueCall
impl Clone for getMetricValueCall
Sourcefn clone(&self) -> getMetricValueCall
fn clone(&self) -> getMetricValueCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getMetricValueCall
impl Debug for getMetricValueCall
Sourceimpl Default for getMetricValueCall
impl Default for getMetricValueCall
Sourcefn default() -> getMetricValueCall
fn default() -> getMetricValueCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getMetricValueCall
impl<'de> Deserialize<'de> for getMetricValueCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getMetricValueCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getMetricValueCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getMetricValueCall
impl Hash for getMetricValueCall
Sourceimpl PartialEq for getMetricValueCall
impl PartialEq for getMetricValueCall
Sourceimpl Serialize for getMetricValueCall
impl Serialize for getMetricValueCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getMetricValueCall
impl SolCall for getMetricValueCall
Sourceconst SIGNATURE: &'static str = "getMetricValue(uint64,address,string)"
const SIGNATURE: &'static str = "getMetricValue(uint64,address,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address, String)
type Parameters<'a> = (Uint<64>, Address, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getMetricValueCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getMetricValueCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getMetricValueCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getMetricValueCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getMetricValueCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getMetricValueCall
fn new<'a>( tuple: <<getMetricValueCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getMetricValueCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getMetricValueCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getMetricValueCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getMetricValueCall as SolCall>::Return,
) -> <getMetricValueCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getMetricValueCall as SolCall>::Return, ) -> <getMetricValueCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getMetricValueCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getMetricValueCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getMetricValueCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getMetricValueCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getMetricValueCall
impl StructuralPartialEq for getMetricValueCall