pub struct getMetricValueReturn {
pub _0: Uint<256, 4>,
}Expand description
Container type for the return parameters of the getMetricValue(uint64,address,string) function.
Fields
_0: Uint<256, 4>Trait Implementations
Sourceimpl Clone for getMetricValueReturn
impl Clone for getMetricValueReturn
Sourcefn clone(&self) -> getMetricValueReturn
fn clone(&self) -> getMetricValueReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getMetricValueReturn
impl Debug for getMetricValueReturn
Sourceimpl Default for getMetricValueReturn
impl Default for getMetricValueReturn
Sourcefn default() -> getMetricValueReturn
fn default() -> getMetricValueReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getMetricValueReturn
impl<'de> Deserialize<'de> for getMetricValueReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getMetricValueReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getMetricValueReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getMetricValueReturn
Sourceimpl Hash for getMetricValueReturn
impl Hash for getMetricValueReturn
Sourceimpl PartialEq for getMetricValueReturn
impl PartialEq for getMetricValueReturn
Sourcefn eq(&self, other: &getMetricValueReturn) -> bool
fn eq(&self, other: &getMetricValueReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getMetricValueReturn
impl Serialize for getMetricValueReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getMetricValueReturn