pub struct getOnlineOperatorsReturn {
pub _0: Vec<Address>,
}Expand description
Container type for the return parameters of the getOnlineOperators(uint64) function.
Fields
_0: Vec<Address>Trait Implementations
Sourceimpl Clone for getOnlineOperatorsReturn
impl Clone for getOnlineOperatorsReturn
Sourcefn clone(&self) -> getOnlineOperatorsReturn
fn clone(&self) -> getOnlineOperatorsReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOnlineOperatorsReturn
impl Debug for getOnlineOperatorsReturn
Sourceimpl Default for getOnlineOperatorsReturn
impl Default for getOnlineOperatorsReturn
Sourcefn default() -> getOnlineOperatorsReturn
fn default() -> getOnlineOperatorsReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOnlineOperatorsReturn
impl<'de> Deserialize<'de> for getOnlineOperatorsReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOnlineOperatorsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOnlineOperatorsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getOnlineOperatorsReturn
Sourceimpl Hash for getOnlineOperatorsReturn
impl Hash for getOnlineOperatorsReturn
Sourceimpl PartialEq for getOnlineOperatorsReturn
impl PartialEq for getOnlineOperatorsReturn
Sourcefn eq(&self, other: &getOnlineOperatorsReturn) -> bool
fn eq(&self, other: &getOnlineOperatorsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOnlineOperatorsReturn
impl Serialize for getOnlineOperatorsReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getOnlineOperatorsReturn