pub struct getOperatorStateCall {
pub serviceId: u64,
pub operator: Address,
}Expand description
Function with signature getOperatorState(uint64,address) and selector 0x71e7388c.
function getOperatorState(uint64 serviceId, address operator) external view returns (OperatorState memory);Fields
serviceId: u64operator: AddressTrait Implementations
Sourceimpl Clone for getOperatorStateCall
impl Clone for getOperatorStateCall
Sourcefn clone(&self) -> getOperatorStateCall
fn clone(&self) -> getOperatorStateCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOperatorStateCall
impl Debug for getOperatorStateCall
Sourceimpl Default for getOperatorStateCall
impl Default for getOperatorStateCall
Sourcefn default() -> getOperatorStateCall
fn default() -> getOperatorStateCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorStateCall
impl<'de> Deserialize<'de> for getOperatorStateCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorStateCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorStateCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getOperatorStateCall
impl Hash for getOperatorStateCall
Sourceimpl PartialEq for getOperatorStateCall
impl PartialEq for getOperatorStateCall
Sourceimpl Serialize for getOperatorStateCall
impl Serialize for getOperatorStateCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getOperatorStateCall
impl SolCall for getOperatorStateCall
Sourceconst SIGNATURE: &'static str = "getOperatorState(uint64,address)"
const SIGNATURE: &'static str = "getOperatorState(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getOperatorStateCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getOperatorStateCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (OperatorState,)
type ReturnTuple<'a> = (OperatorState,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getOperatorStateCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getOperatorStateCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getOperatorStateCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getOperatorStateCall
fn new<'a>( tuple: <<getOperatorStateCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getOperatorStateCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getOperatorStateCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getOperatorStateCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getOperatorStateCall as SolCall>::Return,
) -> <getOperatorStateCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getOperatorStateCall as SolCall>::Return, ) -> <getOperatorStateCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getOperatorStateCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getOperatorStateCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getOperatorStateCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getOperatorStateCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getOperatorStateCall
impl StructuralPartialEq for getOperatorStateCall