pub struct getOperatorStateReturn {
pub _0: <OperatorState as SolType>::RustType,
}Expand description
Container type for the return parameters of the getOperatorState(uint64,address) function.
Fields
_0: <OperatorState as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getOperatorStateReturn
impl Clone for getOperatorStateReturn
Sourcefn clone(&self) -> getOperatorStateReturn
fn clone(&self) -> getOperatorStateReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOperatorStateReturn
impl Debug for getOperatorStateReturn
Sourceimpl Default for getOperatorStateReturn
impl Default for getOperatorStateReturn
Sourcefn default() -> getOperatorStateReturn
fn default() -> getOperatorStateReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorStateReturn
impl<'de> Deserialize<'de> for getOperatorStateReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorStateReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorStateReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getOperatorStateReturn
Sourceimpl Hash for getOperatorStateReturn
impl Hash for getOperatorStateReturn
Sourceimpl PartialEq for getOperatorStateReturn
impl PartialEq for getOperatorStateReturn
Sourcefn eq(&self, other: &getOperatorStateReturn) -> bool
fn eq(&self, other: &getOperatorStateReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOperatorStateReturn
impl Serialize for getOperatorStateReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getOperatorStateReturn