pub struct getOperatorStatusCall {
pub serviceId: u64,
pub operator: Address,
}Expand description
Function with signature getOperatorStatus(uint64,address) and selector 0x62c7e8fc.
function getOperatorStatus(uint64 serviceId, address operator) external view returns (StatusCode);Fields
serviceId: u64operator: AddressTrait Implementations
Sourceimpl Clone for getOperatorStatusCall
impl Clone for getOperatorStatusCall
Sourcefn clone(&self) -> getOperatorStatusCall
fn clone(&self) -> getOperatorStatusCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOperatorStatusCall
impl Debug for getOperatorStatusCall
Sourceimpl Default for getOperatorStatusCall
impl Default for getOperatorStatusCall
Sourcefn default() -> getOperatorStatusCall
fn default() -> getOperatorStatusCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorStatusCall
impl<'de> Deserialize<'de> for getOperatorStatusCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorStatusCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorStatusCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getOperatorStatusCall
impl Hash for getOperatorStatusCall
Sourceimpl PartialEq for getOperatorStatusCall
impl PartialEq for getOperatorStatusCall
Sourceimpl Serialize for getOperatorStatusCall
impl Serialize for getOperatorStatusCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getOperatorStatusCall
impl SolCall for getOperatorStatusCall
Sourceconst SIGNATURE: &'static str = "getOperatorStatus(uint64,address)"
const SIGNATURE: &'static str = "getOperatorStatus(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getOperatorStatusCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getOperatorStatusCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (StatusCode,)
type ReturnTuple<'a> = (StatusCode,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getOperatorStatusCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getOperatorStatusCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getOperatorStatusCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getOperatorStatusCall
fn new<'a>( tuple: <<getOperatorStatusCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getOperatorStatusCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getOperatorStatusCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getOperatorStatusCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getOperatorStatusCall as SolCall>::Return,
) -> <getOperatorStatusCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getOperatorStatusCall as SolCall>::Return, ) -> <getOperatorStatusCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getOperatorStatusCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getOperatorStatusCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getOperatorStatusCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getOperatorStatusCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getOperatorStatusCall
impl StructuralPartialEq for getOperatorStatusCall