pub struct getOperatorStatusReturn {
pub _0: <StatusCode as SolType>::RustType,
}Expand description
Container type for the return parameters of the getOperatorStatus(uint64,address) function.
Fields
_0: <StatusCode as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getOperatorStatusReturn
impl Clone for getOperatorStatusReturn
Sourcefn clone(&self) -> getOperatorStatusReturn
fn clone(&self) -> getOperatorStatusReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOperatorStatusReturn
impl Debug for getOperatorStatusReturn
Sourceimpl Default for getOperatorStatusReturn
impl Default for getOperatorStatusReturn
Sourcefn default() -> getOperatorStatusReturn
fn default() -> getOperatorStatusReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorStatusReturn
impl<'de> Deserialize<'de> for getOperatorStatusReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorStatusReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorStatusReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getOperatorStatusReturn
Sourceimpl Hash for getOperatorStatusReturn
impl Hash for getOperatorStatusReturn
Sourceimpl PartialEq for getOperatorStatusReturn
impl PartialEq for getOperatorStatusReturn
Sourcefn eq(&self, other: &getOperatorStatusReturn) -> bool
fn eq(&self, other: &getOperatorStatusReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOperatorStatusReturn
impl Serialize for getOperatorStatusReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getOperatorStatusReturn