pub struct getSlashableOperatorsPaginatedCall {
pub serviceId: u64,
pub offset: Uint<256, 4>,
pub limit: Uint<256, 4>,
}Expand description
Function with signature getSlashableOperatorsPaginated(uint64,uint256,uint256) and selector 0x81beac2e.
function getSlashableOperatorsPaginated(uint64 serviceId, uint256 offset, uint256 limit) external view returns (address[] memory, uint256);Fields
serviceId: u64offset: Uint<256, 4>limit: Uint<256, 4>Trait Implementations
Sourceimpl Clone for getSlashableOperatorsPaginatedCall
impl Clone for getSlashableOperatorsPaginatedCall
Sourcefn clone(&self) -> getSlashableOperatorsPaginatedCall
fn clone(&self) -> getSlashableOperatorsPaginatedCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getSlashableOperatorsPaginatedCall
impl Default for getSlashableOperatorsPaginatedCall
Sourcefn default() -> getSlashableOperatorsPaginatedCall
fn default() -> getSlashableOperatorsPaginatedCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getSlashableOperatorsPaginatedCall
impl<'de> Deserialize<'de> for getSlashableOperatorsPaginatedCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashableOperatorsPaginatedCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashableOperatorsPaginatedCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getSlashableOperatorsPaginatedCall
impl PartialEq for getSlashableOperatorsPaginatedCall
Sourcefn eq(&self, other: &getSlashableOperatorsPaginatedCall) -> bool
fn eq(&self, other: &getSlashableOperatorsPaginatedCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getSlashableOperatorsPaginatedCall
impl Serialize for getSlashableOperatorsPaginatedCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getSlashableOperatorsPaginatedCall
impl SolCall for getSlashableOperatorsPaginatedCall
Sourceconst SIGNATURE: &'static str = "getSlashableOperatorsPaginated(uint64,uint256,uint256)"
const SIGNATURE: &'static str = "getSlashableOperatorsPaginated(uint64,uint256,uint256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<256>, Uint<256>)
type Parameters<'a> = (Uint<64>, Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getSlashableOperatorsPaginatedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getSlashableOperatorsPaginatedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = getSlashableOperatorsPaginatedReturn
type Return = getSlashableOperatorsPaginatedReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Array<Address>, Uint<256>)
type ReturnTuple<'a> = (Array<Address>, Uint<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getSlashableOperatorsPaginatedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getSlashableOperatorsPaginatedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getSlashableOperatorsPaginatedCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getSlashableOperatorsPaginatedCall
fn new<'a>( tuple: <<getSlashableOperatorsPaginatedCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getSlashableOperatorsPaginatedCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getSlashableOperatorsPaginatedCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getSlashableOperatorsPaginatedCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getSlashableOperatorsPaginatedCall as SolCall>::Return,
) -> <getSlashableOperatorsPaginatedCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getSlashableOperatorsPaginatedCall as SolCall>::Return, ) -> <getSlashableOperatorsPaginatedCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getSlashableOperatorsPaginatedCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getSlashableOperatorsPaginatedCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getSlashableOperatorsPaginatedCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getSlashableOperatorsPaginatedCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getSlashableOperatorsPaginatedCall
impl StructuralPartialEq for getSlashableOperatorsPaginatedCall