pub struct getSlashableOperatorsPaginatedReturn {
pub _0: Vec<Address>,
pub _1: Uint<256, 4>,
}Expand description
Container type for the return parameters of the getSlashableOperatorsPaginated(uint64,uint256,uint256) function.
Fields
_0: Vec<Address>_1: Uint<256, 4>Trait Implementations
Sourceimpl Clone for getSlashableOperatorsPaginatedReturn
impl Clone for getSlashableOperatorsPaginatedReturn
Sourcefn clone(&self) -> getSlashableOperatorsPaginatedReturn
fn clone(&self) -> getSlashableOperatorsPaginatedReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getSlashableOperatorsPaginatedReturn
impl Default for getSlashableOperatorsPaginatedReturn
Sourcefn default() -> getSlashableOperatorsPaginatedReturn
fn default() -> getSlashableOperatorsPaginatedReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getSlashableOperatorsPaginatedReturn
impl<'de> Deserialize<'de> for getSlashableOperatorsPaginatedReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashableOperatorsPaginatedReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashableOperatorsPaginatedReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getSlashableOperatorsPaginatedReturn
impl PartialEq for getSlashableOperatorsPaginatedReturn
Sourcefn eq(&self, other: &getSlashableOperatorsPaginatedReturn) -> bool
fn eq(&self, other: &getSlashableOperatorsPaginatedReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getSlashableOperatorsPaginatedReturn
impl Serialize for getSlashableOperatorsPaginatedReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for getSlashableOperatorsPaginatedReturn
impl StructuralPartialEq for getSlashableOperatorsPaginatedReturn