pub struct getSlashableOperatorsReturn {
pub _0: Vec<Address>,
}Expand description
Container type for the return parameters of the getSlashableOperators(uint64) function.
Fields
_0: Vec<Address>Trait Implementations
Sourceimpl Clone for getSlashableOperatorsReturn
impl Clone for getSlashableOperatorsReturn
Sourcefn clone(&self) -> getSlashableOperatorsReturn
fn clone(&self) -> getSlashableOperatorsReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getSlashableOperatorsReturn
impl Debug for getSlashableOperatorsReturn
Sourceimpl Default for getSlashableOperatorsReturn
impl Default for getSlashableOperatorsReturn
Sourcefn default() -> getSlashableOperatorsReturn
fn default() -> getSlashableOperatorsReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getSlashableOperatorsReturn
impl<'de> Deserialize<'de> for getSlashableOperatorsReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashableOperatorsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getSlashableOperatorsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getSlashableOperatorsReturn
Sourceimpl Hash for getSlashableOperatorsReturn
impl Hash for getSlashableOperatorsReturn
Sourceimpl PartialEq for getSlashableOperatorsReturn
impl PartialEq for getSlashableOperatorsReturn
Sourcefn eq(&self, other: &getSlashableOperatorsReturn) -> bool
fn eq(&self, other: &getSlashableOperatorsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getSlashableOperatorsReturn
impl Serialize for getSlashableOperatorsReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getSlashableOperatorsReturn