pub struct isHeartbeatCurrentReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the isHeartbeatCurrent(uint64,address) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for isHeartbeatCurrentReturn
impl Clone for isHeartbeatCurrentReturn
Sourcefn clone(&self) -> isHeartbeatCurrentReturn
fn clone(&self) -> isHeartbeatCurrentReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isHeartbeatCurrentReturn
impl Debug for isHeartbeatCurrentReturn
Sourceimpl Default for isHeartbeatCurrentReturn
impl Default for isHeartbeatCurrentReturn
Sourcefn default() -> isHeartbeatCurrentReturn
fn default() -> isHeartbeatCurrentReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isHeartbeatCurrentReturn
impl<'de> Deserialize<'de> for isHeartbeatCurrentReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isHeartbeatCurrentReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isHeartbeatCurrentReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for isHeartbeatCurrentReturn
Sourceimpl Hash for isHeartbeatCurrentReturn
impl Hash for isHeartbeatCurrentReturn
Sourceimpl PartialEq for isHeartbeatCurrentReturn
impl PartialEq for isHeartbeatCurrentReturn
Sourcefn eq(&self, other: &isHeartbeatCurrentReturn) -> bool
fn eq(&self, other: &isHeartbeatCurrentReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for isHeartbeatCurrentReturn
impl Serialize for isHeartbeatCurrentReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for isHeartbeatCurrentReturn