pub struct isRegisteredOperatorCall {
pub serviceId: u64,
pub operator: Address,
}Expand description
Function with signature isRegisteredOperator(uint64,address) and selector 0x60cf0991.
function isRegisteredOperator(uint64 serviceId, address operator) external view returns (bool);Fields
serviceId: u64operator: AddressTrait Implementations
Sourceimpl Clone for isRegisteredOperatorCall
impl Clone for isRegisteredOperatorCall
Sourcefn clone(&self) -> isRegisteredOperatorCall
fn clone(&self) -> isRegisteredOperatorCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isRegisteredOperatorCall
impl Debug for isRegisteredOperatorCall
Sourceimpl Default for isRegisteredOperatorCall
impl Default for isRegisteredOperatorCall
Sourcefn default() -> isRegisteredOperatorCall
fn default() -> isRegisteredOperatorCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isRegisteredOperatorCall
impl<'de> Deserialize<'de> for isRegisteredOperatorCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isRegisteredOperatorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isRegisteredOperatorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for isRegisteredOperatorCall
Sourceimpl Hash for isRegisteredOperatorCall
impl Hash for isRegisteredOperatorCall
Sourceimpl PartialEq for isRegisteredOperatorCall
impl PartialEq for isRegisteredOperatorCall
Sourcefn eq(&self, other: &isRegisteredOperatorCall) -> bool
fn eq(&self, other: &isRegisteredOperatorCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for isRegisteredOperatorCall
impl Serialize for isRegisteredOperatorCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for isRegisteredOperatorCall
impl SolCall for isRegisteredOperatorCall
Sourceconst SIGNATURE: &'static str = "isRegisteredOperator(uint64,address)"
const SIGNATURE: &'static str = "isRegisteredOperator(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<isRegisteredOperatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<isRegisteredOperatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<isRegisteredOperatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<isRegisteredOperatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<isRegisteredOperatorCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> isRegisteredOperatorCall
fn new<'a>( tuple: <<isRegisteredOperatorCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> isRegisteredOperatorCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <isRegisteredOperatorCall as SolCall>::Token<'_>
fn tokenize(&self) -> <isRegisteredOperatorCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<isRegisteredOperatorCall as SolCall>::Return,
) -> <isRegisteredOperatorCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<isRegisteredOperatorCall as SolCall>::Return, ) -> <isRegisteredOperatorCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<isRegisteredOperatorCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<isRegisteredOperatorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<isRegisteredOperatorCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<isRegisteredOperatorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for isRegisteredOperatorCall