pub struct registerOperatorCall {
pub serviceId: u64,
pub operator: Address,
}Expand description
Function with signature registerOperator(uint64,address) and selector 0x1e8f5ee5.
function registerOperator(uint64 serviceId, address operator) external;Fields
serviceId: u64operator: AddressTrait Implementations
Sourceimpl Clone for registerOperatorCall
impl Clone for registerOperatorCall
Sourcefn clone(&self) -> registerOperatorCall
fn clone(&self) -> registerOperatorCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for registerOperatorCall
impl Debug for registerOperatorCall
Sourceimpl Default for registerOperatorCall
impl Default for registerOperatorCall
Sourcefn default() -> registerOperatorCall
fn default() -> registerOperatorCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for registerOperatorCall
impl<'de> Deserialize<'de> for registerOperatorCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<registerOperatorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<registerOperatorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for registerOperatorCall
Sourceimpl Hash for registerOperatorCall
impl Hash for registerOperatorCall
Sourceimpl PartialEq for registerOperatorCall
impl PartialEq for registerOperatorCall
Sourcefn eq(&self, other: ®isterOperatorCall) -> bool
fn eq(&self, other: ®isterOperatorCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for registerOperatorCall
impl Serialize for registerOperatorCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for registerOperatorCall
impl SolCall for registerOperatorCall
Sourceconst SIGNATURE: &'static str = "registerOperator(uint64,address)"
const SIGNATURE: &'static str = "registerOperator(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<registerOperatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<registerOperatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = registerOperatorReturn
type Return = registerOperatorReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<registerOperatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<registerOperatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<registerOperatorCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> registerOperatorCall
fn new<'a>( tuple: <<registerOperatorCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> registerOperatorCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <registerOperatorCall as SolCall>::Token<'_>
fn tokenize(&self) -> <registerOperatorCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<registerOperatorCall as SolCall>::Return,
) -> <registerOperatorCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<registerOperatorCall as SolCall>::Return, ) -> <registerOperatorCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<registerOperatorCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<registerOperatorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<registerOperatorCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<registerOperatorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for registerOperatorCall