pub struct reportForSlashingCall {
pub serviceId: u64,
pub operator: Address,
pub reason: String,
}Expand description
Function with signature reportForSlashing(uint64,address,string) and selector 0xadff830c.
function reportForSlashing(uint64 serviceId, address operator, string memory reason) external;Fields
serviceId: u64operator: Addressreason: StringTrait Implementations
Sourceimpl Clone for reportForSlashingCall
impl Clone for reportForSlashingCall
Sourcefn clone(&self) -> reportForSlashingCall
fn clone(&self) -> reportForSlashingCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for reportForSlashingCall
impl Debug for reportForSlashingCall
Sourceimpl Default for reportForSlashingCall
impl Default for reportForSlashingCall
Sourcefn default() -> reportForSlashingCall
fn default() -> reportForSlashingCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for reportForSlashingCall
impl<'de> Deserialize<'de> for reportForSlashingCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<reportForSlashingCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<reportForSlashingCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for reportForSlashingCall
impl Hash for reportForSlashingCall
Sourceimpl PartialEq for reportForSlashingCall
impl PartialEq for reportForSlashingCall
Sourceimpl Serialize for reportForSlashingCall
impl Serialize for reportForSlashingCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for reportForSlashingCall
impl SolCall for reportForSlashingCall
Sourceconst SIGNATURE: &'static str = "reportForSlashing(uint64,address,string)"
const SIGNATURE: &'static str = "reportForSlashing(uint64,address,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address, String)
type Parameters<'a> = (Uint<64>, Address, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<reportForSlashingCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<reportForSlashingCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = reportForSlashingReturn
type Return = reportForSlashingReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<reportForSlashingCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<reportForSlashingCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<reportForSlashingCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> reportForSlashingCall
fn new<'a>( tuple: <<reportForSlashingCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> reportForSlashingCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <reportForSlashingCall as SolCall>::Token<'_>
fn tokenize(&self) -> <reportForSlashingCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<reportForSlashingCall as SolCall>::Return,
) -> <reportForSlashingCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<reportForSlashingCall as SolCall>::Return, ) -> <reportForSlashingCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<reportForSlashingCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<reportForSlashingCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<reportForSlashingCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<reportForSlashingCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for reportForSlashingCall
impl StructuralPartialEq for reportForSlashingCall