pub struct setMetricDefinitionsCall {
pub serviceId: u64,
pub definitions: Vec<<MetricDefinition as SolType>::RustType>,
}Expand description
Function with signature setMetricDefinitions(uint64,(string,uint256,uint256,bool)[]) and selector 0x191cbd1a.
function setMetricDefinitions(uint64 serviceId, MetricDefinition[] memory definitions) external;Fields
serviceId: u64definitions: Vec<<MetricDefinition as SolType>::RustType>Trait Implementations
Sourceimpl Clone for setMetricDefinitionsCall
impl Clone for setMetricDefinitionsCall
Sourcefn clone(&self) -> setMetricDefinitionsCall
fn clone(&self) -> setMetricDefinitionsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for setMetricDefinitionsCall
impl Debug for setMetricDefinitionsCall
Sourceimpl Default for setMetricDefinitionsCall
impl Default for setMetricDefinitionsCall
Sourcefn default() -> setMetricDefinitionsCall
fn default() -> setMetricDefinitionsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for setMetricDefinitionsCall
impl<'de> Deserialize<'de> for setMetricDefinitionsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<setMetricDefinitionsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<setMetricDefinitionsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for setMetricDefinitionsCall
impl Hash for setMetricDefinitionsCall
Sourceimpl PartialEq for setMetricDefinitionsCall
impl PartialEq for setMetricDefinitionsCall
Sourceimpl Serialize for setMetricDefinitionsCall
impl Serialize for setMetricDefinitionsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for setMetricDefinitionsCall
impl SolCall for setMetricDefinitionsCall
Sourceconst SIGNATURE: &'static str = "setMetricDefinitions(uint64,(string,uint256,uint256,bool)[])"
const SIGNATURE: &'static str = "setMetricDefinitions(uint64,(string,uint256,uint256,bool)[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Array<MetricDefinition>)
type Parameters<'a> = (Uint<64>, Array<MetricDefinition>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<setMetricDefinitionsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<setMetricDefinitionsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = setMetricDefinitionsReturn
type Return = setMetricDefinitionsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<setMetricDefinitionsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<setMetricDefinitionsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<setMetricDefinitionsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> setMetricDefinitionsCall
fn new<'a>( tuple: <<setMetricDefinitionsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> setMetricDefinitionsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <setMetricDefinitionsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <setMetricDefinitionsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<setMetricDefinitionsCall as SolCall>::Return,
) -> <setMetricDefinitionsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<setMetricDefinitionsCall as SolCall>::Return, ) -> <setMetricDefinitionsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<setMetricDefinitionsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<setMetricDefinitionsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<setMetricDefinitionsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<setMetricDefinitionsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for setMetricDefinitionsCall
impl StructuralPartialEq for setMetricDefinitionsCall