pub struct submitHeartbeatCall {
pub serviceId: u64,
pub blueprintId: u64,
pub statusCode: u8,
pub metrics: Bytes,
pub signature: Bytes,
}Expand description
Function with signature submitHeartbeat(uint64,uint64,uint8,bytes,bytes) and selector 0xd413a580.
function submitHeartbeat(uint64 serviceId, uint64 blueprintId, uint8 statusCode, bytes memory metrics, bytes memory signature) external;Fields
serviceId: u64blueprintId: u64statusCode: u8metrics: Bytessignature: BytesTrait Implementations
Sourceimpl Clone for submitHeartbeatCall
impl Clone for submitHeartbeatCall
Sourcefn clone(&self) -> submitHeartbeatCall
fn clone(&self) -> submitHeartbeatCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for submitHeartbeatCall
impl Debug for submitHeartbeatCall
Sourceimpl Default for submitHeartbeatCall
impl Default for submitHeartbeatCall
Sourcefn default() -> submitHeartbeatCall
fn default() -> submitHeartbeatCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for submitHeartbeatCall
impl<'de> Deserialize<'de> for submitHeartbeatCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitHeartbeatCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitHeartbeatCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for submitHeartbeatCall
impl Hash for submitHeartbeatCall
Sourceimpl PartialEq for submitHeartbeatCall
impl PartialEq for submitHeartbeatCall
Sourceimpl Serialize for submitHeartbeatCall
impl Serialize for submitHeartbeatCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for submitHeartbeatCall
impl SolCall for submitHeartbeatCall
Sourceconst SIGNATURE: &'static str = "submitHeartbeat(uint64,uint64,uint8,bytes,bytes)"
const SIGNATURE: &'static str = "submitHeartbeat(uint64,uint64,uint8,bytes,bytes)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>, Uint<8>, Bytes, Bytes)
type Parameters<'a> = (Uint<64>, Uint<64>, Uint<8>, Bytes, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<submitHeartbeatCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<submitHeartbeatCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = submitHeartbeatReturn
type Return = submitHeartbeatReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<submitHeartbeatCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<submitHeartbeatCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<submitHeartbeatCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> submitHeartbeatCall
fn new<'a>( tuple: <<submitHeartbeatCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> submitHeartbeatCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <submitHeartbeatCall as SolCall>::Token<'_>
fn tokenize(&self) -> <submitHeartbeatCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<submitHeartbeatCall as SolCall>::Return,
) -> <submitHeartbeatCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<submitHeartbeatCall as SolCall>::Return, ) -> <submitHeartbeatCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<submitHeartbeatCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<submitHeartbeatCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<submitHeartbeatCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<submitHeartbeatCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for submitHeartbeatCall
impl StructuralPartialEq for submitHeartbeatCall