pub struct submitHeartbeatDirectCall {
pub serviceId: u64,
pub blueprintId: u64,
pub statusCode: u8,
pub metrics: Bytes,
}Expand description
Function with signature submitHeartbeatDirect(uint64,uint64,uint8,bytes) and selector 0x5cce98a6.
function submitHeartbeatDirect(uint64 serviceId, uint64 blueprintId, uint8 statusCode, bytes memory metrics) external;Fields
serviceId: u64blueprintId: u64statusCode: u8metrics: BytesTrait Implementations
Sourceimpl Clone for submitHeartbeatDirectCall
impl Clone for submitHeartbeatDirectCall
Sourcefn clone(&self) -> submitHeartbeatDirectCall
fn clone(&self) -> submitHeartbeatDirectCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for submitHeartbeatDirectCall
impl Debug for submitHeartbeatDirectCall
Sourceimpl Default for submitHeartbeatDirectCall
impl Default for submitHeartbeatDirectCall
Sourcefn default() -> submitHeartbeatDirectCall
fn default() -> submitHeartbeatDirectCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for submitHeartbeatDirectCall
impl<'de> Deserialize<'de> for submitHeartbeatDirectCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitHeartbeatDirectCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitHeartbeatDirectCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for submitHeartbeatDirectCall
impl Hash for submitHeartbeatDirectCall
Sourceimpl Serialize for submitHeartbeatDirectCall
impl Serialize for submitHeartbeatDirectCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for submitHeartbeatDirectCall
impl SolCall for submitHeartbeatDirectCall
Sourceconst SIGNATURE: &'static str = "submitHeartbeatDirect(uint64,uint64,uint8,bytes)"
const SIGNATURE: &'static str = "submitHeartbeatDirect(uint64,uint64,uint8,bytes)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>, Uint<8>, Bytes)
type Parameters<'a> = (Uint<64>, Uint<64>, Uint<8>, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<submitHeartbeatDirectCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<submitHeartbeatDirectCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = submitHeartbeatDirectReturn
type Return = submitHeartbeatDirectReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<submitHeartbeatDirectCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<submitHeartbeatDirectCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<submitHeartbeatDirectCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> submitHeartbeatDirectCall
fn new<'a>( tuple: <<submitHeartbeatDirectCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> submitHeartbeatDirectCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <submitHeartbeatDirectCall as SolCall>::Token<'_>
fn tokenize(&self) -> <submitHeartbeatDirectCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<submitHeartbeatDirectCall as SolCall>::Return,
) -> <submitHeartbeatDirectCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<submitHeartbeatDirectCall as SolCall>::Return, ) -> <submitHeartbeatDirectCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<submitHeartbeatDirectCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<submitHeartbeatDirectCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<submitHeartbeatDirectCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<submitHeartbeatDirectCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for submitHeartbeatDirectCall
impl StructuralPartialEq for submitHeartbeatDirectCall