pub enum ITangleEvents {
Show 25 variants
BlueprintCreated(BlueprintCreated),
BlueprintDeactivated(BlueprintDeactivated),
BlueprintResourceRequirementsSet(BlueprintResourceRequirementsSet),
BlueprintTransferred(BlueprintTransferred),
BlueprintUpdated(BlueprintUpdated),
JobCompleted(JobCompleted),
JobResultSubmitted(JobResultSubmitted),
JobSubmitted(JobSubmitted),
JobSubmittedFromQuote(JobSubmittedFromQuote),
OperatorJoinedService(OperatorJoinedService),
OperatorLeftService(OperatorLeftService),
OperatorPreferencesUpdated(OperatorPreferencesUpdated),
OperatorRegistered(OperatorRegistered),
OperatorRewardAccrued(OperatorRewardAccrued),
OperatorUnregistered(OperatorUnregistered),
PaymentDistributed(PaymentDistributed),
RewardsClaimed(RewardsClaimed),
ServiceActivated(ServiceActivated),
ServiceApproved(ServiceApproved),
ServiceRejected(ServiceRejected),
ServiceRequested(ServiceRequested),
ServiceRequestedWithSecurity(ServiceRequestedWithSecurity),
ServiceTerminated(ServiceTerminated),
ServiceTerminatedForNonPayment(ServiceTerminatedForNonPayment),
SubscriptionBilled(SubscriptionBilled),
}Expand description
Container for all the ITangle events.
Variants
BlueprintCreated(BlueprintCreated)
BlueprintDeactivated(BlueprintDeactivated)
BlueprintResourceRequirementsSet(BlueprintResourceRequirementsSet)
BlueprintTransferred(BlueprintTransferred)
BlueprintUpdated(BlueprintUpdated)
JobCompleted(JobCompleted)
JobResultSubmitted(JobResultSubmitted)
JobSubmitted(JobSubmitted)
JobSubmittedFromQuote(JobSubmittedFromQuote)
OperatorJoinedService(OperatorJoinedService)
OperatorLeftService(OperatorLeftService)
OperatorPreferencesUpdated(OperatorPreferencesUpdated)
OperatorRegistered(OperatorRegistered)
OperatorRewardAccrued(OperatorRewardAccrued)
OperatorUnregistered(OperatorUnregistered)
PaymentDistributed(PaymentDistributed)
RewardsClaimed(RewardsClaimed)
ServiceActivated(ServiceActivated)
ServiceApproved(ServiceApproved)
ServiceRejected(ServiceRejected)
ServiceRequested(ServiceRequested)
ServiceRequestedWithSecurity(ServiceRequestedWithSecurity)
ServiceTerminated(ServiceTerminated)
ServiceTerminatedForNonPayment(ServiceTerminatedForNonPayment)
SubscriptionBilled(SubscriptionBilled)
Implementations
Sourceimpl ITangleEvents
impl ITangleEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.