deploy

Function deploy 

pub fn deploy<P, N>(
    __provider: P,
) -> impl Future<Output = Result<ITangleInstance<P, N>, Error>>
where P: Provider<N>, N: Network,
Deploys this contract using the given provider and constructor arguments, if any.

Returns a new instance of the contract, if the deployment was successful.

For more fine-grained control over the deployment process, use deploy_builder instead.