pub struct BlueprintCreated {
pub blueprintId: u64,
pub owner: Address,
pub manager: Address,
pub metadataUri: String,
}Expand description
Event with signature BlueprintCreated(uint64,address,address,string) and selector 0x333da2452b770d8297cd9630b93a2a9190c82483327a16472f621efc11ace010.
event BlueprintCreated(uint64 indexed blueprintId, address indexed owner, address manager, string metadataUri);Fields
blueprintId: u64owner: Addressmanager: AddressmetadataUri: StringTrait Implementations
Sourceimpl Clone for BlueprintCreated
impl Clone for BlueprintCreated
Sourcefn clone(&self) -> BlueprintCreated
fn clone(&self) -> BlueprintCreated
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlueprintCreated
impl Debug for BlueprintCreated
Sourceimpl Default for BlueprintCreated
impl Default for BlueprintCreated
Sourcefn default() -> BlueprintCreated
fn default() -> BlueprintCreated
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BlueprintCreated
impl<'de> Deserialize<'de> for BlueprintCreated
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BlueprintCreated, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BlueprintCreated, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for BlueprintCreated
impl Hash for BlueprintCreated
Sourceimpl IntoLogData for BlueprintCreated
impl IntoLogData for BlueprintCreated
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl PartialEq for BlueprintCreated
impl PartialEq for BlueprintCreated
Sourceimpl Serialize for BlueprintCreated
impl Serialize for BlueprintCreated
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolEvent for BlueprintCreated
impl SolEvent for BlueprintCreated
Sourceconst SIGNATURE: &'static str = "BlueprintCreated(uint64,address,address,string)"
const SIGNATURE: &'static str = "BlueprintCreated(uint64,address,address,string)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: FixedBytes<32>
const SIGNATURE_HASH: FixedBytes<32>
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Address, String)
type DataTuple<'a> = (Address, String)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<BlueprintCreated as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<BlueprintCreated as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>, Uint<64>, Address)
type TopicList = (FixedBytes<32>, Uint<64>, Address)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <<BlueprintCreated as SolEvent>::TopicList as SolType>::RustType,
data: <<BlueprintCreated as SolEvent>::DataTuple<'_> as SolType>::RustType,
) -> BlueprintCreated
fn new( topics: <<BlueprintCreated as SolEvent>::TopicList as SolType>::RustType, data: <<BlueprintCreated as SolEvent>::DataTuple<'_> as SolType>::RustType, ) -> BlueprintCreated
Convert decoded rust data to the event type. Read more
Sourcefn check_signature(
topics: &<<BlueprintCreated as SolEvent>::TopicList as SolType>::RustType,
) -> Result<(), Error>
fn check_signature( topics: &<<BlueprintCreated as SolEvent>::TopicList as SolType>::RustType, ) -> Result<(), Error>
Check that the event’s signature matches the given topics.
Sourcefn tokenize_body(&self) -> <BlueprintCreated as SolEvent>::DataToken<'_>
fn tokenize_body(&self) -> <BlueprintCreated as SolEvent>::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn topics(
&self,
) -> <<BlueprintCreated as SolEvent>::TopicList as SolType>::RustType
fn topics( &self, ) -> <<BlueprintCreated as SolEvent>::TopicList as SolType>::RustType
The event’s topics.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
Encode the topics of this event into the given buffer. Read more
Sourcefn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a
LogData.Sourcefn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer, with validation. Read more
Sourcefn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info.
Sourcefn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info, with validation. Read more
Sourcefn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object.
Sourcefn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object with validation.
impl Eq for BlueprintCreated
impl StructuralPartialEq for BlueprintCreated