pub struct OperatorPreferencesUpdated {
pub blueprintId: u64,
pub operator: Address,
pub ecdsaPublicKey: Bytes,
pub rpcAddress: String,
}Expand description
Event with signature OperatorPreferencesUpdated(uint64,address,bytes,string) and selector 0xbaca468a52670b77d74d0423b33ac5227a7f1a5c548e07006b29c6e2289779a6.
event OperatorPreferencesUpdated(uint64 indexed blueprintId, address indexed operator, bytes ecdsaPublicKey, string rpcAddress);Fields
blueprintId: u64operator: AddressecdsaPublicKey: BytesrpcAddress: StringTrait Implementations
Sourceimpl Clone for OperatorPreferencesUpdated
impl Clone for OperatorPreferencesUpdated
Sourcefn clone(&self) -> OperatorPreferencesUpdated
fn clone(&self) -> OperatorPreferencesUpdated
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperatorPreferencesUpdated
impl Debug for OperatorPreferencesUpdated
Sourceimpl Default for OperatorPreferencesUpdated
impl Default for OperatorPreferencesUpdated
Sourcefn default() -> OperatorPreferencesUpdated
fn default() -> OperatorPreferencesUpdated
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OperatorPreferencesUpdated
impl<'de> Deserialize<'de> for OperatorPreferencesUpdated
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<OperatorPreferencesUpdated, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<OperatorPreferencesUpdated, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for OperatorPreferencesUpdated
impl Hash for OperatorPreferencesUpdated
Sourceimpl IntoLogData for OperatorPreferencesUpdated
impl IntoLogData for OperatorPreferencesUpdated
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl Serialize for OperatorPreferencesUpdated
impl Serialize for OperatorPreferencesUpdated
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolEvent for OperatorPreferencesUpdated
impl SolEvent for OperatorPreferencesUpdated
Sourceconst SIGNATURE: &'static str = "OperatorPreferencesUpdated(uint64,address,bytes,string)"
const SIGNATURE: &'static str = "OperatorPreferencesUpdated(uint64,address,bytes,string)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: FixedBytes<32>
const SIGNATURE_HASH: FixedBytes<32>
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Bytes, String)
type DataTuple<'a> = (Bytes, String)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<OperatorPreferencesUpdated as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<OperatorPreferencesUpdated as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>, Uint<64>, Address)
type TopicList = (FixedBytes<32>, Uint<64>, Address)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <<OperatorPreferencesUpdated as SolEvent>::TopicList as SolType>::RustType,
data: <<OperatorPreferencesUpdated as SolEvent>::DataTuple<'_> as SolType>::RustType,
) -> OperatorPreferencesUpdated
fn new( topics: <<OperatorPreferencesUpdated as SolEvent>::TopicList as SolType>::RustType, data: <<OperatorPreferencesUpdated as SolEvent>::DataTuple<'_> as SolType>::RustType, ) -> OperatorPreferencesUpdated
Convert decoded rust data to the event type. Read more
Sourcefn check_signature(
topics: &<<OperatorPreferencesUpdated as SolEvent>::TopicList as SolType>::RustType,
) -> Result<(), Error>
fn check_signature( topics: &<<OperatorPreferencesUpdated as SolEvent>::TopicList as SolType>::RustType, ) -> Result<(), Error>
Check that the event’s signature matches the given topics.
Sourcefn tokenize_body(
&self,
) -> <OperatorPreferencesUpdated as SolEvent>::DataToken<'_>
fn tokenize_body( &self, ) -> <OperatorPreferencesUpdated as SolEvent>::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn topics(
&self,
) -> <<OperatorPreferencesUpdated as SolEvent>::TopicList as SolType>::RustType
fn topics( &self, ) -> <<OperatorPreferencesUpdated as SolEvent>::TopicList as SolType>::RustType
The event’s topics.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
Encode the topics of this event into the given buffer. Read more
Sourcefn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a
LogData.Sourcefn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer, with validation. Read more
Sourcefn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info.
Sourcefn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info, with validation. Read more
Sourcefn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object.
Sourcefn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object with validation.
impl Eq for OperatorPreferencesUpdated
impl StructuralPartialEq for OperatorPreferencesUpdated