pub struct OperatorRegistered {
pub blueprintId: u64,
pub operator: Address,
pub ecdsaPublicKey: Bytes,
pub rpcAddress: String,
}Expand description
Event with signature OperatorRegistered(uint64,address,bytes,string) and selector 0x0455541bf5feb5fcc32e827dc18bf2175448427c6ae72c8d5e985c99e4104102.
event OperatorRegistered(uint64 indexed blueprintId, address indexed operator, bytes ecdsaPublicKey, string rpcAddress);Fields
blueprintId: u64operator: AddressecdsaPublicKey: BytesrpcAddress: StringTrait Implementations
Sourceimpl Clone for OperatorRegistered
impl Clone for OperatorRegistered
Sourcefn clone(&self) -> OperatorRegistered
fn clone(&self) -> OperatorRegistered
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperatorRegistered
impl Debug for OperatorRegistered
Sourceimpl Default for OperatorRegistered
impl Default for OperatorRegistered
Sourcefn default() -> OperatorRegistered
fn default() -> OperatorRegistered
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OperatorRegistered
impl<'de> Deserialize<'de> for OperatorRegistered
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<OperatorRegistered, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<OperatorRegistered, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OperatorRegistered
Sourceimpl Hash for OperatorRegistered
impl Hash for OperatorRegistered
Sourceimpl IntoLogData for OperatorRegistered
impl IntoLogData for OperatorRegistered
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl PartialEq for OperatorRegistered
impl PartialEq for OperatorRegistered
Sourcefn eq(&self, other: &OperatorRegistered) -> bool
fn eq(&self, other: &OperatorRegistered) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OperatorRegistered
impl Serialize for OperatorRegistered
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolEvent for OperatorRegistered
impl SolEvent for OperatorRegistered
Sourceconst SIGNATURE: &'static str = "OperatorRegistered(uint64,address,bytes,string)"
const SIGNATURE: &'static str = "OperatorRegistered(uint64,address,bytes,string)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: FixedBytes<32>
const SIGNATURE_HASH: FixedBytes<32>
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Bytes, String)
type DataTuple<'a> = (Bytes, String)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<OperatorRegistered as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<OperatorRegistered as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>, Uint<64>, Address)
type TopicList = (FixedBytes<32>, Uint<64>, Address)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <<OperatorRegistered as SolEvent>::TopicList as SolType>::RustType,
data: <<OperatorRegistered as SolEvent>::DataTuple<'_> as SolType>::RustType,
) -> OperatorRegistered
fn new( topics: <<OperatorRegistered as SolEvent>::TopicList as SolType>::RustType, data: <<OperatorRegistered as SolEvent>::DataTuple<'_> as SolType>::RustType, ) -> OperatorRegistered
Convert decoded rust data to the event type. Read more
Sourcefn check_signature(
topics: &<<OperatorRegistered as SolEvent>::TopicList as SolType>::RustType,
) -> Result<(), Error>
fn check_signature( topics: &<<OperatorRegistered as SolEvent>::TopicList as SolType>::RustType, ) -> Result<(), Error>
Check that the event’s signature matches the given topics.
Sourcefn tokenize_body(&self) -> <OperatorRegistered as SolEvent>::DataToken<'_>
fn tokenize_body(&self) -> <OperatorRegistered as SolEvent>::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn topics(
&self,
) -> <<OperatorRegistered as SolEvent>::TopicList as SolType>::RustType
fn topics( &self, ) -> <<OperatorRegistered as SolEvent>::TopicList as SolType>::RustType
The event’s topics.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
Encode the topics of this event into the given buffer. Read more
Sourcefn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a
LogData.Sourcefn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer, with validation. Read more
Sourcefn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info.
Sourcefn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info, with validation. Read more
Sourcefn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object.
Sourcefn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object with validation.
impl StructuralPartialEq for OperatorRegistered