pub struct ackBlueprintSourcesCall {
pub blueprintId: u64,
pub sourcesHash: FixedBytes<32>,
}Expand description
Function with signature ackBlueprintSources(uint64,bytes32) and selector 0x38a702d5.
function ackBlueprintSources(uint64 blueprintId, bytes32 sourcesHash) external;Fields
blueprintId: u64sourcesHash: FixedBytes<32>Trait Implementations
Sourceimpl Clone for ackBlueprintSourcesCall
impl Clone for ackBlueprintSourcesCall
Sourcefn clone(&self) -> ackBlueprintSourcesCall
fn clone(&self) -> ackBlueprintSourcesCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ackBlueprintSourcesCall
impl Debug for ackBlueprintSourcesCall
Sourceimpl Default for ackBlueprintSourcesCall
impl Default for ackBlueprintSourcesCall
Sourcefn default() -> ackBlueprintSourcesCall
fn default() -> ackBlueprintSourcesCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ackBlueprintSourcesCall
impl<'de> Deserialize<'de> for ackBlueprintSourcesCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ackBlueprintSourcesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ackBlueprintSourcesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ackBlueprintSourcesCall
Sourceimpl Hash for ackBlueprintSourcesCall
impl Hash for ackBlueprintSourcesCall
Sourceimpl PartialEq for ackBlueprintSourcesCall
impl PartialEq for ackBlueprintSourcesCall
Sourcefn eq(&self, other: &ackBlueprintSourcesCall) -> bool
fn eq(&self, other: &ackBlueprintSourcesCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ackBlueprintSourcesCall
impl Serialize for ackBlueprintSourcesCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for ackBlueprintSourcesCall
impl SolCall for ackBlueprintSourcesCall
Sourceconst SIGNATURE: &'static str = "ackBlueprintSources(uint64,bytes32)"
const SIGNATURE: &'static str = "ackBlueprintSources(uint64,bytes32)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, FixedBytes<32>)
type Parameters<'a> = (Uint<64>, FixedBytes<32>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<ackBlueprintSourcesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<ackBlueprintSourcesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = ackBlueprintSourcesReturn
type Return = ackBlueprintSourcesReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<ackBlueprintSourcesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<ackBlueprintSourcesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<ackBlueprintSourcesCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> ackBlueprintSourcesCall
fn new<'a>( tuple: <<ackBlueprintSourcesCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> ackBlueprintSourcesCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <ackBlueprintSourcesCall as SolCall>::Token<'_>
fn tokenize(&self) -> <ackBlueprintSourcesCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<ackBlueprintSourcesCall as SolCall>::Return,
) -> <ackBlueprintSourcesCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<ackBlueprintSourcesCall as SolCall>::Return, ) -> <ackBlueprintSourcesCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<ackBlueprintSourcesCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<ackBlueprintSourcesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<ackBlueprintSourcesCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<ackBlueprintSourcesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for ackBlueprintSourcesCall