pub struct addPermittedCallerCall {
pub serviceId: u64,
pub caller: Address,
}Expand description
Function with signature addPermittedCaller(uint64,address) and selector 0x815d6a26.
function addPermittedCaller(uint64 serviceId, address caller) external;Fields
serviceId: u64caller: AddressTrait Implementations
Sourceimpl Clone for addPermittedCallerCall
impl Clone for addPermittedCallerCall
Sourcefn clone(&self) -> addPermittedCallerCall
fn clone(&self) -> addPermittedCallerCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for addPermittedCallerCall
impl Debug for addPermittedCallerCall
Sourceimpl Default for addPermittedCallerCall
impl Default for addPermittedCallerCall
Sourcefn default() -> addPermittedCallerCall
fn default() -> addPermittedCallerCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for addPermittedCallerCall
impl<'de> Deserialize<'de> for addPermittedCallerCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<addPermittedCallerCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<addPermittedCallerCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for addPermittedCallerCall
impl Hash for addPermittedCallerCall
Sourceimpl PartialEq for addPermittedCallerCall
impl PartialEq for addPermittedCallerCall
Sourceimpl Serialize for addPermittedCallerCall
impl Serialize for addPermittedCallerCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for addPermittedCallerCall
impl SolCall for addPermittedCallerCall
Sourceconst SIGNATURE: &'static str = "addPermittedCaller(uint64,address)"
const SIGNATURE: &'static str = "addPermittedCaller(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<addPermittedCallerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<addPermittedCallerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = addPermittedCallerReturn
type Return = addPermittedCallerReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<addPermittedCallerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<addPermittedCallerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<addPermittedCallerCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> addPermittedCallerCall
fn new<'a>( tuple: <<addPermittedCallerCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> addPermittedCallerCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <addPermittedCallerCall as SolCall>::Token<'_>
fn tokenize(&self) -> <addPermittedCallerCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<addPermittedCallerCall as SolCall>::Return,
) -> <addPermittedCallerCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<addPermittedCallerCall as SolCall>::Return, ) -> <addPermittedCallerCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<addPermittedCallerCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<addPermittedCallerCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<addPermittedCallerCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<addPermittedCallerCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for addPermittedCallerCall
impl StructuralPartialEq for addPermittedCallerCall