pub struct approveServiceCall {
pub requestId: u64,
pub stakingPercent: u8,
}Expand description
Function with signature approveService(uint64,uint8) and selector 0x614823b2.
function approveService(uint64 requestId, uint8 stakingPercent) external;Fields
requestId: u64stakingPercent: u8Trait Implementations
Sourceimpl Clone for approveServiceCall
impl Clone for approveServiceCall
Sourcefn clone(&self) -> approveServiceCall
fn clone(&self) -> approveServiceCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for approveServiceCall
impl Debug for approveServiceCall
Sourceimpl Default for approveServiceCall
impl Default for approveServiceCall
Sourcefn default() -> approveServiceCall
fn default() -> approveServiceCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for approveServiceCall
impl<'de> Deserialize<'de> for approveServiceCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<approveServiceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<approveServiceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for approveServiceCall
impl Hash for approveServiceCall
Sourceimpl PartialEq for approveServiceCall
impl PartialEq for approveServiceCall
Sourceimpl Serialize for approveServiceCall
impl Serialize for approveServiceCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for approveServiceCall
impl SolCall for approveServiceCall
Sourcetype Parameters<'a> = (Uint<64>, Uint<8>)
type Parameters<'a> = (Uint<64>, Uint<8>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<approveServiceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<approveServiceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = approveServiceReturn
type Return = approveServiceReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<approveServiceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<approveServiceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<approveServiceCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> approveServiceCall
fn new<'a>( tuple: <<approveServiceCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> approveServiceCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <approveServiceCall as SolCall>::Token<'_>
fn tokenize(&self) -> <approveServiceCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<approveServiceCall as SolCall>::Return,
) -> <approveServiceCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<approveServiceCall as SolCall>::Return, ) -> <approveServiceCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<approveServiceCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<approveServiceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<approveServiceCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<approveServiceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for approveServiceCall
impl StructuralPartialEq for approveServiceCall