pub struct approveServiceWithBlsCall {
pub requestId: u64,
pub stakingPercent: u8,
pub blsPubkey: [Uint<256, 4>; 4],
}Expand description
Function with signature approveServiceWithBls(uint64,uint8,uint256[4]) and selector 0x9926fbec.
function approveServiceWithBls(uint64 requestId, uint8 stakingPercent, uint256[4] memory blsPubkey) external;Fields
requestId: u64stakingPercent: u8blsPubkey: [Uint<256, 4>; 4]Trait Implementations
Sourceimpl Clone for approveServiceWithBlsCall
impl Clone for approveServiceWithBlsCall
Sourcefn clone(&self) -> approveServiceWithBlsCall
fn clone(&self) -> approveServiceWithBlsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for approveServiceWithBlsCall
impl Debug for approveServiceWithBlsCall
Sourceimpl Default for approveServiceWithBlsCall
impl Default for approveServiceWithBlsCall
Sourcefn default() -> approveServiceWithBlsCall
fn default() -> approveServiceWithBlsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for approveServiceWithBlsCall
impl<'de> Deserialize<'de> for approveServiceWithBlsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<approveServiceWithBlsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<approveServiceWithBlsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for approveServiceWithBlsCall
impl Hash for approveServiceWithBlsCall
Sourceimpl Serialize for approveServiceWithBlsCall
impl Serialize for approveServiceWithBlsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for approveServiceWithBlsCall
impl SolCall for approveServiceWithBlsCall
Sourceconst SIGNATURE: &'static str = "approveServiceWithBls(uint64,uint8,uint256[4])"
const SIGNATURE: &'static str = "approveServiceWithBls(uint64,uint8,uint256[4])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<8>, FixedArray<Uint<256>, 4>)
type Parameters<'a> = (Uint<64>, Uint<8>, FixedArray<Uint<256>, 4>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<approveServiceWithBlsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<approveServiceWithBlsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = approveServiceWithBlsReturn
type Return = approveServiceWithBlsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<approveServiceWithBlsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<approveServiceWithBlsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<approveServiceWithBlsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> approveServiceWithBlsCall
fn new<'a>( tuple: <<approveServiceWithBlsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> approveServiceWithBlsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <approveServiceWithBlsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <approveServiceWithBlsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<approveServiceWithBlsCall as SolCall>::Return,
) -> <approveServiceWithBlsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<approveServiceWithBlsCall as SolCall>::Return, ) -> <approveServiceWithBlsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<approveServiceWithBlsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<approveServiceWithBlsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<approveServiceWithBlsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<approveServiceWithBlsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for approveServiceWithBlsCall
impl StructuralPartialEq for approveServiceWithBlsCall