pub struct approveServiceWithCommitmentsAndBlsCall {
pub requestId: u64,
pub commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>,
pub blsPubkey: [Uint<256, 4>; 4],
}Expand description
Function with signature approveServiceWithCommitmentsAndBls(uint64,((uint8,address),uint16)[],uint256[4]) and selector 0x0e9a75de.
function approveServiceWithCommitmentsAndBls(uint64 requestId, Types.AssetSecurityCommitment[] memory commitments, uint256[4] memory blsPubkey) external;Fields
requestId: u64commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>blsPubkey: [Uint<256, 4>; 4]Trait Implementations
Sourceimpl Clone for approveServiceWithCommitmentsAndBlsCall
impl Clone for approveServiceWithCommitmentsAndBlsCall
Sourcefn clone(&self) -> approveServiceWithCommitmentsAndBlsCall
fn clone(&self) -> approveServiceWithCommitmentsAndBlsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for approveServiceWithCommitmentsAndBlsCall
impl<'de> Deserialize<'de> for approveServiceWithCommitmentsAndBlsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<approveServiceWithCommitmentsAndBlsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<approveServiceWithCommitmentsAndBlsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for approveServiceWithCommitmentsAndBlsCall
impl Serialize for approveServiceWithCommitmentsAndBlsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for approveServiceWithCommitmentsAndBlsCall
impl SolCall for approveServiceWithCommitmentsAndBlsCall
Sourceconst SIGNATURE: &'static str = "approveServiceWithCommitmentsAndBls(uint64,((uint8,address),uint16)[],uint256[4])"
const SIGNATURE: &'static str = "approveServiceWithCommitmentsAndBls(uint64,((uint8,address),uint16)[],uint256[4])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Array<AssetSecurityCommitment>, FixedArray<Uint<256>, 4>)
type Parameters<'a> = (Uint<64>, Array<AssetSecurityCommitment>, FixedArray<Uint<256>, 4>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<approveServiceWithCommitmentsAndBlsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<approveServiceWithCommitmentsAndBlsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = approveServiceWithCommitmentsAndBlsReturn
type Return = approveServiceWithCommitmentsAndBlsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<approveServiceWithCommitmentsAndBlsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<approveServiceWithCommitmentsAndBlsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<approveServiceWithCommitmentsAndBlsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> approveServiceWithCommitmentsAndBlsCall
fn new<'a>( tuple: <<approveServiceWithCommitmentsAndBlsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> approveServiceWithCommitmentsAndBlsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(
&self,
) -> <approveServiceWithCommitmentsAndBlsCall as SolCall>::Token<'_>
fn tokenize( &self, ) -> <approveServiceWithCommitmentsAndBlsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<approveServiceWithCommitmentsAndBlsCall as SolCall>::Return,
) -> <approveServiceWithCommitmentsAndBlsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<approveServiceWithCommitmentsAndBlsCall as SolCall>::Return, ) -> <approveServiceWithCommitmentsAndBlsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<approveServiceWithCommitmentsAndBlsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<approveServiceWithCommitmentsAndBlsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<approveServiceWithCommitmentsAndBlsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<approveServiceWithCommitmentsAndBlsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.