pub struct billSubscriptionBatchCall {
pub serviceIds: Vec<u64>,
}Expand description
Function with signature billSubscriptionBatch(uint64[]) and selector 0xda232ded.
function billSubscriptionBatch(uint64[] memory serviceIds) external returns (uint256 totalBilled, uint256 billedCount);Fields
serviceIds: Vec<u64>Trait Implementations
Sourceimpl Clone for billSubscriptionBatchCall
impl Clone for billSubscriptionBatchCall
Sourcefn clone(&self) -> billSubscriptionBatchCall
fn clone(&self) -> billSubscriptionBatchCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for billSubscriptionBatchCall
impl Debug for billSubscriptionBatchCall
Sourceimpl Default for billSubscriptionBatchCall
impl Default for billSubscriptionBatchCall
Sourcefn default() -> billSubscriptionBatchCall
fn default() -> billSubscriptionBatchCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for billSubscriptionBatchCall
impl<'de> Deserialize<'de> for billSubscriptionBatchCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<billSubscriptionBatchCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<billSubscriptionBatchCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for billSubscriptionBatchCall
impl Hash for billSubscriptionBatchCall
Sourceimpl Serialize for billSubscriptionBatchCall
impl Serialize for billSubscriptionBatchCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for billSubscriptionBatchCall
impl SolCall for billSubscriptionBatchCall
Sourceconst SIGNATURE: &'static str = "billSubscriptionBatch(uint64[])"
const SIGNATURE: &'static str = "billSubscriptionBatch(uint64[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Array<Uint<64>>,)
type Parameters<'a> = (Array<Uint<64>>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<billSubscriptionBatchCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<billSubscriptionBatchCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = billSubscriptionBatchReturn
type Return = billSubscriptionBatchReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Uint<256>, Uint<256>)
type ReturnTuple<'a> = (Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<billSubscriptionBatchCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<billSubscriptionBatchCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<billSubscriptionBatchCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> billSubscriptionBatchCall
fn new<'a>( tuple: <<billSubscriptionBatchCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> billSubscriptionBatchCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <billSubscriptionBatchCall as SolCall>::Token<'_>
fn tokenize(&self) -> <billSubscriptionBatchCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<billSubscriptionBatchCall as SolCall>::Return,
) -> <billSubscriptionBatchCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<billSubscriptionBatchCall as SolCall>::Return, ) -> <billSubscriptionBatchCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<billSubscriptionBatchCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<billSubscriptionBatchCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<billSubscriptionBatchCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<billSubscriptionBatchCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for billSubscriptionBatchCall
impl StructuralPartialEq for billSubscriptionBatchCall