pub struct blsPopMessageCall {
pub operator: Address,
pub blsPubkey: [Uint<256, 4>; 4],
}Expand description
Function with signature blsPopMessage(address,uint256[4]) and selector 0x433615a2.
function blsPopMessage(address operator, uint256[4] memory blsPubkey) external view returns (bytes memory);Fields
operator: AddressblsPubkey: [Uint<256, 4>; 4]Trait Implementations
Sourceimpl Clone for blsPopMessageCall
impl Clone for blsPopMessageCall
Sourcefn clone(&self) -> blsPopMessageCall
fn clone(&self) -> blsPopMessageCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for blsPopMessageCall
impl Debug for blsPopMessageCall
Sourceimpl Default for blsPopMessageCall
impl Default for blsPopMessageCall
Sourcefn default() -> blsPopMessageCall
fn default() -> blsPopMessageCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for blsPopMessageCall
impl<'de> Deserialize<'de> for blsPopMessageCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<blsPopMessageCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<blsPopMessageCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for blsPopMessageCall
Sourceimpl Hash for blsPopMessageCall
impl Hash for blsPopMessageCall
Sourceimpl PartialEq for blsPopMessageCall
impl PartialEq for blsPopMessageCall
Sourcefn eq(&self, other: &blsPopMessageCall) -> bool
fn eq(&self, other: &blsPopMessageCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for blsPopMessageCall
impl Serialize for blsPopMessageCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for blsPopMessageCall
impl SolCall for blsPopMessageCall
Sourceconst SIGNATURE: &'static str = "blsPopMessage(address,uint256[4])"
const SIGNATURE: &'static str = "blsPopMessage(address,uint256[4])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, FixedArray<Uint<256>, 4>)
type Parameters<'a> = (Address, FixedArray<Uint<256>, 4>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<blsPopMessageCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<blsPopMessageCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bytes,)
type ReturnTuple<'a> = (Bytes,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<blsPopMessageCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<blsPopMessageCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<blsPopMessageCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> blsPopMessageCall
fn new<'a>( tuple: <<blsPopMessageCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> blsPopMessageCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <blsPopMessageCall as SolCall>::Token<'_>
fn tokenize(&self) -> <blsPopMessageCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<blsPopMessageCall as SolCall>::Return,
) -> <blsPopMessageCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<blsPopMessageCall as SolCall>::Return, ) -> <blsPopMessageCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<blsPopMessageCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<blsPopMessageCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<blsPopMessageCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<blsPopMessageCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for blsPopMessageCall