pub struct blsPopMessageReturn {
pub _0: Bytes,
}Expand description
Container type for the return parameters of the blsPopMessage(address,uint256[4]) function.
Fields
_0: BytesTrait Implementations
Sourceimpl Clone for blsPopMessageReturn
impl Clone for blsPopMessageReturn
Sourcefn clone(&self) -> blsPopMessageReturn
fn clone(&self) -> blsPopMessageReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for blsPopMessageReturn
impl Debug for blsPopMessageReturn
Sourceimpl Default for blsPopMessageReturn
impl Default for blsPopMessageReturn
Sourcefn default() -> blsPopMessageReturn
fn default() -> blsPopMessageReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for blsPopMessageReturn
impl<'de> Deserialize<'de> for blsPopMessageReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<blsPopMessageReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<blsPopMessageReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for blsPopMessageReturn
Sourceimpl Hash for blsPopMessageReturn
impl Hash for blsPopMessageReturn
Sourceimpl PartialEq for blsPopMessageReturn
impl PartialEq for blsPopMessageReturn
Sourcefn eq(&self, other: &blsPopMessageReturn) -> bool
fn eq(&self, other: &blsPopMessageReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for blsPopMessageReturn
impl Serialize for blsPopMessageReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for blsPopMessageReturn