pub struct blueprintCountCall;Expand description
Function with signature blueprintCount() and selector 0xc602d4fa.
function blueprintCount() external view returns (uint64);Trait Implementations
Sourceimpl Clone for blueprintCountCall
impl Clone for blueprintCountCall
Sourcefn clone(&self) -> blueprintCountCall
fn clone(&self) -> blueprintCountCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for blueprintCountCall
impl Debug for blueprintCountCall
Sourceimpl Default for blueprintCountCall
impl Default for blueprintCountCall
Sourcefn default() -> blueprintCountCall
fn default() -> blueprintCountCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for blueprintCountCall
impl<'de> Deserialize<'de> for blueprintCountCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintCountCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintCountCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for blueprintCountCall
impl Hash for blueprintCountCall
Sourceimpl PartialEq for blueprintCountCall
impl PartialEq for blueprintCountCall
Sourceimpl Serialize for blueprintCountCall
impl Serialize for blueprintCountCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for blueprintCountCall
impl SolCall for blueprintCountCall
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<blueprintCountCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<blueprintCountCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<blueprintCountCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<blueprintCountCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<blueprintCountCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> blueprintCountCall
fn new<'a>( tuple: <<blueprintCountCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> blueprintCountCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <blueprintCountCall as SolCall>::Token<'_>
fn tokenize(&self) -> <blueprintCountCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<blueprintCountCall as SolCall>::Return,
) -> <blueprintCountCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<blueprintCountCall as SolCall>::Return, ) -> <blueprintCountCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<blueprintCountCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<blueprintCountCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<blueprintCountCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<blueprintCountCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for blueprintCountCall
impl StructuralPartialEq for blueprintCountCall