pub struct blueprintCountReturn {
pub _0: u64,
}Expand description
Container type for the return parameters of the blueprintCount() function.
Fields
_0: u64Trait Implementations
Sourceimpl Clone for blueprintCountReturn
impl Clone for blueprintCountReturn
Sourcefn clone(&self) -> blueprintCountReturn
fn clone(&self) -> blueprintCountReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for blueprintCountReturn
impl Debug for blueprintCountReturn
Sourceimpl Default for blueprintCountReturn
impl Default for blueprintCountReturn
Sourcefn default() -> blueprintCountReturn
fn default() -> blueprintCountReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for blueprintCountReturn
impl<'de> Deserialize<'de> for blueprintCountReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintCountReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintCountReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for blueprintCountReturn
Sourceimpl Hash for blueprintCountReturn
impl Hash for blueprintCountReturn
Sourceimpl PartialEq for blueprintCountReturn
impl PartialEq for blueprintCountReturn
Sourcefn eq(&self, other: &blueprintCountReturn) -> bool
fn eq(&self, other: &blueprintCountReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for blueprintCountReturn
impl Serialize for blueprintCountReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for blueprintCountReturn