pub struct blueprintDefinitionHashCall {
pub blueprintId: u64,
}Expand description
Function with signature blueprintDefinitionHash(uint64) and selector 0x35257ef4.
function blueprintDefinitionHash(uint64 blueprintId) external view returns (bytes32);Fields
blueprintId: u64Trait Implementations
Sourceimpl Clone for blueprintDefinitionHashCall
impl Clone for blueprintDefinitionHashCall
Sourcefn clone(&self) -> blueprintDefinitionHashCall
fn clone(&self) -> blueprintDefinitionHashCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for blueprintDefinitionHashCall
impl Debug for blueprintDefinitionHashCall
Sourceimpl Default for blueprintDefinitionHashCall
impl Default for blueprintDefinitionHashCall
Sourcefn default() -> blueprintDefinitionHashCall
fn default() -> blueprintDefinitionHashCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for blueprintDefinitionHashCall
impl<'de> Deserialize<'de> for blueprintDefinitionHashCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintDefinitionHashCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintDefinitionHashCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for blueprintDefinitionHashCall
Sourceimpl Hash for blueprintDefinitionHashCall
impl Hash for blueprintDefinitionHashCall
Sourceimpl PartialEq for blueprintDefinitionHashCall
impl PartialEq for blueprintDefinitionHashCall
Sourcefn eq(&self, other: &blueprintDefinitionHashCall) -> bool
fn eq(&self, other: &blueprintDefinitionHashCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for blueprintDefinitionHashCall
impl Serialize for blueprintDefinitionHashCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for blueprintDefinitionHashCall
impl SolCall for blueprintDefinitionHashCall
Sourceconst SIGNATURE: &'static str = "blueprintDefinitionHash(uint64)"
const SIGNATURE: &'static str = "blueprintDefinitionHash(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<blueprintDefinitionHashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<blueprintDefinitionHashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = FixedBytes<32>
type Return = FixedBytes<32>
The function’s return struct.
Sourcetype ReturnTuple<'a> = (FixedBytes<32>,)
type ReturnTuple<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<blueprintDefinitionHashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<blueprintDefinitionHashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<blueprintDefinitionHashCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> blueprintDefinitionHashCall
fn new<'a>( tuple: <<blueprintDefinitionHashCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> blueprintDefinitionHashCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <blueprintDefinitionHashCall as SolCall>::Token<'_>
fn tokenize(&self) -> <blueprintDefinitionHashCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<blueprintDefinitionHashCall as SolCall>::Return,
) -> <blueprintDefinitionHashCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<blueprintDefinitionHashCall as SolCall>::Return, ) -> <blueprintDefinitionHashCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<blueprintDefinitionHashCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<blueprintDefinitionHashCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<blueprintDefinitionHashCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<blueprintDefinitionHashCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for blueprintDefinitionHashCall