pub struct blueprintMasterRevisionReturn {
pub _0: u32,
}Expand description
Container type for the return parameters of the blueprintMasterRevision(uint64) function.
Fields
_0: u32Trait Implementations
Sourceimpl Clone for blueprintMasterRevisionReturn
impl Clone for blueprintMasterRevisionReturn
Sourcefn clone(&self) -> blueprintMasterRevisionReturn
fn clone(&self) -> blueprintMasterRevisionReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for blueprintMasterRevisionReturn
impl Default for blueprintMasterRevisionReturn
Sourcefn default() -> blueprintMasterRevisionReturn
fn default() -> blueprintMasterRevisionReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for blueprintMasterRevisionReturn
impl<'de> Deserialize<'de> for blueprintMasterRevisionReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintMasterRevisionReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintMasterRevisionReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for blueprintMasterRevisionReturn
Sourceimpl Hash for blueprintMasterRevisionReturn
impl Hash for blueprintMasterRevisionReturn
Sourceimpl PartialEq for blueprintMasterRevisionReturn
impl PartialEq for blueprintMasterRevisionReturn
Sourcefn eq(&self, other: &blueprintMasterRevisionReturn) -> bool
fn eq(&self, other: &blueprintMasterRevisionReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for blueprintMasterRevisionReturn
impl Serialize for blueprintMasterRevisionReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for blueprintMasterRevisionReturn