pub struct blueprintOperatorCountReturn {
pub _0: Uint<256, 4>,
}Expand description
Container type for the return parameters of the blueprintOperatorCount(uint64) function.
Fields
_0: Uint<256, 4>Trait Implementations
Sourceimpl Clone for blueprintOperatorCountReturn
impl Clone for blueprintOperatorCountReturn
Sourcefn clone(&self) -> blueprintOperatorCountReturn
fn clone(&self) -> blueprintOperatorCountReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for blueprintOperatorCountReturn
impl Debug for blueprintOperatorCountReturn
Sourceimpl Default for blueprintOperatorCountReturn
impl Default for blueprintOperatorCountReturn
Sourcefn default() -> blueprintOperatorCountReturn
fn default() -> blueprintOperatorCountReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for blueprintOperatorCountReturn
impl<'de> Deserialize<'de> for blueprintOperatorCountReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintOperatorCountReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintOperatorCountReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for blueprintOperatorCountReturn
Sourceimpl Hash for blueprintOperatorCountReturn
impl Hash for blueprintOperatorCountReturn
Sourceimpl PartialEq for blueprintOperatorCountReturn
impl PartialEq for blueprintOperatorCountReturn
Sourcefn eq(&self, other: &blueprintOperatorCountReturn) -> bool
fn eq(&self, other: &blueprintOperatorCountReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for blueprintOperatorCountReturn
impl Serialize for blueprintOperatorCountReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for blueprintOperatorCountReturn