pub struct blueprintSourcesHashCall {
pub blueprintId: u64,
}Expand description
Function with signature blueprintSourcesHash(uint64) and selector 0x8f78b256.
function blueprintSourcesHash(uint64 blueprintId) external view returns (bytes32);Fields
blueprintId: u64Trait Implementations
Sourceimpl Clone for blueprintSourcesHashCall
impl Clone for blueprintSourcesHashCall
Sourcefn clone(&self) -> blueprintSourcesHashCall
fn clone(&self) -> blueprintSourcesHashCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for blueprintSourcesHashCall
impl Debug for blueprintSourcesHashCall
Sourceimpl Default for blueprintSourcesHashCall
impl Default for blueprintSourcesHashCall
Sourcefn default() -> blueprintSourcesHashCall
fn default() -> blueprintSourcesHashCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for blueprintSourcesHashCall
impl<'de> Deserialize<'de> for blueprintSourcesHashCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintSourcesHashCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<blueprintSourcesHashCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for blueprintSourcesHashCall
Sourceimpl Hash for blueprintSourcesHashCall
impl Hash for blueprintSourcesHashCall
Sourceimpl PartialEq for blueprintSourcesHashCall
impl PartialEq for blueprintSourcesHashCall
Sourcefn eq(&self, other: &blueprintSourcesHashCall) -> bool
fn eq(&self, other: &blueprintSourcesHashCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for blueprintSourcesHashCall
impl Serialize for blueprintSourcesHashCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for blueprintSourcesHashCall
impl SolCall for blueprintSourcesHashCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<blueprintSourcesHashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<blueprintSourcesHashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = FixedBytes<32>
type Return = FixedBytes<32>
The function’s return struct.
Sourcetype ReturnTuple<'a> = (FixedBytes<32>,)
type ReturnTuple<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<blueprintSourcesHashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<blueprintSourcesHashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<blueprintSourcesHashCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> blueprintSourcesHashCall
fn new<'a>( tuple: <<blueprintSourcesHashCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> blueprintSourcesHashCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <blueprintSourcesHashCall as SolCall>::Token<'_>
fn tokenize(&self) -> <blueprintSourcesHashCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<blueprintSourcesHashCall as SolCall>::Return,
) -> <blueprintSourcesHashCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<blueprintSourcesHashCall as SolCall>::Return, ) -> <blueprintSourcesHashCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<blueprintSourcesHashCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<blueprintSourcesHashCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<blueprintSourcesHashCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<blueprintSourcesHashCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for blueprintSourcesHashCall