pub struct claimRewardsAllCall;Expand description
Function with signature claimRewardsAll() and selector 0x62b83dda.
function claimRewardsAll() external;Trait Implementations
Sourceimpl Clone for claimRewardsAllCall
impl Clone for claimRewardsAllCall
Sourcefn clone(&self) -> claimRewardsAllCall
fn clone(&self) -> claimRewardsAllCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for claimRewardsAllCall
impl Debug for claimRewardsAllCall
Sourceimpl Default for claimRewardsAllCall
impl Default for claimRewardsAllCall
Sourcefn default() -> claimRewardsAllCall
fn default() -> claimRewardsAllCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for claimRewardsAllCall
impl<'de> Deserialize<'de> for claimRewardsAllCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<claimRewardsAllCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<claimRewardsAllCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for claimRewardsAllCall
impl Hash for claimRewardsAllCall
Sourceimpl PartialEq for claimRewardsAllCall
impl PartialEq for claimRewardsAllCall
Sourceimpl Serialize for claimRewardsAllCall
impl Serialize for claimRewardsAllCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for claimRewardsAllCall
impl SolCall for claimRewardsAllCall
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<claimRewardsAllCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<claimRewardsAllCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = claimRewardsAllReturn
type Return = claimRewardsAllReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<claimRewardsAllCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<claimRewardsAllCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<claimRewardsAllCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> claimRewardsAllCall
fn new<'a>( tuple: <<claimRewardsAllCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> claimRewardsAllCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <claimRewardsAllCall as SolCall>::Token<'_>
fn tokenize(&self) -> <claimRewardsAllCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<claimRewardsAllCall as SolCall>::Return,
) -> <claimRewardsAllCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<claimRewardsAllCall as SolCall>::Return, ) -> <claimRewardsAllCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<claimRewardsAllCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<claimRewardsAllCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<claimRewardsAllCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<claimRewardsAllCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for claimRewardsAllCall
impl StructuralPartialEq for claimRewardsAllCall