pub struct claimRewards_1Call {
pub token: Address,
}Expand description
Function with signature claimRewards(address) and selector 0xef5cfb8c.
function claimRewards(address token) external;Fields
token: AddressTrait Implementations
Sourceimpl Clone for claimRewards_1Call
impl Clone for claimRewards_1Call
Sourcefn clone(&self) -> claimRewards_1Call
fn clone(&self) -> claimRewards_1Call
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for claimRewards_1Call
impl Debug for claimRewards_1Call
Sourceimpl Default for claimRewards_1Call
impl Default for claimRewards_1Call
Sourcefn default() -> claimRewards_1Call
fn default() -> claimRewards_1Call
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for claimRewards_1Call
impl<'de> Deserialize<'de> for claimRewards_1Call
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<claimRewards_1Call, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<claimRewards_1Call, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for claimRewards_1Call
impl Hash for claimRewards_1Call
Sourceimpl PartialEq for claimRewards_1Call
impl PartialEq for claimRewards_1Call
Sourceimpl Serialize for claimRewards_1Call
impl Serialize for claimRewards_1Call
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for claimRewards_1Call
impl SolCall for claimRewards_1Call
Sourcetype Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<claimRewards_1Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<claimRewards_1Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = claimRewards_1Return
type Return = claimRewards_1Return
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<claimRewards_1Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<claimRewards_1Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<claimRewards_1Call as SolCall>::Parameters<'a> as SolType>::RustType,
) -> claimRewards_1Call
fn new<'a>( tuple: <<claimRewards_1Call as SolCall>::Parameters<'a> as SolType>::RustType, ) -> claimRewards_1Call
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <claimRewards_1Call as SolCall>::Token<'_>
fn tokenize(&self) -> <claimRewards_1Call as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<claimRewards_1Call as SolCall>::Return,
) -> <claimRewards_1Call as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<claimRewards_1Call as SolCall>::Return, ) -> <claimRewards_1Call as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<claimRewards_1Call as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<claimRewards_1Call as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<claimRewards_1Call as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<claimRewards_1Call as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for claimRewards_1Call
impl StructuralPartialEq for claimRewards_1Call