pub struct createBlueprintReturn {
pub blueprintId: u64,
}Expand description
Container type for the return parameters of the createBlueprint((string,bytes32,address,uint32,bool,(uint8,uint8,uint32,uint32,uint256,uint64,uint256),(string,string,string,string,string,string,string,string,string),(string,string,string,bytes,bytes)[],bytes,bytes,(uint8,(string,string,string),(uint8,uint8,string,string),(uint8,string,string),(string,string,string),(uint8,uint8,string,bytes32)[])[],uint8[])) function.
Fields
blueprintId: u64Trait Implementations
Sourceimpl Clone for createBlueprintReturn
impl Clone for createBlueprintReturn
Sourcefn clone(&self) -> createBlueprintReturn
fn clone(&self) -> createBlueprintReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for createBlueprintReturn
impl Debug for createBlueprintReturn
Sourceimpl Default for createBlueprintReturn
impl Default for createBlueprintReturn
Sourcefn default() -> createBlueprintReturn
fn default() -> createBlueprintReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for createBlueprintReturn
impl<'de> Deserialize<'de> for createBlueprintReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<createBlueprintReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<createBlueprintReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for createBlueprintReturn
Sourceimpl Hash for createBlueprintReturn
impl Hash for createBlueprintReturn
Sourceimpl PartialEq for createBlueprintReturn
impl PartialEq for createBlueprintReturn
Sourcefn eq(&self, other: &createBlueprintReturn) -> bool
fn eq(&self, other: &createBlueprintReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for createBlueprintReturn
impl Serialize for createBlueprintReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for createBlueprintReturn