pub struct createServiceFromQuotesCall {
pub blueprintId: u64,
pub quotes: Vec<<SignedQuote as SolType>::RustType>,
pub config: Bytes,
pub permittedCallers: Vec<Address>,
pub ttl: u64,
}Expand description
Function with signature createServiceFromQuotes(uint64,((uint64,uint64,uint256,uint64,uint64,uint8,((uint8,address),uint16)[],(uint8,uint64)[]),bytes,address)[],bytes,address[],uint64) and selector 0x7b72a106.
function createServiceFromQuotes(uint64 blueprintId, Types.SignedQuote[] memory quotes, bytes memory config, address[] memory permittedCallers, uint64 ttl) external payable returns (uint64 serviceId);Fields
blueprintId: u64quotes: Vec<<SignedQuote as SolType>::RustType>config: BytespermittedCallers: Vec<Address>ttl: u64Trait Implementations
Sourceimpl Clone for createServiceFromQuotesCall
impl Clone for createServiceFromQuotesCall
Sourcefn clone(&self) -> createServiceFromQuotesCall
fn clone(&self) -> createServiceFromQuotesCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for createServiceFromQuotesCall
impl<'de> Deserialize<'de> for createServiceFromQuotesCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<createServiceFromQuotesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<createServiceFromQuotesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for createServiceFromQuotesCall
impl Serialize for createServiceFromQuotesCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for createServiceFromQuotesCall
impl SolCall for createServiceFromQuotesCall
Sourceconst SIGNATURE: &'static str = "createServiceFromQuotes(uint64,((uint64,uint64,uint256,uint64,uint64,uint8,((uint8,address),uint16)[],(uint8,uint64)[]),bytes,address)[],bytes,address[],uint64)"
const SIGNATURE: &'static str = "createServiceFromQuotes(uint64,((uint64,uint64,uint256,uint64,uint64,uint8,((uint8,address),uint16)[],(uint8,uint64)[]),bytes,address)[],bytes,address[],uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Array<SignedQuote>, Bytes, Array<Address>, Uint<64>)
type Parameters<'a> = (Uint<64>, Array<SignedQuote>, Bytes, Array<Address>, Uint<64>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<createServiceFromQuotesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<createServiceFromQuotesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<createServiceFromQuotesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<createServiceFromQuotesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<createServiceFromQuotesCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> createServiceFromQuotesCall
fn new<'a>( tuple: <<createServiceFromQuotesCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> createServiceFromQuotesCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <createServiceFromQuotesCall as SolCall>::Token<'_>
fn tokenize(&self) -> <createServiceFromQuotesCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<createServiceFromQuotesCall as SolCall>::Return,
) -> <createServiceFromQuotesCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<createServiceFromQuotesCall as SolCall>::Return, ) -> <createServiceFromQuotesCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<createServiceFromQuotesCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<createServiceFromQuotesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<createServiceFromQuotesCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<createServiceFromQuotesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.