pub struct createServiceFromQuotesReturn {
pub serviceId: u64,
}Expand description
Container type for the return parameters of the createServiceFromQuotes(uint64,((address,uint64,uint64,uint256,uint64,uint64,uint8,((uint8,address),uint16)[],(uint8,uint64)[]),bytes,address)[],bytes,address[],uint64) function.
Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for createServiceFromQuotesReturn
impl Clone for createServiceFromQuotesReturn
Sourcefn clone(&self) -> createServiceFromQuotesReturn
fn clone(&self) -> createServiceFromQuotesReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for createServiceFromQuotesReturn
impl Default for createServiceFromQuotesReturn
Sourcefn default() -> createServiceFromQuotesReturn
fn default() -> createServiceFromQuotesReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for createServiceFromQuotesReturn
impl<'de> Deserialize<'de> for createServiceFromQuotesReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<createServiceFromQuotesReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<createServiceFromQuotesReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for createServiceFromQuotesReturn
Sourceimpl Hash for createServiceFromQuotesReturn
impl Hash for createServiceFromQuotesReturn
Sourceimpl PartialEq for createServiceFromQuotesReturn
impl PartialEq for createServiceFromQuotesReturn
Sourcefn eq(&self, other: &createServiceFromQuotesReturn) -> bool
fn eq(&self, other: &createServiceFromQuotesReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for createServiceFromQuotesReturn
impl Serialize for createServiceFromQuotesReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for createServiceFromQuotesReturn