pub struct expireServiceRequestCall {
pub requestId: u64,
}Expand description
Function with signature expireServiceRequest(uint64) and selector 0xe07a86bd.
function expireServiceRequest(uint64 requestId) external;Fields
requestId: u64Trait Implementations
Sourceimpl Clone for expireServiceRequestCall
impl Clone for expireServiceRequestCall
Sourcefn clone(&self) -> expireServiceRequestCall
fn clone(&self) -> expireServiceRequestCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for expireServiceRequestCall
impl Debug for expireServiceRequestCall
Sourceimpl Default for expireServiceRequestCall
impl Default for expireServiceRequestCall
Sourcefn default() -> expireServiceRequestCall
fn default() -> expireServiceRequestCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for expireServiceRequestCall
impl<'de> Deserialize<'de> for expireServiceRequestCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<expireServiceRequestCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<expireServiceRequestCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for expireServiceRequestCall
Sourceimpl Hash for expireServiceRequestCall
impl Hash for expireServiceRequestCall
Sourceimpl PartialEq for expireServiceRequestCall
impl PartialEq for expireServiceRequestCall
Sourcefn eq(&self, other: &expireServiceRequestCall) -> bool
fn eq(&self, other: &expireServiceRequestCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for expireServiceRequestCall
impl Serialize for expireServiceRequestCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for expireServiceRequestCall
impl SolCall for expireServiceRequestCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<expireServiceRequestCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<expireServiceRequestCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = expireServiceRequestReturn
type Return = expireServiceRequestReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<expireServiceRequestCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<expireServiceRequestCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<expireServiceRequestCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> expireServiceRequestCall
fn new<'a>( tuple: <<expireServiceRequestCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> expireServiceRequestCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <expireServiceRequestCall as SolCall>::Token<'_>
fn tokenize(&self) -> <expireServiceRequestCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<expireServiceRequestCall as SolCall>::Return,
) -> <expireServiceRequestCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<expireServiceRequestCall as SolCall>::Return, ) -> <expireServiceRequestCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<expireServiceRequestCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<expireServiceRequestCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<expireServiceRequestCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<expireServiceRequestCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for expireServiceRequestCall