pub struct forceExitCall {
pub serviceId: u64,
pub operator: Address,
}Expand description
Function with signature forceExit(uint64,address) and selector 0xaea65925.
function forceExit(uint64 serviceId, address operator) external;Fields
serviceId: u64operator: AddressTrait Implementations
Sourceimpl Clone for forceExitCall
impl Clone for forceExitCall
Sourcefn clone(&self) -> forceExitCall
fn clone(&self) -> forceExitCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for forceExitCall
impl Debug for forceExitCall
Sourceimpl Default for forceExitCall
impl Default for forceExitCall
Sourcefn default() -> forceExitCall
fn default() -> forceExitCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for forceExitCall
impl<'de> Deserialize<'de> for forceExitCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<forceExitCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<forceExitCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for forceExitCall
impl Hash for forceExitCall
Sourceimpl PartialEq for forceExitCall
impl PartialEq for forceExitCall
Sourceimpl Serialize for forceExitCall
impl Serialize for forceExitCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for forceExitCall
impl SolCall for forceExitCall
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<forceExitCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<forceExitCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = forceExitReturn
type Return = forceExitReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<forceExitCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<forceExitCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<forceExitCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> forceExitCall
fn new<'a>( tuple: <<forceExitCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> forceExitCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<forceExitCall as SolCall>::Return,
) -> <forceExitCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<forceExitCall as SolCall>::Return, ) -> <forceExitCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<forceExitCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<forceExitCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<forceExitCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<forceExitCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for forceExitCall
impl StructuralPartialEq for forceExitCall