pub struct forceRemoveOperatorCall {
pub serviceId: u64,
pub operator: Address,
}Expand description
Function with signature forceRemoveOperator(uint64,address) and selector 0x684d89f5.
function forceRemoveOperator(uint64 serviceId, address operator) external;Fields
serviceId: u64operator: AddressTrait Implementations
Sourceimpl Clone for forceRemoveOperatorCall
impl Clone for forceRemoveOperatorCall
Sourcefn clone(&self) -> forceRemoveOperatorCall
fn clone(&self) -> forceRemoveOperatorCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for forceRemoveOperatorCall
impl Debug for forceRemoveOperatorCall
Sourceimpl Default for forceRemoveOperatorCall
impl Default for forceRemoveOperatorCall
Sourcefn default() -> forceRemoveOperatorCall
fn default() -> forceRemoveOperatorCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for forceRemoveOperatorCall
impl<'de> Deserialize<'de> for forceRemoveOperatorCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<forceRemoveOperatorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<forceRemoveOperatorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for forceRemoveOperatorCall
impl Hash for forceRemoveOperatorCall
Sourceimpl PartialEq for forceRemoveOperatorCall
impl PartialEq for forceRemoveOperatorCall
Sourceimpl Serialize for forceRemoveOperatorCall
impl Serialize for forceRemoveOperatorCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for forceRemoveOperatorCall
impl SolCall for forceRemoveOperatorCall
Sourceconst SIGNATURE: &'static str = "forceRemoveOperator(uint64,address)"
const SIGNATURE: &'static str = "forceRemoveOperator(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<forceRemoveOperatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<forceRemoveOperatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = forceRemoveOperatorReturn
type Return = forceRemoveOperatorReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<forceRemoveOperatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<forceRemoveOperatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<forceRemoveOperatorCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> forceRemoveOperatorCall
fn new<'a>( tuple: <<forceRemoveOperatorCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> forceRemoveOperatorCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <forceRemoveOperatorCall as SolCall>::Token<'_>
fn tokenize(&self) -> <forceRemoveOperatorCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<forceRemoveOperatorCall as SolCall>::Return,
) -> <forceRemoveOperatorCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<forceRemoveOperatorCall as SolCall>::Return, ) -> <forceRemoveOperatorCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<forceRemoveOperatorCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<forceRemoveOperatorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<forceRemoveOperatorCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<forceRemoveOperatorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for forceRemoveOperatorCall
impl StructuralPartialEq for forceRemoveOperatorCall