pub struct getBillableServicesCall {
pub serviceIds: Vec<u64>,
}Expand description
Function with signature getBillableServices(uint64[]) and selector 0x93f3ddaf.
function getBillableServices(uint64[] memory serviceIds) external view returns (uint64[] memory billable);Fields
serviceIds: Vec<u64>Trait Implementations
Sourceimpl Clone for getBillableServicesCall
impl Clone for getBillableServicesCall
Sourcefn clone(&self) -> getBillableServicesCall
fn clone(&self) -> getBillableServicesCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getBillableServicesCall
impl Debug for getBillableServicesCall
Sourceimpl Default for getBillableServicesCall
impl Default for getBillableServicesCall
Sourcefn default() -> getBillableServicesCall
fn default() -> getBillableServicesCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getBillableServicesCall
impl<'de> Deserialize<'de> for getBillableServicesCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getBillableServicesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getBillableServicesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getBillableServicesCall
impl Hash for getBillableServicesCall
Sourceimpl PartialEq for getBillableServicesCall
impl PartialEq for getBillableServicesCall
Sourceimpl Serialize for getBillableServicesCall
impl Serialize for getBillableServicesCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getBillableServicesCall
impl SolCall for getBillableServicesCall
Sourcetype Parameters<'a> = (Array<Uint<64>>,)
type Parameters<'a> = (Array<Uint<64>>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getBillableServicesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getBillableServicesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<Uint<64>>,)
type ReturnTuple<'a> = (Array<Uint<64>>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getBillableServicesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getBillableServicesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getBillableServicesCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getBillableServicesCall
fn new<'a>( tuple: <<getBillableServicesCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getBillableServicesCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getBillableServicesCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getBillableServicesCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getBillableServicesCall as SolCall>::Return,
) -> <getBillableServicesCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getBillableServicesCall as SolCall>::Return, ) -> <getBillableServicesCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getBillableServicesCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getBillableServicesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getBillableServicesCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getBillableServicesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getBillableServicesCall
impl StructuralPartialEq for getBillableServicesCall