pub struct getBlueprintResourceRequirementsCall {
pub blueprintId: u64,
}Expand description
Function with signature getBlueprintResourceRequirements(uint64) and selector 0x349e961a.
function getBlueprintResourceRequirements(uint64 blueprintId) external view returns (Types.ResourceCommitment[] memory);Fields
blueprintId: u64Trait Implementations
Sourceimpl Clone for getBlueprintResourceRequirementsCall
impl Clone for getBlueprintResourceRequirementsCall
Sourcefn clone(&self) -> getBlueprintResourceRequirementsCall
fn clone(&self) -> getBlueprintResourceRequirementsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getBlueprintResourceRequirementsCall
impl Default for getBlueprintResourceRequirementsCall
Sourcefn default() -> getBlueprintResourceRequirementsCall
fn default() -> getBlueprintResourceRequirementsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getBlueprintResourceRequirementsCall
impl<'de> Deserialize<'de> for getBlueprintResourceRequirementsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getBlueprintResourceRequirementsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getBlueprintResourceRequirementsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getBlueprintResourceRequirementsCall
impl PartialEq for getBlueprintResourceRequirementsCall
Sourcefn eq(&self, other: &getBlueprintResourceRequirementsCall) -> bool
fn eq(&self, other: &getBlueprintResourceRequirementsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getBlueprintResourceRequirementsCall
impl Serialize for getBlueprintResourceRequirementsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getBlueprintResourceRequirementsCall
impl SolCall for getBlueprintResourceRequirementsCall
Sourceconst SIGNATURE: &'static str = "getBlueprintResourceRequirements(uint64)"
const SIGNATURE: &'static str = "getBlueprintResourceRequirements(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getBlueprintResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getBlueprintResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<ResourceCommitment>,)
type ReturnTuple<'a> = (Array<ResourceCommitment>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getBlueprintResourceRequirementsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getBlueprintResourceRequirementsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getBlueprintResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getBlueprintResourceRequirementsCall
fn new<'a>( tuple: <<getBlueprintResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getBlueprintResourceRequirementsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(
&self,
) -> <getBlueprintResourceRequirementsCall as SolCall>::Token<'_>
fn tokenize( &self, ) -> <getBlueprintResourceRequirementsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getBlueprintResourceRequirementsCall as SolCall>::Return,
) -> <getBlueprintResourceRequirementsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getBlueprintResourceRequirementsCall as SolCall>::Return, ) -> <getBlueprintResourceRequirementsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getBlueprintResourceRequirementsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getBlueprintResourceRequirementsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getBlueprintResourceRequirementsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getBlueprintResourceRequirementsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getBlueprintResourceRequirementsCall
impl StructuralPartialEq for getBlueprintResourceRequirementsCall