pub struct getExitRequestReturn {
pub _0: <ExitRequest as SolType>::RustType,
}Expand description
Container type for the return parameters of the getExitRequest(uint64,address) function.
Fields
_0: <ExitRequest as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getExitRequestReturn
impl Clone for getExitRequestReturn
Sourcefn clone(&self) -> getExitRequestReturn
fn clone(&self) -> getExitRequestReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getExitRequestReturn
impl Debug for getExitRequestReturn
Sourceimpl Default for getExitRequestReturn
impl Default for getExitRequestReturn
Sourcefn default() -> getExitRequestReturn
fn default() -> getExitRequestReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getExitRequestReturn
impl<'de> Deserialize<'de> for getExitRequestReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getExitRequestReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getExitRequestReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getExitRequestReturn
Sourceimpl Hash for getExitRequestReturn
impl Hash for getExitRequestReturn
Sourceimpl PartialEq for getExitRequestReturn
impl PartialEq for getExitRequestReturn
Sourcefn eq(&self, other: &getExitRequestReturn) -> bool
fn eq(&self, other: &getExitRequestReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getExitRequestReturn
impl Serialize for getExitRequestReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getExitRequestReturn