pub struct getJobCallCall {
pub serviceId: u64,
pub callId: u64,
}Expand description
Function with signature getJobCall(uint64,uint64) and selector 0xa672bc0a.
function getJobCall(uint64 serviceId, uint64 callId) external view returns (Types.JobCall memory);Fields
serviceId: u64callId: u64Trait Implementations
Sourceimpl Clone for getJobCallCall
impl Clone for getJobCallCall
Sourcefn clone(&self) -> getJobCallCall
fn clone(&self) -> getJobCallCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getJobCallCall
impl Debug for getJobCallCall
Sourceimpl Default for getJobCallCall
impl Default for getJobCallCall
Sourcefn default() -> getJobCallCall
fn default() -> getJobCallCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getJobCallCall
impl<'de> Deserialize<'de> for getJobCallCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobCallCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobCallCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getJobCallCall
impl Hash for getJobCallCall
Sourceimpl PartialEq for getJobCallCall
impl PartialEq for getJobCallCall
Sourceimpl Serialize for getJobCallCall
impl Serialize for getJobCallCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getJobCallCall
impl SolCall for getJobCallCall
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>)
type Parameters<'a> = (Uint<64>, Uint<64>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getJobCallCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getJobCallCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (JobCall,)
type ReturnTuple<'a> = (JobCall,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getJobCallCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getJobCallCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getJobCallCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getJobCallCall
fn new<'a>( tuple: <<getJobCallCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getJobCallCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<getJobCallCall as SolCall>::Return,
) -> <getJobCallCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getJobCallCall as SolCall>::Return, ) -> <getJobCallCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getJobCallCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getJobCallCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getJobCallCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getJobCallCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getJobCallCall
impl StructuralPartialEq for getJobCallCall