pub struct getJobEventRateReturn {
pub rate: Uint<256, 4>,
}Expand description
Container type for the return parameters of the getJobEventRate(uint64,uint8) function.
Fields
rate: Uint<256, 4>Trait Implementations
Sourceimpl Clone for getJobEventRateReturn
impl Clone for getJobEventRateReturn
Sourcefn clone(&self) -> getJobEventRateReturn
fn clone(&self) -> getJobEventRateReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getJobEventRateReturn
impl Debug for getJobEventRateReturn
Sourceimpl Default for getJobEventRateReturn
impl Default for getJobEventRateReturn
Sourcefn default() -> getJobEventRateReturn
fn default() -> getJobEventRateReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getJobEventRateReturn
impl<'de> Deserialize<'de> for getJobEventRateReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobEventRateReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobEventRateReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getJobEventRateReturn
Sourceimpl Hash for getJobEventRateReturn
impl Hash for getJobEventRateReturn
Sourceimpl PartialEq for getJobEventRateReturn
impl PartialEq for getJobEventRateReturn
Sourcefn eq(&self, other: &getJobEventRateReturn) -> bool
fn eq(&self, other: &getJobEventRateReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getJobEventRateReturn
impl Serialize for getJobEventRateReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getJobEventRateReturn