pub struct getJobQuotedOperatorsCall {
pub serviceId: u64,
pub callId: u64,
}Expand description
Function with signature getJobQuotedOperators(uint64,uint64) and selector 0x038dda6c.
function getJobQuotedOperators(uint64 serviceId, uint64 callId) external view returns (address[] memory);Fields
serviceId: u64callId: u64Trait Implementations
Sourceimpl Clone for getJobQuotedOperatorsCall
impl Clone for getJobQuotedOperatorsCall
Sourcefn clone(&self) -> getJobQuotedOperatorsCall
fn clone(&self) -> getJobQuotedOperatorsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getJobQuotedOperatorsCall
impl Debug for getJobQuotedOperatorsCall
Sourceimpl Default for getJobQuotedOperatorsCall
impl Default for getJobQuotedOperatorsCall
Sourcefn default() -> getJobQuotedOperatorsCall
fn default() -> getJobQuotedOperatorsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getJobQuotedOperatorsCall
impl<'de> Deserialize<'de> for getJobQuotedOperatorsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobQuotedOperatorsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobQuotedOperatorsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getJobQuotedOperatorsCall
impl Hash for getJobQuotedOperatorsCall
Sourceimpl Serialize for getJobQuotedOperatorsCall
impl Serialize for getJobQuotedOperatorsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getJobQuotedOperatorsCall
impl SolCall for getJobQuotedOperatorsCall
Sourceconst SIGNATURE: &'static str = "getJobQuotedOperators(uint64,uint64)"
const SIGNATURE: &'static str = "getJobQuotedOperators(uint64,uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>)
type Parameters<'a> = (Uint<64>, Uint<64>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getJobQuotedOperatorsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getJobQuotedOperatorsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<Address>,)
type ReturnTuple<'a> = (Array<Address>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getJobQuotedOperatorsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getJobQuotedOperatorsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getJobQuotedOperatorsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getJobQuotedOperatorsCall
fn new<'a>( tuple: <<getJobQuotedOperatorsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getJobQuotedOperatorsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getJobQuotedOperatorsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getJobQuotedOperatorsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getJobQuotedOperatorsCall as SolCall>::Return,
) -> <getJobQuotedOperatorsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getJobQuotedOperatorsCall as SolCall>::Return, ) -> <getJobQuotedOperatorsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getJobQuotedOperatorsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getJobQuotedOperatorsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getJobQuotedOperatorsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getJobQuotedOperatorsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getJobQuotedOperatorsCall
impl StructuralPartialEq for getJobQuotedOperatorsCall