pub struct getJobQuotedOperatorsReturn {
pub _0: Vec<Address>,
}Expand description
Container type for the return parameters of the getJobQuotedOperators(uint64,uint64) function.
Fields
_0: Vec<Address>Trait Implementations
Sourceimpl Clone for getJobQuotedOperatorsReturn
impl Clone for getJobQuotedOperatorsReturn
Sourcefn clone(&self) -> getJobQuotedOperatorsReturn
fn clone(&self) -> getJobQuotedOperatorsReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getJobQuotedOperatorsReturn
impl Debug for getJobQuotedOperatorsReturn
Sourceimpl Default for getJobQuotedOperatorsReturn
impl Default for getJobQuotedOperatorsReturn
Sourcefn default() -> getJobQuotedOperatorsReturn
fn default() -> getJobQuotedOperatorsReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getJobQuotedOperatorsReturn
impl<'de> Deserialize<'de> for getJobQuotedOperatorsReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobQuotedOperatorsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobQuotedOperatorsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getJobQuotedOperatorsReturn
Sourceimpl Hash for getJobQuotedOperatorsReturn
impl Hash for getJobQuotedOperatorsReturn
Sourceimpl PartialEq for getJobQuotedOperatorsReturn
impl PartialEq for getJobQuotedOperatorsReturn
Sourcefn eq(&self, other: &getJobQuotedOperatorsReturn) -> bool
fn eq(&self, other: &getJobQuotedOperatorsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getJobQuotedOperatorsReturn
impl Serialize for getJobQuotedOperatorsReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getJobQuotedOperatorsReturn