pub struct getJobQuotedPriceCall {
pub serviceId: u64,
pub callId: u64,
pub operator: Address,
}Expand description
Function with signature getJobQuotedPrice(uint64,uint64,address) and selector 0xfca78d2d.
function getJobQuotedPrice(uint64 serviceId, uint64 callId, address operator) external view returns (uint256);Fields
serviceId: u64callId: u64operator: AddressTrait Implementations
Sourceimpl Clone for getJobQuotedPriceCall
impl Clone for getJobQuotedPriceCall
Sourcefn clone(&self) -> getJobQuotedPriceCall
fn clone(&self) -> getJobQuotedPriceCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getJobQuotedPriceCall
impl Debug for getJobQuotedPriceCall
Sourceimpl Default for getJobQuotedPriceCall
impl Default for getJobQuotedPriceCall
Sourcefn default() -> getJobQuotedPriceCall
fn default() -> getJobQuotedPriceCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getJobQuotedPriceCall
impl<'de> Deserialize<'de> for getJobQuotedPriceCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobQuotedPriceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobQuotedPriceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getJobQuotedPriceCall
impl Hash for getJobQuotedPriceCall
Sourceimpl PartialEq for getJobQuotedPriceCall
impl PartialEq for getJobQuotedPriceCall
Sourceimpl Serialize for getJobQuotedPriceCall
impl Serialize for getJobQuotedPriceCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getJobQuotedPriceCall
impl SolCall for getJobQuotedPriceCall
Sourceconst SIGNATURE: &'static str = "getJobQuotedPrice(uint64,uint64,address)"
const SIGNATURE: &'static str = "getJobQuotedPrice(uint64,uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getJobQuotedPriceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getJobQuotedPriceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getJobQuotedPriceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getJobQuotedPriceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getJobQuotedPriceCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getJobQuotedPriceCall
fn new<'a>( tuple: <<getJobQuotedPriceCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getJobQuotedPriceCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getJobQuotedPriceCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getJobQuotedPriceCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getJobQuotedPriceCall as SolCall>::Return,
) -> <getJobQuotedPriceCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getJobQuotedPriceCall as SolCall>::Return, ) -> <getJobQuotedPriceCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getJobQuotedPriceCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getJobQuotedPriceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getJobQuotedPriceCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getJobQuotedPriceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getJobQuotedPriceCall
impl StructuralPartialEq for getJobQuotedPriceCall