pub struct getJobQuotedPriceReturn {
pub _0: Uint<256, 4>,
}Expand description
Container type for the return parameters of the getJobQuotedPrice(uint64,uint64,address) function.
Fields
_0: Uint<256, 4>Trait Implementations
Sourceimpl Clone for getJobQuotedPriceReturn
impl Clone for getJobQuotedPriceReturn
Sourcefn clone(&self) -> getJobQuotedPriceReturn
fn clone(&self) -> getJobQuotedPriceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getJobQuotedPriceReturn
impl Debug for getJobQuotedPriceReturn
Sourceimpl Default for getJobQuotedPriceReturn
impl Default for getJobQuotedPriceReturn
Sourcefn default() -> getJobQuotedPriceReturn
fn default() -> getJobQuotedPriceReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getJobQuotedPriceReturn
impl<'de> Deserialize<'de> for getJobQuotedPriceReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobQuotedPriceReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getJobQuotedPriceReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getJobQuotedPriceReturn
Sourceimpl Hash for getJobQuotedPriceReturn
impl Hash for getJobQuotedPriceReturn
Sourceimpl PartialEq for getJobQuotedPriceReturn
impl PartialEq for getJobQuotedPriceReturn
Sourcefn eq(&self, other: &getJobQuotedPriceReturn) -> bool
fn eq(&self, other: &getJobQuotedPriceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getJobQuotedPriceReturn
impl Serialize for getJobQuotedPriceReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getJobQuotedPriceReturn