pub struct getOperatorBlsPubkeyReturn {
pub blsPubkey: [Uint<256, 4>; 4],
}Expand description
Container type for the return parameters of the getOperatorBlsPubkey(uint64,address) function.
Fields
blsPubkey: [Uint<256, 4>; 4]Trait Implementations
Sourceimpl Clone for getOperatorBlsPubkeyReturn
impl Clone for getOperatorBlsPubkeyReturn
Sourcefn clone(&self) -> getOperatorBlsPubkeyReturn
fn clone(&self) -> getOperatorBlsPubkeyReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOperatorBlsPubkeyReturn
impl Debug for getOperatorBlsPubkeyReturn
Sourceimpl Default for getOperatorBlsPubkeyReturn
impl Default for getOperatorBlsPubkeyReturn
Sourcefn default() -> getOperatorBlsPubkeyReturn
fn default() -> getOperatorBlsPubkeyReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorBlsPubkeyReturn
impl<'de> Deserialize<'de> for getOperatorBlsPubkeyReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorBlsPubkeyReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorBlsPubkeyReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getOperatorBlsPubkeyReturn
Sourceimpl Hash for getOperatorBlsPubkeyReturn
impl Hash for getOperatorBlsPubkeyReturn
Sourceimpl PartialEq for getOperatorBlsPubkeyReturn
impl PartialEq for getOperatorBlsPubkeyReturn
Sourcefn eq(&self, other: &getOperatorBlsPubkeyReturn) -> bool
fn eq(&self, other: &getOperatorBlsPubkeyReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOperatorBlsPubkeyReturn
impl Serialize for getOperatorBlsPubkeyReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getOperatorBlsPubkeyReturn