pub struct getOperatorPreferencesReturn {
pub _0: <OperatorPreferences as SolType>::RustType,
}Expand description
Container type for the return parameters of the getOperatorPreferences(uint64,address) function.
Fields
_0: <OperatorPreferences as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getOperatorPreferencesReturn
impl Clone for getOperatorPreferencesReturn
Sourcefn clone(&self) -> getOperatorPreferencesReturn
fn clone(&self) -> getOperatorPreferencesReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOperatorPreferencesReturn
impl Debug for getOperatorPreferencesReturn
Sourceimpl Default for getOperatorPreferencesReturn
impl Default for getOperatorPreferencesReturn
Sourcefn default() -> getOperatorPreferencesReturn
fn default() -> getOperatorPreferencesReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorPreferencesReturn
impl<'de> Deserialize<'de> for getOperatorPreferencesReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorPreferencesReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorPreferencesReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getOperatorPreferencesReturn
Sourceimpl Hash for getOperatorPreferencesReturn
impl Hash for getOperatorPreferencesReturn
Sourceimpl PartialEq for getOperatorPreferencesReturn
impl PartialEq for getOperatorPreferencesReturn
Sourcefn eq(&self, other: &getOperatorPreferencesReturn) -> bool
fn eq(&self, other: &getOperatorPreferencesReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOperatorPreferencesReturn
impl Serialize for getOperatorPreferencesReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getOperatorPreferencesReturn