pub struct getOperatorRegistrationCall {
pub blueprintId: u64,
pub operator: Address,
}Expand description
Function with signature getOperatorRegistration(uint64,address) and selector 0x6bda42f3.
function getOperatorRegistration(uint64 blueprintId, address operator) external view returns (Types.OperatorRegistration memory);Fields
blueprintId: u64operator: AddressTrait Implementations
Sourceimpl Clone for getOperatorRegistrationCall
impl Clone for getOperatorRegistrationCall
Sourcefn clone(&self) -> getOperatorRegistrationCall
fn clone(&self) -> getOperatorRegistrationCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOperatorRegistrationCall
impl Debug for getOperatorRegistrationCall
Sourceimpl Default for getOperatorRegistrationCall
impl Default for getOperatorRegistrationCall
Sourcefn default() -> getOperatorRegistrationCall
fn default() -> getOperatorRegistrationCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorRegistrationCall
impl<'de> Deserialize<'de> for getOperatorRegistrationCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorRegistrationCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorRegistrationCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getOperatorRegistrationCall
impl Hash for getOperatorRegistrationCall
Sourceimpl Serialize for getOperatorRegistrationCall
impl Serialize for getOperatorRegistrationCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getOperatorRegistrationCall
impl SolCall for getOperatorRegistrationCall
Sourceconst SIGNATURE: &'static str = "getOperatorRegistration(uint64,address)"
const SIGNATURE: &'static str = "getOperatorRegistration(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getOperatorRegistrationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getOperatorRegistrationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (OperatorRegistration,)
type ReturnTuple<'a> = (OperatorRegistration,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getOperatorRegistrationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getOperatorRegistrationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getOperatorRegistrationCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getOperatorRegistrationCall
fn new<'a>( tuple: <<getOperatorRegistrationCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getOperatorRegistrationCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getOperatorRegistrationCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getOperatorRegistrationCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getOperatorRegistrationCall as SolCall>::Return,
) -> <getOperatorRegistrationCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getOperatorRegistrationCall as SolCall>::Return, ) -> <getOperatorRegistrationCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getOperatorRegistrationCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getOperatorRegistrationCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getOperatorRegistrationCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getOperatorRegistrationCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getOperatorRegistrationCall
impl StructuralPartialEq for getOperatorRegistrationCall