pub struct getOperatorTotalActiveServicesCall {
pub operator: Address,
}Expand description
Function with signature getOperatorTotalActiveServices(address) and selector 0x0ded8bf9.
function getOperatorTotalActiveServices(address operator) external view returns (uint256 count);Fields
operator: AddressTrait Implementations
Sourceimpl Clone for getOperatorTotalActiveServicesCall
impl Clone for getOperatorTotalActiveServicesCall
Sourcefn clone(&self) -> getOperatorTotalActiveServicesCall
fn clone(&self) -> getOperatorTotalActiveServicesCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getOperatorTotalActiveServicesCall
impl Default for getOperatorTotalActiveServicesCall
Sourcefn default() -> getOperatorTotalActiveServicesCall
fn default() -> getOperatorTotalActiveServicesCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorTotalActiveServicesCall
impl<'de> Deserialize<'de> for getOperatorTotalActiveServicesCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorTotalActiveServicesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorTotalActiveServicesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getOperatorTotalActiveServicesCall
impl PartialEq for getOperatorTotalActiveServicesCall
Sourcefn eq(&self, other: &getOperatorTotalActiveServicesCall) -> bool
fn eq(&self, other: &getOperatorTotalActiveServicesCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOperatorTotalActiveServicesCall
impl Serialize for getOperatorTotalActiveServicesCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getOperatorTotalActiveServicesCall
impl SolCall for getOperatorTotalActiveServicesCall
Sourceconst SIGNATURE: &'static str = "getOperatorTotalActiveServices(address)"
const SIGNATURE: &'static str = "getOperatorTotalActiveServices(address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getOperatorTotalActiveServicesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getOperatorTotalActiveServicesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getOperatorTotalActiveServicesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getOperatorTotalActiveServicesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getOperatorTotalActiveServicesCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getOperatorTotalActiveServicesCall
fn new<'a>( tuple: <<getOperatorTotalActiveServicesCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getOperatorTotalActiveServicesCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getOperatorTotalActiveServicesCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getOperatorTotalActiveServicesCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getOperatorTotalActiveServicesCall as SolCall>::Return,
) -> <getOperatorTotalActiveServicesCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getOperatorTotalActiveServicesCall as SolCall>::Return, ) -> <getOperatorTotalActiveServicesCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getOperatorTotalActiveServicesCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getOperatorTotalActiveServicesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getOperatorTotalActiveServicesCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getOperatorTotalActiveServicesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getOperatorTotalActiveServicesCall
impl StructuralPartialEq for getOperatorTotalActiveServicesCall