pub struct getOperatorTotalActiveServicesReturn {
pub count: Uint<256, 4>,
}Expand description
Container type for the return parameters of the getOperatorTotalActiveServices(address) function.
Fields
count: Uint<256, 4>Trait Implementations
Sourceimpl Clone for getOperatorTotalActiveServicesReturn
impl Clone for getOperatorTotalActiveServicesReturn
Sourcefn clone(&self) -> getOperatorTotalActiveServicesReturn
fn clone(&self) -> getOperatorTotalActiveServicesReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getOperatorTotalActiveServicesReturn
impl Default for getOperatorTotalActiveServicesReturn
Sourcefn default() -> getOperatorTotalActiveServicesReturn
fn default() -> getOperatorTotalActiveServicesReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorTotalActiveServicesReturn
impl<'de> Deserialize<'de> for getOperatorTotalActiveServicesReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorTotalActiveServicesReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorTotalActiveServicesReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getOperatorTotalActiveServicesReturn
Sourceimpl PartialEq for getOperatorTotalActiveServicesReturn
impl PartialEq for getOperatorTotalActiveServicesReturn
Sourcefn eq(&self, other: &getOperatorTotalActiveServicesReturn) -> bool
fn eq(&self, other: &getOperatorTotalActiveServicesReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOperatorTotalActiveServicesReturn
impl Serialize for getOperatorTotalActiveServicesReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getOperatorTotalActiveServicesReturn