pub struct getServiceEscrowCall {
pub serviceId: u64,
}Expand description
Function with signature getServiceEscrow(uint64) and selector 0xeb8c3bcd.
function getServiceEscrow(uint64 serviceId) external view returns (PaymentLib.ServiceEscrow memory);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for getServiceEscrowCall
impl Clone for getServiceEscrowCall
Sourcefn clone(&self) -> getServiceEscrowCall
fn clone(&self) -> getServiceEscrowCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getServiceEscrowCall
impl Debug for getServiceEscrowCall
Sourceimpl Default for getServiceEscrowCall
impl Default for getServiceEscrowCall
Sourcefn default() -> getServiceEscrowCall
fn default() -> getServiceEscrowCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceEscrowCall
impl<'de> Deserialize<'de> for getServiceEscrowCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceEscrowCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceEscrowCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getServiceEscrowCall
impl Hash for getServiceEscrowCall
Sourceimpl PartialEq for getServiceEscrowCall
impl PartialEq for getServiceEscrowCall
Sourceimpl Serialize for getServiceEscrowCall
impl Serialize for getServiceEscrowCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getServiceEscrowCall
impl SolCall for getServiceEscrowCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getServiceEscrowCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getServiceEscrowCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (ServiceEscrow,)
type ReturnTuple<'a> = (ServiceEscrow,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getServiceEscrowCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getServiceEscrowCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getServiceEscrowCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getServiceEscrowCall
fn new<'a>( tuple: <<getServiceEscrowCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getServiceEscrowCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getServiceEscrowCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getServiceEscrowCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getServiceEscrowCall as SolCall>::Return,
) -> <getServiceEscrowCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getServiceEscrowCall as SolCall>::Return, ) -> <getServiceEscrowCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getServiceEscrowCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getServiceEscrowCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getServiceEscrowCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getServiceEscrowCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getServiceEscrowCall
impl StructuralPartialEq for getServiceEscrowCall