pub struct getServiceOperatorsReturn {
pub _0: Vec<Address>,
}Expand description
Container type for the return parameters of the getServiceOperators(uint64) function.
Fields
_0: Vec<Address>Trait Implementations
Sourceimpl Clone for getServiceOperatorsReturn
impl Clone for getServiceOperatorsReturn
Sourcefn clone(&self) -> getServiceOperatorsReturn
fn clone(&self) -> getServiceOperatorsReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getServiceOperatorsReturn
impl Debug for getServiceOperatorsReturn
Sourceimpl Default for getServiceOperatorsReturn
impl Default for getServiceOperatorsReturn
Sourcefn default() -> getServiceOperatorsReturn
fn default() -> getServiceOperatorsReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceOperatorsReturn
impl<'de> Deserialize<'de> for getServiceOperatorsReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceOperatorsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceOperatorsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getServiceOperatorsReturn
Sourceimpl Hash for getServiceOperatorsReturn
impl Hash for getServiceOperatorsReturn
Sourceimpl PartialEq for getServiceOperatorsReturn
impl PartialEq for getServiceOperatorsReturn
Sourcefn eq(&self, other: &getServiceOperatorsReturn) -> bool
fn eq(&self, other: &getServiceOperatorsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getServiceOperatorsReturn
impl Serialize for getServiceOperatorsReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getServiceOperatorsReturn