pub struct getServicePaymentAssetCall {
pub serviceId: u64,
}Expand description
Function with signature getServicePaymentAsset(uint64) and selector 0xfc99b3d3.
function getServicePaymentAsset(uint64 serviceId) external view returns (address);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for getServicePaymentAssetCall
impl Clone for getServicePaymentAssetCall
Sourcefn clone(&self) -> getServicePaymentAssetCall
fn clone(&self) -> getServicePaymentAssetCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getServicePaymentAssetCall
impl Debug for getServicePaymentAssetCall
Sourceimpl Default for getServicePaymentAssetCall
impl Default for getServicePaymentAssetCall
Sourcefn default() -> getServicePaymentAssetCall
fn default() -> getServicePaymentAssetCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServicePaymentAssetCall
impl<'de> Deserialize<'de> for getServicePaymentAssetCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServicePaymentAssetCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServicePaymentAssetCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getServicePaymentAssetCall
Sourceimpl Hash for getServicePaymentAssetCall
impl Hash for getServicePaymentAssetCall
Sourceimpl Serialize for getServicePaymentAssetCall
impl Serialize for getServicePaymentAssetCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getServicePaymentAssetCall
impl SolCall for getServicePaymentAssetCall
Sourceconst SIGNATURE: &'static str = "getServicePaymentAsset(uint64)"
const SIGNATURE: &'static str = "getServicePaymentAsset(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getServicePaymentAssetCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getServicePaymentAssetCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Address,)
type ReturnTuple<'a> = (Address,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getServicePaymentAssetCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getServicePaymentAssetCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getServicePaymentAssetCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getServicePaymentAssetCall
fn new<'a>( tuple: <<getServicePaymentAssetCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getServicePaymentAssetCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getServicePaymentAssetCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getServicePaymentAssetCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getServicePaymentAssetCall as SolCall>::Return,
) -> <getServicePaymentAssetCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getServicePaymentAssetCall as SolCall>::Return, ) -> <getServicePaymentAssetCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getServicePaymentAssetCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getServicePaymentAssetCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getServicePaymentAssetCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getServicePaymentAssetCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for getServicePaymentAssetCall