pub struct getServiceRequestResourceRequirementsCall {
pub requestId: u64,
}Expand description
Function with signature getServiceRequestResourceRequirements(uint64) and selector 0xa305fb44.
function getServiceRequestResourceRequirements(uint64 requestId) external view returns (Types.ResourceCommitment[] memory);Fields
requestId: u64Trait Implementations
Sourceimpl Clone for getServiceRequestResourceRequirementsCall
impl Clone for getServiceRequestResourceRequirementsCall
Sourcefn clone(&self) -> getServiceRequestResourceRequirementsCall
fn clone(&self) -> getServiceRequestResourceRequirementsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getServiceRequestResourceRequirementsCall
impl Default for getServiceRequestResourceRequirementsCall
Sourcefn default() -> getServiceRequestResourceRequirementsCall
fn default() -> getServiceRequestResourceRequirementsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceRequestResourceRequirementsCall
impl<'de> Deserialize<'de> for getServiceRequestResourceRequirementsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceRequestResourceRequirementsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceRequestResourceRequirementsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getServiceRequestResourceRequirementsCall
impl PartialEq for getServiceRequestResourceRequirementsCall
Sourcefn eq(&self, other: &getServiceRequestResourceRequirementsCall) -> bool
fn eq(&self, other: &getServiceRequestResourceRequirementsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getServiceRequestResourceRequirementsCall
impl Serialize for getServiceRequestResourceRequirementsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getServiceRequestResourceRequirementsCall
impl SolCall for getServiceRequestResourceRequirementsCall
Sourceconst SIGNATURE: &'static str = "getServiceRequestResourceRequirements(uint64)"
const SIGNATURE: &'static str = "getServiceRequestResourceRequirements(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getServiceRequestResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getServiceRequestResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<ResourceCommitment>,)
type ReturnTuple<'a> = (Array<ResourceCommitment>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getServiceRequestResourceRequirementsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getServiceRequestResourceRequirementsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getServiceRequestResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getServiceRequestResourceRequirementsCall
fn new<'a>( tuple: <<getServiceRequestResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getServiceRequestResourceRequirementsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(
&self,
) -> <getServiceRequestResourceRequirementsCall as SolCall>::Token<'_>
fn tokenize( &self, ) -> <getServiceRequestResourceRequirementsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getServiceRequestResourceRequirementsCall as SolCall>::Return,
) -> <getServiceRequestResourceRequirementsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getServiceRequestResourceRequirementsCall as SolCall>::Return, ) -> <getServiceRequestResourceRequirementsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getServiceRequestResourceRequirementsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getServiceRequestResourceRequirementsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getServiceRequestResourceRequirementsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getServiceRequestResourceRequirementsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getServiceRequestResourceRequirementsCall
impl StructuralPartialEq for getServiceRequestResourceRequirementsCall