pub struct getServiceRequestResourceRequirementsReturn {
pub _0: Vec<<ResourceCommitment as SolType>::RustType>,
}Expand description
Container type for the return parameters of the getServiceRequestResourceRequirements(uint64) function.
Fields
_0: Vec<<ResourceCommitment as SolType>::RustType>Trait Implementations
Sourceimpl Clone for getServiceRequestResourceRequirementsReturn
impl Clone for getServiceRequestResourceRequirementsReturn
Sourcefn clone(&self) -> getServiceRequestResourceRequirementsReturn
fn clone(&self) -> getServiceRequestResourceRequirementsReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getServiceRequestResourceRequirementsReturn
impl Default for getServiceRequestResourceRequirementsReturn
Sourcefn default() -> getServiceRequestResourceRequirementsReturn
fn default() -> getServiceRequestResourceRequirementsReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceRequestResourceRequirementsReturn
impl<'de> Deserialize<'de> for getServiceRequestResourceRequirementsReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceRequestResourceRequirementsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceRequestResourceRequirementsReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getServiceRequestResourceRequirementsReturn
Sourceimpl PartialEq for getServiceRequestResourceRequirementsReturn
impl PartialEq for getServiceRequestResourceRequirementsReturn
Sourcefn eq(&self, other: &getServiceRequestResourceRequirementsReturn) -> bool
fn eq(&self, other: &getServiceRequestResourceRequirementsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getServiceRequestResourceRequirementsReturn
impl Serialize for getServiceRequestResourceRequirementsReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getServiceRequestResourceRequirementsReturn