pub struct getServiceRequestSecurityCommitmentsCall {
pub requestId: u64,
pub operator: Address,
}Expand description
Function with signature getServiceRequestSecurityCommitments(uint64,address) and selector 0x05bb3aa3.
function getServiceRequestSecurityCommitments(uint64 requestId, address operator) external view returns (Types.AssetSecurityCommitment[] memory);Fields
requestId: u64operator: AddressTrait Implementations
Sourceimpl Clone for getServiceRequestSecurityCommitmentsCall
impl Clone for getServiceRequestSecurityCommitmentsCall
Sourcefn clone(&self) -> getServiceRequestSecurityCommitmentsCall
fn clone(&self) -> getServiceRequestSecurityCommitmentsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getServiceRequestSecurityCommitmentsCall
impl Default for getServiceRequestSecurityCommitmentsCall
Sourcefn default() -> getServiceRequestSecurityCommitmentsCall
fn default() -> getServiceRequestSecurityCommitmentsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceRequestSecurityCommitmentsCall
impl<'de> Deserialize<'de> for getServiceRequestSecurityCommitmentsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceRequestSecurityCommitmentsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceRequestSecurityCommitmentsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getServiceRequestSecurityCommitmentsCall
impl PartialEq for getServiceRequestSecurityCommitmentsCall
Sourcefn eq(&self, other: &getServiceRequestSecurityCommitmentsCall) -> bool
fn eq(&self, other: &getServiceRequestSecurityCommitmentsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getServiceRequestSecurityCommitmentsCall
impl Serialize for getServiceRequestSecurityCommitmentsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getServiceRequestSecurityCommitmentsCall
impl SolCall for getServiceRequestSecurityCommitmentsCall
Sourceconst SIGNATURE: &'static str = "getServiceRequestSecurityCommitments(uint64,address)"
const SIGNATURE: &'static str = "getServiceRequestSecurityCommitments(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getServiceRequestSecurityCommitmentsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getServiceRequestSecurityCommitmentsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = Vec<<AssetSecurityCommitment as SolType>::RustType>
type Return = Vec<<AssetSecurityCommitment as SolType>::RustType>
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Array<AssetSecurityCommitment>,)
type ReturnTuple<'a> = (Array<AssetSecurityCommitment>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getServiceRequestSecurityCommitmentsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getServiceRequestSecurityCommitmentsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getServiceRequestSecurityCommitmentsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getServiceRequestSecurityCommitmentsCall
fn new<'a>( tuple: <<getServiceRequestSecurityCommitmentsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getServiceRequestSecurityCommitmentsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(
&self,
) -> <getServiceRequestSecurityCommitmentsCall as SolCall>::Token<'_>
fn tokenize( &self, ) -> <getServiceRequestSecurityCommitmentsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getServiceRequestSecurityCommitmentsCall as SolCall>::Return,
) -> <getServiceRequestSecurityCommitmentsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getServiceRequestSecurityCommitmentsCall as SolCall>::Return, ) -> <getServiceRequestSecurityCommitmentsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getServiceRequestSecurityCommitmentsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getServiceRequestSecurityCommitmentsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getServiceRequestSecurityCommitmentsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getServiceRequestSecurityCommitmentsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getServiceRequestSecurityCommitmentsCall
impl StructuralPartialEq for getServiceRequestSecurityCommitmentsCall