pub struct getServiceSecurityRequirementsCall {
pub serviceId: u64,
}Expand description
Function with signature getServiceSecurityRequirements(uint64) and selector 0xd8644e52.
function getServiceSecurityRequirements(uint64 serviceId) external view returns (Types.AssetSecurityRequirement[] memory);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for getServiceSecurityRequirementsCall
impl Clone for getServiceSecurityRequirementsCall
Sourcefn clone(&self) -> getServiceSecurityRequirementsCall
fn clone(&self) -> getServiceSecurityRequirementsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getServiceSecurityRequirementsCall
impl Default for getServiceSecurityRequirementsCall
Sourcefn default() -> getServiceSecurityRequirementsCall
fn default() -> getServiceSecurityRequirementsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceSecurityRequirementsCall
impl<'de> Deserialize<'de> for getServiceSecurityRequirementsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceSecurityRequirementsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceSecurityRequirementsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getServiceSecurityRequirementsCall
impl PartialEq for getServiceSecurityRequirementsCall
Sourcefn eq(&self, other: &getServiceSecurityRequirementsCall) -> bool
fn eq(&self, other: &getServiceSecurityRequirementsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getServiceSecurityRequirementsCall
impl Serialize for getServiceSecurityRequirementsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getServiceSecurityRequirementsCall
impl SolCall for getServiceSecurityRequirementsCall
Sourceconst SIGNATURE: &'static str = "getServiceSecurityRequirements(uint64)"
const SIGNATURE: &'static str = "getServiceSecurityRequirements(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getServiceSecurityRequirementsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getServiceSecurityRequirementsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = Vec<<AssetSecurityRequirement as SolType>::RustType>
type Return = Vec<<AssetSecurityRequirement as SolType>::RustType>
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Array<AssetSecurityRequirement>,)
type ReturnTuple<'a> = (Array<AssetSecurityRequirement>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getServiceSecurityRequirementsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getServiceSecurityRequirementsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getServiceSecurityRequirementsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getServiceSecurityRequirementsCall
fn new<'a>( tuple: <<getServiceSecurityRequirementsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getServiceSecurityRequirementsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getServiceSecurityRequirementsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getServiceSecurityRequirementsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getServiceSecurityRequirementsCall as SolCall>::Return,
) -> <getServiceSecurityRequirementsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getServiceSecurityRequirementsCall as SolCall>::Return, ) -> <getServiceSecurityRequirementsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getServiceSecurityRequirementsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getServiceSecurityRequirementsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getServiceSecurityRequirementsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getServiceSecurityRequirementsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getServiceSecurityRequirementsCall
impl StructuralPartialEq for getServiceSecurityRequirementsCall