pub struct isOperatorRegisteredCall {
pub blueprintId: u64,
pub operator: Address,
}Expand description
Function with signature isOperatorRegistered(uint64,address) and selector 0x64462595.
function isOperatorRegistered(uint64 blueprintId, address operator) external view returns (bool);Fields
blueprintId: u64operator: AddressTrait Implementations
Sourceimpl Clone for isOperatorRegisteredCall
impl Clone for isOperatorRegisteredCall
Sourcefn clone(&self) -> isOperatorRegisteredCall
fn clone(&self) -> isOperatorRegisteredCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isOperatorRegisteredCall
impl Debug for isOperatorRegisteredCall
Sourceimpl Default for isOperatorRegisteredCall
impl Default for isOperatorRegisteredCall
Sourcefn default() -> isOperatorRegisteredCall
fn default() -> isOperatorRegisteredCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isOperatorRegisteredCall
impl<'de> Deserialize<'de> for isOperatorRegisteredCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isOperatorRegisteredCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isOperatorRegisteredCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for isOperatorRegisteredCall
Sourceimpl Hash for isOperatorRegisteredCall
impl Hash for isOperatorRegisteredCall
Sourceimpl PartialEq for isOperatorRegisteredCall
impl PartialEq for isOperatorRegisteredCall
Sourcefn eq(&self, other: &isOperatorRegisteredCall) -> bool
fn eq(&self, other: &isOperatorRegisteredCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for isOperatorRegisteredCall
impl Serialize for isOperatorRegisteredCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for isOperatorRegisteredCall
impl SolCall for isOperatorRegisteredCall
Sourceconst SIGNATURE: &'static str = "isOperatorRegistered(uint64,address)"
const SIGNATURE: &'static str = "isOperatorRegistered(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<isOperatorRegisteredCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<isOperatorRegisteredCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<isOperatorRegisteredCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<isOperatorRegisteredCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<isOperatorRegisteredCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> isOperatorRegisteredCall
fn new<'a>( tuple: <<isOperatorRegisteredCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> isOperatorRegisteredCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <isOperatorRegisteredCall as SolCall>::Token<'_>
fn tokenize(&self) -> <isOperatorRegisteredCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<isOperatorRegisteredCall as SolCall>::Return,
) -> <isOperatorRegisteredCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<isOperatorRegisteredCall as SolCall>::Return, ) -> <isOperatorRegisteredCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<isOperatorRegisteredCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<isOperatorRegisteredCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<isOperatorRegisteredCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<isOperatorRegisteredCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for isOperatorRegisteredCall