pub struct isOperatorRegisteredReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the isOperatorRegistered(uint64,address) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for isOperatorRegisteredReturn
impl Clone for isOperatorRegisteredReturn
Sourcefn clone(&self) -> isOperatorRegisteredReturn
fn clone(&self) -> isOperatorRegisteredReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isOperatorRegisteredReturn
impl Debug for isOperatorRegisteredReturn
Sourceimpl Default for isOperatorRegisteredReturn
impl Default for isOperatorRegisteredReturn
Sourcefn default() -> isOperatorRegisteredReturn
fn default() -> isOperatorRegisteredReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isOperatorRegisteredReturn
impl<'de> Deserialize<'de> for isOperatorRegisteredReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isOperatorRegisteredReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isOperatorRegisteredReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for isOperatorRegisteredReturn
Sourceimpl Hash for isOperatorRegisteredReturn
impl Hash for isOperatorRegisteredReturn
Sourceimpl PartialEq for isOperatorRegisteredReturn
impl PartialEq for isOperatorRegisteredReturn
Sourcefn eq(&self, other: &isOperatorRegisteredReturn) -> bool
fn eq(&self, other: &isOperatorRegisteredReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for isOperatorRegisteredReturn
impl Serialize for isOperatorRegisteredReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for isOperatorRegisteredReturn