pub struct isPermittedCallerCall {
pub serviceId: u64,
pub caller: Address,
}Expand description
Function with signature isPermittedCaller(uint64,address) and selector 0x2ec2bd03.
function isPermittedCaller(uint64 serviceId, address caller) external view returns (bool);Fields
serviceId: u64caller: AddressTrait Implementations
Sourceimpl Clone for isPermittedCallerCall
impl Clone for isPermittedCallerCall
Sourcefn clone(&self) -> isPermittedCallerCall
fn clone(&self) -> isPermittedCallerCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isPermittedCallerCall
impl Debug for isPermittedCallerCall
Sourceimpl Default for isPermittedCallerCall
impl Default for isPermittedCallerCall
Sourcefn default() -> isPermittedCallerCall
fn default() -> isPermittedCallerCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isPermittedCallerCall
impl<'de> Deserialize<'de> for isPermittedCallerCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isPermittedCallerCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isPermittedCallerCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for isPermittedCallerCall
impl Hash for isPermittedCallerCall
Sourceimpl PartialEq for isPermittedCallerCall
impl PartialEq for isPermittedCallerCall
Sourceimpl Serialize for isPermittedCallerCall
impl Serialize for isPermittedCallerCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for isPermittedCallerCall
impl SolCall for isPermittedCallerCall
Sourceconst SIGNATURE: &'static str = "isPermittedCaller(uint64,address)"
const SIGNATURE: &'static str = "isPermittedCaller(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<isPermittedCallerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<isPermittedCallerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<isPermittedCallerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<isPermittedCallerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<isPermittedCallerCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> isPermittedCallerCall
fn new<'a>( tuple: <<isPermittedCallerCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> isPermittedCallerCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <isPermittedCallerCall as SolCall>::Token<'_>
fn tokenize(&self) -> <isPermittedCallerCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<isPermittedCallerCall as SolCall>::Return,
) -> <isPermittedCallerCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<isPermittedCallerCall as SolCall>::Return, ) -> <isPermittedCallerCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<isPermittedCallerCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<isPermittedCallerCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<isPermittedCallerCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<isPermittedCallerCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for isPermittedCallerCall
impl StructuralPartialEq for isPermittedCallerCall