pub struct isPermittedCallerReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the isPermittedCaller(uint64,address) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for isPermittedCallerReturn
impl Clone for isPermittedCallerReturn
Sourcefn clone(&self) -> isPermittedCallerReturn
fn clone(&self) -> isPermittedCallerReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isPermittedCallerReturn
impl Debug for isPermittedCallerReturn
Sourceimpl Default for isPermittedCallerReturn
impl Default for isPermittedCallerReturn
Sourcefn default() -> isPermittedCallerReturn
fn default() -> isPermittedCallerReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isPermittedCallerReturn
impl<'de> Deserialize<'de> for isPermittedCallerReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isPermittedCallerReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isPermittedCallerReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for isPermittedCallerReturn
Sourceimpl Hash for isPermittedCallerReturn
impl Hash for isPermittedCallerReturn
Sourceimpl PartialEq for isPermittedCallerReturn
impl PartialEq for isPermittedCallerReturn
Sourcefn eq(&self, other: &isPermittedCallerReturn) -> bool
fn eq(&self, other: &isPermittedCallerReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for isPermittedCallerReturn
impl Serialize for isPermittedCallerReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for isPermittedCallerReturn