pub struct isServiceActiveCall {
pub serviceId: u64,
}Expand description
Function with signature isServiceActive(uint64) and selector 0x2f46279f.
function isServiceActive(uint64 serviceId) external view returns (bool);Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for isServiceActiveCall
impl Clone for isServiceActiveCall
Sourcefn clone(&self) -> isServiceActiveCall
fn clone(&self) -> isServiceActiveCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isServiceActiveCall
impl Debug for isServiceActiveCall
Sourceimpl Default for isServiceActiveCall
impl Default for isServiceActiveCall
Sourcefn default() -> isServiceActiveCall
fn default() -> isServiceActiveCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isServiceActiveCall
impl<'de> Deserialize<'de> for isServiceActiveCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isServiceActiveCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isServiceActiveCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for isServiceActiveCall
impl Hash for isServiceActiveCall
Sourceimpl PartialEq for isServiceActiveCall
impl PartialEq for isServiceActiveCall
Sourceimpl Serialize for isServiceActiveCall
impl Serialize for isServiceActiveCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for isServiceActiveCall
impl SolCall for isServiceActiveCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<isServiceActiveCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<isServiceActiveCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<isServiceActiveCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<isServiceActiveCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<isServiceActiveCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> isServiceActiveCall
fn new<'a>( tuple: <<isServiceActiveCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> isServiceActiveCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <isServiceActiveCall as SolCall>::Token<'_>
fn tokenize(&self) -> <isServiceActiveCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<isServiceActiveCall as SolCall>::Return,
) -> <isServiceActiveCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<isServiceActiveCall as SolCall>::Return, ) -> <isServiceActiveCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<isServiceActiveCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<isServiceActiveCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<isServiceActiveCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<isServiceActiveCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for isServiceActiveCall
impl StructuralPartialEq for isServiceActiveCall