pub struct joinServiceCall {
pub serviceId: u64,
pub exposureBps: u16,
}Expand description
Function with signature joinService(uint64,uint16) and selector 0x2b9da71a.
function joinService(uint64 serviceId, uint16 exposureBps) external;Fields
serviceId: u64exposureBps: u16Trait Implementations
Sourceimpl Clone for joinServiceCall
impl Clone for joinServiceCall
Sourcefn clone(&self) -> joinServiceCall
fn clone(&self) -> joinServiceCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for joinServiceCall
impl Debug for joinServiceCall
Sourceimpl Default for joinServiceCall
impl Default for joinServiceCall
Sourcefn default() -> joinServiceCall
fn default() -> joinServiceCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for joinServiceCall
impl<'de> Deserialize<'de> for joinServiceCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<joinServiceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<joinServiceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for joinServiceCall
impl Hash for joinServiceCall
Sourceimpl PartialEq for joinServiceCall
impl PartialEq for joinServiceCall
Sourceimpl Serialize for joinServiceCall
impl Serialize for joinServiceCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for joinServiceCall
impl SolCall for joinServiceCall
Sourcetype Parameters<'a> = (Uint<64>, Uint<16>)
type Parameters<'a> = (Uint<64>, Uint<16>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<joinServiceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<joinServiceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = joinServiceReturn
type Return = joinServiceReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<joinServiceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<joinServiceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<joinServiceCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> joinServiceCall
fn new<'a>( tuple: <<joinServiceCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> joinServiceCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<joinServiceCall as SolCall>::Return,
) -> <joinServiceCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<joinServiceCall as SolCall>::Return, ) -> <joinServiceCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<joinServiceCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<joinServiceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<joinServiceCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<joinServiceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for joinServiceCall
impl StructuralPartialEq for joinServiceCall