pub struct joinServiceWithCommitmentsCall {
pub serviceId: u64,
pub exposureBps: u16,
pub commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>,
}Expand description
Function with signature joinServiceWithCommitments(uint64,uint16,((uint8,address),uint16)[]) and selector 0xd563701f.
function joinServiceWithCommitments(uint64 serviceId, uint16 exposureBps, Types.AssetSecurityCommitment[] memory commitments) external;Fields
serviceId: u64exposureBps: u16commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>Trait Implementations
Sourceimpl Clone for joinServiceWithCommitmentsCall
impl Clone for joinServiceWithCommitmentsCall
Sourcefn clone(&self) -> joinServiceWithCommitmentsCall
fn clone(&self) -> joinServiceWithCommitmentsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for joinServiceWithCommitmentsCall
impl<'de> Deserialize<'de> for joinServiceWithCommitmentsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<joinServiceWithCommitmentsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<joinServiceWithCommitmentsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for joinServiceWithCommitmentsCall
impl Serialize for joinServiceWithCommitmentsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for joinServiceWithCommitmentsCall
impl SolCall for joinServiceWithCommitmentsCall
Sourceconst SIGNATURE: &'static str = "joinServiceWithCommitments(uint64,uint16,((uint8,address),uint16)[])"
const SIGNATURE: &'static str = "joinServiceWithCommitments(uint64,uint16,((uint8,address),uint16)[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<16>, Array<AssetSecurityCommitment>)
type Parameters<'a> = (Uint<64>, Uint<16>, Array<AssetSecurityCommitment>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<joinServiceWithCommitmentsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<joinServiceWithCommitmentsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = joinServiceWithCommitmentsReturn
type Return = joinServiceWithCommitmentsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<joinServiceWithCommitmentsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<joinServiceWithCommitmentsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<joinServiceWithCommitmentsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> joinServiceWithCommitmentsCall
fn new<'a>( tuple: <<joinServiceWithCommitmentsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> joinServiceWithCommitmentsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <joinServiceWithCommitmentsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <joinServiceWithCommitmentsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<joinServiceWithCommitmentsCall as SolCall>::Return,
) -> <joinServiceWithCommitmentsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<joinServiceWithCommitmentsCall as SolCall>::Return, ) -> <joinServiceWithCommitmentsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<joinServiceWithCommitmentsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<joinServiceWithCommitmentsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<joinServiceWithCommitmentsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<joinServiceWithCommitmentsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.