pub struct leaveServiceCall {
pub serviceId: u64,
}Expand description
Function with signature leaveService(uint64) and selector 0x6778afbc.
function leaveService(uint64 serviceId) external;Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for leaveServiceCall
impl Clone for leaveServiceCall
Sourcefn clone(&self) -> leaveServiceCall
fn clone(&self) -> leaveServiceCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for leaveServiceCall
impl Debug for leaveServiceCall
Sourceimpl Default for leaveServiceCall
impl Default for leaveServiceCall
Sourcefn default() -> leaveServiceCall
fn default() -> leaveServiceCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for leaveServiceCall
impl<'de> Deserialize<'de> for leaveServiceCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<leaveServiceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<leaveServiceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for leaveServiceCall
impl Hash for leaveServiceCall
Sourceimpl PartialEq for leaveServiceCall
impl PartialEq for leaveServiceCall
Sourceimpl Serialize for leaveServiceCall
impl Serialize for leaveServiceCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for leaveServiceCall
impl SolCall for leaveServiceCall
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<leaveServiceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<leaveServiceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = leaveServiceReturn
type Return = leaveServiceReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<leaveServiceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<leaveServiceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<leaveServiceCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> leaveServiceCall
fn new<'a>( tuple: <<leaveServiceCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> leaveServiceCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<leaveServiceCall as SolCall>::Return,
) -> <leaveServiceCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<leaveServiceCall as SolCall>::Return, ) -> <leaveServiceCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<leaveServiceCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<leaveServiceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<leaveServiceCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<leaveServiceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for leaveServiceCall
impl StructuralPartialEq for leaveServiceCall