pub struct pendingRewards_0Return {
pub _0: Uint<256, 4>,
}Expand description
Container type for the return parameters of the pendingRewards(address) function.
Fields
_0: Uint<256, 4>Trait Implementations
Sourceimpl Clone for pendingRewards_0Return
impl Clone for pendingRewards_0Return
Sourcefn clone(&self) -> pendingRewards_0Return
fn clone(&self) -> pendingRewards_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for pendingRewards_0Return
impl Debug for pendingRewards_0Return
Sourceimpl Default for pendingRewards_0Return
impl Default for pendingRewards_0Return
Sourcefn default() -> pendingRewards_0Return
fn default() -> pendingRewards_0Return
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for pendingRewards_0Return
impl<'de> Deserialize<'de> for pendingRewards_0Return
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<pendingRewards_0Return, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<pendingRewards_0Return, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for pendingRewards_0Return
Sourceimpl Hash for pendingRewards_0Return
impl Hash for pendingRewards_0Return
Sourceimpl PartialEq for pendingRewards_0Return
impl PartialEq for pendingRewards_0Return
Sourcefn eq(&self, other: &pendingRewards_0Return) -> bool
fn eq(&self, other: &pendingRewards_0Return) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for pendingRewards_0Return
impl Serialize for pendingRewards_0Return
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for pendingRewards_0Return