pub struct removePermittedCallerCall {
pub serviceId: u64,
pub caller: Address,
}Expand description
Function with signature removePermittedCaller(uint64,address) and selector 0x5f359924.
function removePermittedCaller(uint64 serviceId, address caller) external;Fields
serviceId: u64caller: AddressTrait Implementations
Sourceimpl Clone for removePermittedCallerCall
impl Clone for removePermittedCallerCall
Sourcefn clone(&self) -> removePermittedCallerCall
fn clone(&self) -> removePermittedCallerCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for removePermittedCallerCall
impl Debug for removePermittedCallerCall
Sourceimpl Default for removePermittedCallerCall
impl Default for removePermittedCallerCall
Sourcefn default() -> removePermittedCallerCall
fn default() -> removePermittedCallerCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for removePermittedCallerCall
impl<'de> Deserialize<'de> for removePermittedCallerCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<removePermittedCallerCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<removePermittedCallerCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for removePermittedCallerCall
impl Hash for removePermittedCallerCall
Sourceimpl Serialize for removePermittedCallerCall
impl Serialize for removePermittedCallerCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for removePermittedCallerCall
impl SolCall for removePermittedCallerCall
Sourceconst SIGNATURE: &'static str = "removePermittedCaller(uint64,address)"
const SIGNATURE: &'static str = "removePermittedCaller(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<removePermittedCallerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<removePermittedCallerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = removePermittedCallerReturn
type Return = removePermittedCallerReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<removePermittedCallerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<removePermittedCallerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<removePermittedCallerCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> removePermittedCallerCall
fn new<'a>( tuple: <<removePermittedCallerCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> removePermittedCallerCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <removePermittedCallerCall as SolCall>::Token<'_>
fn tokenize(&self) -> <removePermittedCallerCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<removePermittedCallerCall as SolCall>::Return,
) -> <removePermittedCallerCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<removePermittedCallerCall as SolCall>::Return, ) -> <removePermittedCallerCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<removePermittedCallerCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<removePermittedCallerCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<removePermittedCallerCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<removePermittedCallerCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for removePermittedCallerCall
impl StructuralPartialEq for removePermittedCallerCall