pub struct requestServiceReturn {
pub requestId: u64,
}Expand description
Container type for the return parameters of the requestService(uint64,address[],bytes,address[],uint64,address,uint256,uint8) function.
Fields
requestId: u64Trait Implementations
Sourceimpl Clone for requestServiceReturn
impl Clone for requestServiceReturn
Sourcefn clone(&self) -> requestServiceReturn
fn clone(&self) -> requestServiceReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for requestServiceReturn
impl Debug for requestServiceReturn
Sourceimpl Default for requestServiceReturn
impl Default for requestServiceReturn
Sourcefn default() -> requestServiceReturn
fn default() -> requestServiceReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for requestServiceReturn
impl<'de> Deserialize<'de> for requestServiceReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for requestServiceReturn
Sourceimpl Hash for requestServiceReturn
impl Hash for requestServiceReturn
Sourceimpl PartialEq for requestServiceReturn
impl PartialEq for requestServiceReturn
Sourcefn eq(&self, other: &requestServiceReturn) -> bool
fn eq(&self, other: &requestServiceReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for requestServiceReturn
impl Serialize for requestServiceReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for requestServiceReturn