pub struct requestServiceWithExposureCall {
pub blueprintId: u64,
pub operators: Vec<Address>,
pub exposureBps: Vec<u16>,
pub config: Bytes,
pub permittedCallers: Vec<Address>,
pub ttl: u64,
pub paymentToken: Address,
pub paymentAmount: Uint<256, 4>,
pub confidentiality: <ConfidentialityPolicy as SolType>::RustType,
}Expand description
Function with signature requestServiceWithExposure(uint64,address[],uint16[],bytes,address[],uint64,address,uint256,uint8) and selector 0x327d6898.
function requestServiceWithExposure(uint64 blueprintId, address[] memory operators, uint16[] memory exposureBps, bytes memory config, address[] memory permittedCallers, uint64 ttl, address paymentToken, uint256 paymentAmount, Types.ConfidentialityPolicy confidentiality) external payable returns (uint64 requestId);Fields
blueprintId: u64operators: Vec<Address>exposureBps: Vec<u16>config: BytespermittedCallers: Vec<Address>ttl: u64paymentToken: AddresspaymentAmount: Uint<256, 4>confidentiality: <ConfidentialityPolicy as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for requestServiceWithExposureCall
impl Clone for requestServiceWithExposureCall
Sourcefn clone(&self) -> requestServiceWithExposureCall
fn clone(&self) -> requestServiceWithExposureCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for requestServiceWithExposureCall
impl Default for requestServiceWithExposureCall
Sourcefn default() -> requestServiceWithExposureCall
fn default() -> requestServiceWithExposureCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for requestServiceWithExposureCall
impl<'de> Deserialize<'de> for requestServiceWithExposureCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceWithExposureCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceWithExposureCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for requestServiceWithExposureCall
impl PartialEq for requestServiceWithExposureCall
Sourcefn eq(&self, other: &requestServiceWithExposureCall) -> bool
fn eq(&self, other: &requestServiceWithExposureCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for requestServiceWithExposureCall
impl Serialize for requestServiceWithExposureCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for requestServiceWithExposureCall
impl SolCall for requestServiceWithExposureCall
Sourceconst SIGNATURE: &'static str = "requestServiceWithExposure(uint64,address[],uint16[],bytes,address[],uint64,address,uint256,uint8)"
const SIGNATURE: &'static str = "requestServiceWithExposure(uint64,address[],uint16[],bytes,address[],uint64,address,uint256,uint8)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Array<Address>, Array<Uint<16>>, Bytes, Array<Address>, Uint<64>, Address, Uint<256>, ConfidentialityPolicy)
type Parameters<'a> = (Uint<64>, Array<Address>, Array<Uint<16>>, Bytes, Array<Address>, Uint<64>, Address, Uint<256>, ConfidentialityPolicy)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<requestServiceWithExposureCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<requestServiceWithExposureCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<requestServiceWithExposureCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<requestServiceWithExposureCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<requestServiceWithExposureCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> requestServiceWithExposureCall
fn new<'a>( tuple: <<requestServiceWithExposureCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> requestServiceWithExposureCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <requestServiceWithExposureCall as SolCall>::Token<'_>
fn tokenize(&self) -> <requestServiceWithExposureCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<requestServiceWithExposureCall as SolCall>::Return,
) -> <requestServiceWithExposureCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<requestServiceWithExposureCall as SolCall>::Return, ) -> <requestServiceWithExposureCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<requestServiceWithExposureCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<requestServiceWithExposureCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<requestServiceWithExposureCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<requestServiceWithExposureCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for requestServiceWithExposureCall
impl StructuralPartialEq for requestServiceWithExposureCall