pub struct requestServiceWithExposureReturn {
pub requestId: u64,
}Expand description
Container type for the return parameters of the requestServiceWithExposure(uint64,address[],uint16[],bytes,address[],uint64,address,uint256,uint8) function.
Fields
requestId: u64Trait Implementations
Sourceimpl Clone for requestServiceWithExposureReturn
impl Clone for requestServiceWithExposureReturn
Sourcefn clone(&self) -> requestServiceWithExposureReturn
fn clone(&self) -> requestServiceWithExposureReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for requestServiceWithExposureReturn
impl Default for requestServiceWithExposureReturn
Sourcefn default() -> requestServiceWithExposureReturn
fn default() -> requestServiceWithExposureReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for requestServiceWithExposureReturn
impl<'de> Deserialize<'de> for requestServiceWithExposureReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceWithExposureReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceWithExposureReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for requestServiceWithExposureReturn
Sourceimpl PartialEq for requestServiceWithExposureReturn
impl PartialEq for requestServiceWithExposureReturn
Sourcefn eq(&self, other: &requestServiceWithExposureReturn) -> bool
fn eq(&self, other: &requestServiceWithExposureReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for requestServiceWithExposureReturn
impl Serialize for requestServiceWithExposureReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for requestServiceWithExposureReturn