pub struct requestServiceWithSecurityCall {
pub blueprintId: u64,
pub operators: Vec<Address>,
pub securityRequirements: Vec<<AssetSecurityRequirement as SolType>::RustType>,
pub config: Bytes,
pub permittedCallers: Vec<Address>,
pub ttl: u64,
pub paymentToken: Address,
pub paymentAmount: Uint<256, 4>,
pub confidentiality: <ConfidentialityPolicy as SolType>::RustType,
}Expand description
Function with signature requestServiceWithSecurity(uint64,address[],((uint8,address),uint16,uint16)[],bytes,address[],uint64,address,uint256,uint8) and selector 0x4c540ec1.
function requestServiceWithSecurity(uint64 blueprintId, address[] memory operators, Types.AssetSecurityRequirement[] memory securityRequirements, bytes memory config, address[] memory permittedCallers, uint64 ttl, address paymentToken, uint256 paymentAmount, Types.ConfidentialityPolicy confidentiality) external payable returns (uint64 requestId);Fields
blueprintId: u64operators: Vec<Address>securityRequirements: Vec<<AssetSecurityRequirement as SolType>::RustType>config: BytespermittedCallers: Vec<Address>ttl: u64paymentToken: AddresspaymentAmount: Uint<256, 4>confidentiality: <ConfidentialityPolicy as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for requestServiceWithSecurityCall
impl Clone for requestServiceWithSecurityCall
Sourcefn clone(&self) -> requestServiceWithSecurityCall
fn clone(&self) -> requestServiceWithSecurityCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for requestServiceWithSecurityCall
impl<'de> Deserialize<'de> for requestServiceWithSecurityCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceWithSecurityCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceWithSecurityCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for requestServiceWithSecurityCall
impl Serialize for requestServiceWithSecurityCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for requestServiceWithSecurityCall
impl SolCall for requestServiceWithSecurityCall
Sourceconst SIGNATURE: &'static str = "requestServiceWithSecurity(uint64,address[],((uint8,address),uint16,uint16)[],bytes,address[],uint64,address,uint256,uint8)"
const SIGNATURE: &'static str = "requestServiceWithSecurity(uint64,address[],((uint8,address),uint16,uint16)[],bytes,address[],uint64,address,uint256,uint8)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Array<Address>, Array<AssetSecurityRequirement>, Bytes, Array<Address>, Uint<64>, Address, Uint<256>, ConfidentialityPolicy)
type Parameters<'a> = (Uint<64>, Array<Address>, Array<AssetSecurityRequirement>, Bytes, Array<Address>, Uint<64>, Address, Uint<256>, ConfidentialityPolicy)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<requestServiceWithSecurityCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<requestServiceWithSecurityCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<requestServiceWithSecurityCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<requestServiceWithSecurityCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<requestServiceWithSecurityCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> requestServiceWithSecurityCall
fn new<'a>( tuple: <<requestServiceWithSecurityCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> requestServiceWithSecurityCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <requestServiceWithSecurityCall as SolCall>::Token<'_>
fn tokenize(&self) -> <requestServiceWithSecurityCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<requestServiceWithSecurityCall as SolCall>::Return,
) -> <requestServiceWithSecurityCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<requestServiceWithSecurityCall as SolCall>::Return, ) -> <requestServiceWithSecurityCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<requestServiceWithSecurityCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<requestServiceWithSecurityCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<requestServiceWithSecurityCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<requestServiceWithSecurityCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.