pub struct requestServiceWithSecurityReturn {
pub requestId: u64,
}Expand description
Container type for the return parameters of the requestServiceWithSecurity(uint64,address[],((uint8,address),uint16,uint16)[],bytes,address[],uint64,address,uint256,uint8) function.
Fields
requestId: u64Trait Implementations
Sourceimpl Clone for requestServiceWithSecurityReturn
impl Clone for requestServiceWithSecurityReturn
Sourcefn clone(&self) -> requestServiceWithSecurityReturn
fn clone(&self) -> requestServiceWithSecurityReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for requestServiceWithSecurityReturn
impl Default for requestServiceWithSecurityReturn
Sourcefn default() -> requestServiceWithSecurityReturn
fn default() -> requestServiceWithSecurityReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for requestServiceWithSecurityReturn
impl<'de> Deserialize<'de> for requestServiceWithSecurityReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceWithSecurityReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<requestServiceWithSecurityReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for requestServiceWithSecurityReturn
Sourceimpl PartialEq for requestServiceWithSecurityReturn
impl PartialEq for requestServiceWithSecurityReturn
Sourcefn eq(&self, other: &requestServiceWithSecurityReturn) -> bool
fn eq(&self, other: &requestServiceWithSecurityReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for requestServiceWithSecurityReturn
impl Serialize for requestServiceWithSecurityReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for requestServiceWithSecurityReturn