pub struct rewardTokensCall {
pub account: Address,
}Expand description
Function with signature rewardTokens(address) and selector 0xf5ab16cc.
function rewardTokens(address account) external view returns (address[] memory);Fields
account: AddressTrait Implementations
Sourceimpl Clone for rewardTokensCall
impl Clone for rewardTokensCall
Sourcefn clone(&self) -> rewardTokensCall
fn clone(&self) -> rewardTokensCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for rewardTokensCall
impl Debug for rewardTokensCall
Sourceimpl Default for rewardTokensCall
impl Default for rewardTokensCall
Sourcefn default() -> rewardTokensCall
fn default() -> rewardTokensCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for rewardTokensCall
impl<'de> Deserialize<'de> for rewardTokensCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<rewardTokensCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<rewardTokensCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for rewardTokensCall
impl Hash for rewardTokensCall
Sourceimpl PartialEq for rewardTokensCall
impl PartialEq for rewardTokensCall
Sourceimpl Serialize for rewardTokensCall
impl Serialize for rewardTokensCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for rewardTokensCall
impl SolCall for rewardTokensCall
Sourcetype Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<rewardTokensCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<rewardTokensCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<Address>,)
type ReturnTuple<'a> = (Array<Address>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<rewardTokensCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<rewardTokensCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<rewardTokensCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> rewardTokensCall
fn new<'a>( tuple: <<rewardTokensCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> rewardTokensCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<rewardTokensCall as SolCall>::Return,
) -> <rewardTokensCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<rewardTokensCall as SolCall>::Return, ) -> <rewardTokensCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<rewardTokensCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<rewardTokensCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<rewardTokensCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<rewardTokensCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for rewardTokensCall
impl StructuralPartialEq for rewardTokensCall