pub struct rewardTokensReturn {
pub _0: Vec<Address>,
}Expand description
Container type for the return parameters of the rewardTokens(address) function.
Fields
_0: Vec<Address>Trait Implementations
Sourceimpl Clone for rewardTokensReturn
impl Clone for rewardTokensReturn
Sourcefn clone(&self) -> rewardTokensReturn
fn clone(&self) -> rewardTokensReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for rewardTokensReturn
impl Debug for rewardTokensReturn
Sourceimpl Default for rewardTokensReturn
impl Default for rewardTokensReturn
Sourcefn default() -> rewardTokensReturn
fn default() -> rewardTokensReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for rewardTokensReturn
impl<'de> Deserialize<'de> for rewardTokensReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<rewardTokensReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<rewardTokensReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for rewardTokensReturn
Sourceimpl Hash for rewardTokensReturn
impl Hash for rewardTokensReturn
Sourceimpl PartialEq for rewardTokensReturn
impl PartialEq for rewardTokensReturn
Sourcefn eq(&self, other: &rewardTokensReturn) -> bool
fn eq(&self, other: &rewardTokensReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for rewardTokensReturn
impl Serialize for rewardTokensReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for rewardTokensReturn