pub struct serviceCountReturn {
pub _0: u64,
}Expand description
Container type for the return parameters of the serviceCount() function.
Fields
_0: u64Trait Implementations
Sourceimpl Clone for serviceCountReturn
impl Clone for serviceCountReturn
Sourcefn clone(&self) -> serviceCountReturn
fn clone(&self) -> serviceCountReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for serviceCountReturn
impl Debug for serviceCountReturn
Sourceimpl Default for serviceCountReturn
impl Default for serviceCountReturn
Sourcefn default() -> serviceCountReturn
fn default() -> serviceCountReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for serviceCountReturn
impl<'de> Deserialize<'de> for serviceCountReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<serviceCountReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<serviceCountReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for serviceCountReturn
Sourceimpl Hash for serviceCountReturn
impl Hash for serviceCountReturn
Sourceimpl PartialEq for serviceCountReturn
impl PartialEq for serviceCountReturn
Sourcefn eq(&self, other: &serviceCountReturn) -> bool
fn eq(&self, other: &serviceCountReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for serviceCountReturn
impl Serialize for serviceCountReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for serviceCountReturn