pub struct setBlueprintResourceRequirementsCall {
pub blueprintId: u64,
pub requirements: Vec<<ResourceCommitment as SolType>::RustType>,
}Expand description
Function with signature setBlueprintResourceRequirements(uint64,(uint8,uint64)[]) and selector 0xe830bff6.
function setBlueprintResourceRequirements(uint64 blueprintId, Types.ResourceCommitment[] memory requirements) external;Fields
blueprintId: u64requirements: Vec<<ResourceCommitment as SolType>::RustType>Trait Implementations
Sourceimpl Clone for setBlueprintResourceRequirementsCall
impl Clone for setBlueprintResourceRequirementsCall
Sourcefn clone(&self) -> setBlueprintResourceRequirementsCall
fn clone(&self) -> setBlueprintResourceRequirementsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for setBlueprintResourceRequirementsCall
impl Default for setBlueprintResourceRequirementsCall
Sourcefn default() -> setBlueprintResourceRequirementsCall
fn default() -> setBlueprintResourceRequirementsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for setBlueprintResourceRequirementsCall
impl<'de> Deserialize<'de> for setBlueprintResourceRequirementsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<setBlueprintResourceRequirementsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<setBlueprintResourceRequirementsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for setBlueprintResourceRequirementsCall
impl PartialEq for setBlueprintResourceRequirementsCall
Sourcefn eq(&self, other: &setBlueprintResourceRequirementsCall) -> bool
fn eq(&self, other: &setBlueprintResourceRequirementsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for setBlueprintResourceRequirementsCall
impl Serialize for setBlueprintResourceRequirementsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for setBlueprintResourceRequirementsCall
impl SolCall for setBlueprintResourceRequirementsCall
Sourceconst SIGNATURE: &'static str = "setBlueprintResourceRequirements(uint64,(uint8,uint64)[])"
const SIGNATURE: &'static str = "setBlueprintResourceRequirements(uint64,(uint8,uint64)[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Array<ResourceCommitment>)
type Parameters<'a> = (Uint<64>, Array<ResourceCommitment>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<setBlueprintResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<setBlueprintResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = setBlueprintResourceRequirementsReturn
type Return = setBlueprintResourceRequirementsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<setBlueprintResourceRequirementsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<setBlueprintResourceRequirementsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<setBlueprintResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> setBlueprintResourceRequirementsCall
fn new<'a>( tuple: <<setBlueprintResourceRequirementsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> setBlueprintResourceRequirementsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(
&self,
) -> <setBlueprintResourceRequirementsCall as SolCall>::Token<'_>
fn tokenize( &self, ) -> <setBlueprintResourceRequirementsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<setBlueprintResourceRequirementsCall as SolCall>::Return,
) -> <setBlueprintResourceRequirementsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<setBlueprintResourceRequirementsCall as SolCall>::Return, ) -> <setBlueprintResourceRequirementsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<setBlueprintResourceRequirementsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<setBlueprintResourceRequirementsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<setBlueprintResourceRequirementsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<setBlueprintResourceRequirementsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for setBlueprintResourceRequirementsCall
impl StructuralPartialEq for setBlueprintResourceRequirementsCall