pub struct setBlueprintSettlementAssetCall {
pub blueprintId: u64,
pub asset: Address,
}Expand description
Function with signature setBlueprintSettlementAsset(uint64,address) and selector 0x730b595f.
function setBlueprintSettlementAsset(uint64 blueprintId, address asset) external;Fields
blueprintId: u64asset: AddressTrait Implementations
Sourceimpl Clone for setBlueprintSettlementAssetCall
impl Clone for setBlueprintSettlementAssetCall
Sourcefn clone(&self) -> setBlueprintSettlementAssetCall
fn clone(&self) -> setBlueprintSettlementAssetCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for setBlueprintSettlementAssetCall
impl Default for setBlueprintSettlementAssetCall
Sourcefn default() -> setBlueprintSettlementAssetCall
fn default() -> setBlueprintSettlementAssetCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for setBlueprintSettlementAssetCall
impl<'de> Deserialize<'de> for setBlueprintSettlementAssetCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<setBlueprintSettlementAssetCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<setBlueprintSettlementAssetCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for setBlueprintSettlementAssetCall
Sourceimpl Serialize for setBlueprintSettlementAssetCall
impl Serialize for setBlueprintSettlementAssetCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for setBlueprintSettlementAssetCall
impl SolCall for setBlueprintSettlementAssetCall
Sourceconst SIGNATURE: &'static str = "setBlueprintSettlementAsset(uint64,address)"
const SIGNATURE: &'static str = "setBlueprintSettlementAsset(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<setBlueprintSettlementAssetCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<setBlueprintSettlementAssetCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = setBlueprintSettlementAssetReturn
type Return = setBlueprintSettlementAssetReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<setBlueprintSettlementAssetCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<setBlueprintSettlementAssetCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<setBlueprintSettlementAssetCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> setBlueprintSettlementAssetCall
fn new<'a>( tuple: <<setBlueprintSettlementAssetCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> setBlueprintSettlementAssetCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <setBlueprintSettlementAssetCall as SolCall>::Token<'_>
fn tokenize(&self) -> <setBlueprintSettlementAssetCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<setBlueprintSettlementAssetCall as SolCall>::Return,
) -> <setBlueprintSettlementAssetCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<setBlueprintSettlementAssetCall as SolCall>::Return, ) -> <setBlueprintSettlementAssetCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<setBlueprintSettlementAssetCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<setBlueprintSettlementAssetCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<setBlueprintSettlementAssetCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<setBlueprintSettlementAssetCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for setBlueprintSettlementAssetCall