pub struct setJobEventRatesCall {
pub blueprintId: u64,
pub jobIndexes: Vec<u8>,
pub rates: Vec<Uint<256, 4>>,
}Expand description
Function with signature setJobEventRates(uint64,uint8[],uint256[]) and selector 0xc1d71304.
function setJobEventRates(uint64 blueprintId, uint8[] memory jobIndexes, uint256[] memory rates) external;Fields
blueprintId: u64jobIndexes: Vec<u8>rates: Vec<Uint<256, 4>>Trait Implementations
Sourceimpl Clone for setJobEventRatesCall
impl Clone for setJobEventRatesCall
Sourcefn clone(&self) -> setJobEventRatesCall
fn clone(&self) -> setJobEventRatesCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for setJobEventRatesCall
impl Debug for setJobEventRatesCall
Sourceimpl Default for setJobEventRatesCall
impl Default for setJobEventRatesCall
Sourcefn default() -> setJobEventRatesCall
fn default() -> setJobEventRatesCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for setJobEventRatesCall
impl<'de> Deserialize<'de> for setJobEventRatesCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<setJobEventRatesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<setJobEventRatesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for setJobEventRatesCall
impl Hash for setJobEventRatesCall
Sourceimpl PartialEq for setJobEventRatesCall
impl PartialEq for setJobEventRatesCall
Sourceimpl Serialize for setJobEventRatesCall
impl Serialize for setJobEventRatesCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for setJobEventRatesCall
impl SolCall for setJobEventRatesCall
Sourceconst SIGNATURE: &'static str = "setJobEventRates(uint64,uint8[],uint256[])"
const SIGNATURE: &'static str = "setJobEventRates(uint64,uint8[],uint256[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Array<Uint<8>>, Array<Uint<256>>)
type Parameters<'a> = (Uint<64>, Array<Uint<8>>, Array<Uint<256>>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<setJobEventRatesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<setJobEventRatesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = setJobEventRatesReturn
type Return = setJobEventRatesReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<setJobEventRatesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<setJobEventRatesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<setJobEventRatesCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> setJobEventRatesCall
fn new<'a>( tuple: <<setJobEventRatesCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> setJobEventRatesCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <setJobEventRatesCall as SolCall>::Token<'_>
fn tokenize(&self) -> <setJobEventRatesCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<setJobEventRatesCall as SolCall>::Return,
) -> <setJobEventRatesCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<setJobEventRatesCall as SolCall>::Return, ) -> <setJobEventRatesCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<setJobEventRatesCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<setJobEventRatesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<setJobEventRatesCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<setJobEventRatesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for setJobEventRatesCall
impl StructuralPartialEq for setJobEventRatesCall