pub struct submitAggregatedResultCall {
pub serviceId: u64,
pub callId: u64,
pub output: Bytes,
pub signerBitmap: Uint<256, 4>,
pub aggregatedSignature: [Uint<256, 4>; 2],
pub aggregatedPubkey: [Uint<256, 4>; 4],
}Expand description
Function with signature submitAggregatedResult(uint64,uint64,bytes,uint256,uint256[2],uint256[4]) and selector 0xc325ae12.
function submitAggregatedResult(uint64 serviceId, uint64 callId, bytes memory output, uint256 signerBitmap, uint256[2] memory aggregatedSignature, uint256[4] memory aggregatedPubkey) external;Fields
serviceId: u64callId: u64output: BytessignerBitmap: Uint<256, 4>aggregatedSignature: [Uint<256, 4>; 2]aggregatedPubkey: [Uint<256, 4>; 4]Trait Implementations
Sourceimpl Clone for submitAggregatedResultCall
impl Clone for submitAggregatedResultCall
Sourcefn clone(&self) -> submitAggregatedResultCall
fn clone(&self) -> submitAggregatedResultCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for submitAggregatedResultCall
impl Debug for submitAggregatedResultCall
Sourceimpl Default for submitAggregatedResultCall
impl Default for submitAggregatedResultCall
Sourcefn default() -> submitAggregatedResultCall
fn default() -> submitAggregatedResultCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for submitAggregatedResultCall
impl<'de> Deserialize<'de> for submitAggregatedResultCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitAggregatedResultCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitAggregatedResultCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for submitAggregatedResultCall
impl Hash for submitAggregatedResultCall
Sourceimpl Serialize for submitAggregatedResultCall
impl Serialize for submitAggregatedResultCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for submitAggregatedResultCall
impl SolCall for submitAggregatedResultCall
Sourceconst SIGNATURE: &'static str = "submitAggregatedResult(uint64,uint64,bytes,uint256,uint256[2],uint256[4])"
const SIGNATURE: &'static str = "submitAggregatedResult(uint64,uint64,bytes,uint256,uint256[2],uint256[4])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>, Bytes, Uint<256>, FixedArray<Uint<256>, 2>, FixedArray<Uint<256>, 4>)
type Parameters<'a> = (Uint<64>, Uint<64>, Bytes, Uint<256>, FixedArray<Uint<256>, 2>, FixedArray<Uint<256>, 4>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<submitAggregatedResultCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<submitAggregatedResultCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = submitAggregatedResultReturn
type Return = submitAggregatedResultReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<submitAggregatedResultCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<submitAggregatedResultCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<submitAggregatedResultCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> submitAggregatedResultCall
fn new<'a>( tuple: <<submitAggregatedResultCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> submitAggregatedResultCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <submitAggregatedResultCall as SolCall>::Token<'_>
fn tokenize(&self) -> <submitAggregatedResultCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<submitAggregatedResultCall as SolCall>::Return,
) -> <submitAggregatedResultCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<submitAggregatedResultCall as SolCall>::Return, ) -> <submitAggregatedResultCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<submitAggregatedResultCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<submitAggregatedResultCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<submitAggregatedResultCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<submitAggregatedResultCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for submitAggregatedResultCall
impl StructuralPartialEq for submitAggregatedResultCall