pub struct submitJobCall {
pub serviceId: u64,
pub jobIndex: u8,
pub inputs: Bytes,
}Expand description
Function with signature submitJob(uint64,uint8,bytes) and selector 0x3413e8ee.
function submitJob(uint64 serviceId, uint8 jobIndex, bytes memory inputs) external payable returns (uint64 callId);Fields
serviceId: u64jobIndex: u8inputs: BytesTrait Implementations
Sourceimpl Clone for submitJobCall
impl Clone for submitJobCall
Sourcefn clone(&self) -> submitJobCall
fn clone(&self) -> submitJobCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for submitJobCall
impl Debug for submitJobCall
Sourceimpl Default for submitJobCall
impl Default for submitJobCall
Sourcefn default() -> submitJobCall
fn default() -> submitJobCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for submitJobCall
impl<'de> Deserialize<'de> for submitJobCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitJobCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitJobCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for submitJobCall
impl Hash for submitJobCall
Sourceimpl PartialEq for submitJobCall
impl PartialEq for submitJobCall
Sourceimpl Serialize for submitJobCall
impl Serialize for submitJobCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for submitJobCall
impl SolCall for submitJobCall
Sourcetype Parameters<'a> = (Uint<64>, Uint<8>, Bytes)
type Parameters<'a> = (Uint<64>, Uint<8>, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<submitJobCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<submitJobCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<submitJobCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<submitJobCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<submitJobCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> submitJobCall
fn new<'a>( tuple: <<submitJobCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> submitJobCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<submitJobCall as SolCall>::Return,
) -> <submitJobCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<submitJobCall as SolCall>::Return, ) -> <submitJobCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<submitJobCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<submitJobCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<submitJobCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<submitJobCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for submitJobCall
impl StructuralPartialEq for submitJobCall