pub struct submitJobFromQuoteCall {
pub serviceId: u64,
pub jobIndex: u8,
pub inputs: Bytes,
pub quotes: Vec<<SignedJobQuote as SolType>::RustType>,
}Expand description
Function with signature submitJobFromQuote(uint64,uint8,bytes,((uint64,uint8,uint256,uint64,uint64,uint8),bytes,address)[]) and selector 0x58a9e743.
function submitJobFromQuote(uint64 serviceId, uint8 jobIndex, bytes memory inputs, Types.SignedJobQuote[] memory quotes) external payable returns (uint64 callId);Fields
serviceId: u64jobIndex: u8inputs: Bytesquotes: Vec<<SignedJobQuote as SolType>::RustType>Trait Implementations
Sourceimpl Clone for submitJobFromQuoteCall
impl Clone for submitJobFromQuoteCall
Sourcefn clone(&self) -> submitJobFromQuoteCall
fn clone(&self) -> submitJobFromQuoteCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for submitJobFromQuoteCall
impl<'de> Deserialize<'de> for submitJobFromQuoteCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitJobFromQuoteCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitJobFromQuoteCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for submitJobFromQuoteCall
impl Serialize for submitJobFromQuoteCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for submitJobFromQuoteCall
impl SolCall for submitJobFromQuoteCall
Sourceconst SIGNATURE: &'static str = "submitJobFromQuote(uint64,uint8,bytes,((uint64,uint8,uint256,uint64,uint64,uint8),bytes,address)[])"
const SIGNATURE: &'static str = "submitJobFromQuote(uint64,uint8,bytes,((uint64,uint8,uint256,uint64,uint64,uint8),bytes,address)[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<8>, Bytes, Array<SignedJobQuote>)
type Parameters<'a> = (Uint<64>, Uint<8>, Bytes, Array<SignedJobQuote>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<submitJobFromQuoteCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<submitJobFromQuoteCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<submitJobFromQuoteCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<submitJobFromQuoteCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<submitJobFromQuoteCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> submitJobFromQuoteCall
fn new<'a>( tuple: <<submitJobFromQuoteCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> submitJobFromQuoteCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <submitJobFromQuoteCall as SolCall>::Token<'_>
fn tokenize(&self) -> <submitJobFromQuoteCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<submitJobFromQuoteCall as SolCall>::Return,
) -> <submitJobFromQuoteCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<submitJobFromQuoteCall as SolCall>::Return, ) -> <submitJobFromQuoteCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<submitJobFromQuoteCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<submitJobFromQuoteCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<submitJobFromQuoteCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<submitJobFromQuoteCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.