pub struct submitJobFromQuoteReturn {
pub callId: u64,
}Expand description
Container type for the return parameters of the submitJobFromQuote(uint64,uint8,bytes,((address,uint64,uint8,uint256,uint64,uint64,uint8),bytes,address)[]) function.
Fields
callId: u64Trait Implementations
Sourceimpl Clone for submitJobFromQuoteReturn
impl Clone for submitJobFromQuoteReturn
Sourcefn clone(&self) -> submitJobFromQuoteReturn
fn clone(&self) -> submitJobFromQuoteReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for submitJobFromQuoteReturn
impl Debug for submitJobFromQuoteReturn
Sourceimpl Default for submitJobFromQuoteReturn
impl Default for submitJobFromQuoteReturn
Sourcefn default() -> submitJobFromQuoteReturn
fn default() -> submitJobFromQuoteReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for submitJobFromQuoteReturn
impl<'de> Deserialize<'de> for submitJobFromQuoteReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitJobFromQuoteReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitJobFromQuoteReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for submitJobFromQuoteReturn
Sourceimpl Hash for submitJobFromQuoteReturn
impl Hash for submitJobFromQuoteReturn
Sourceimpl PartialEq for submitJobFromQuoteReturn
impl PartialEq for submitJobFromQuoteReturn
Sourcefn eq(&self, other: &submitJobFromQuoteReturn) -> bool
fn eq(&self, other: &submitJobFromQuoteReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for submitJobFromQuoteReturn
impl Serialize for submitJobFromQuoteReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for submitJobFromQuoteReturn