pub struct submitResultCall {
pub serviceId: u64,
pub callId: u64,
pub result: Bytes,
}Expand description
Function with signature submitResult(uint64,uint64,bytes) and selector 0x2d07e655.
function submitResult(uint64 serviceId, uint64 callId, bytes memory result) external;Fields
serviceId: u64callId: u64result: BytesTrait Implementations
Sourceimpl Clone for submitResultCall
impl Clone for submitResultCall
Sourcefn clone(&self) -> submitResultCall
fn clone(&self) -> submitResultCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for submitResultCall
impl Debug for submitResultCall
Sourceimpl Default for submitResultCall
impl Default for submitResultCall
Sourcefn default() -> submitResultCall
fn default() -> submitResultCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for submitResultCall
impl<'de> Deserialize<'de> for submitResultCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitResultCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitResultCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for submitResultCall
impl Hash for submitResultCall
Sourceimpl PartialEq for submitResultCall
impl PartialEq for submitResultCall
Sourceimpl Serialize for submitResultCall
impl Serialize for submitResultCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for submitResultCall
impl SolCall for submitResultCall
Sourceconst SIGNATURE: &'static str = "submitResult(uint64,uint64,bytes)"
const SIGNATURE: &'static str = "submitResult(uint64,uint64,bytes)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>, Bytes)
type Parameters<'a> = (Uint<64>, Uint<64>, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<submitResultCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<submitResultCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = submitResultReturn
type Return = submitResultReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<submitResultCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<submitResultCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<submitResultCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> submitResultCall
fn new<'a>( tuple: <<submitResultCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> submitResultCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<submitResultCall as SolCall>::Return,
) -> <submitResultCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<submitResultCall as SolCall>::Return, ) -> <submitResultCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<submitResultCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<submitResultCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<submitResultCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<submitResultCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for submitResultCall
impl StructuralPartialEq for submitResultCall