pub struct submitResultsCall {
pub serviceId: u64,
pub callIds: Vec<u64>,
pub results: Vec<Bytes>,
}Expand description
Function with signature submitResults(uint64,uint64[],bytes[]) and selector 0xaacdba9f.
function submitResults(uint64 serviceId, uint64[] memory callIds, bytes[] memory results) external;Fields
serviceId: u64callIds: Vec<u64>results: Vec<Bytes>Trait Implementations
Sourceimpl Clone for submitResultsCall
impl Clone for submitResultsCall
Sourcefn clone(&self) -> submitResultsCall
fn clone(&self) -> submitResultsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for submitResultsCall
impl Debug for submitResultsCall
Sourceimpl Default for submitResultsCall
impl Default for submitResultsCall
Sourcefn default() -> submitResultsCall
fn default() -> submitResultsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for submitResultsCall
impl<'de> Deserialize<'de> for submitResultsCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitResultsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitResultsCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for submitResultsCall
impl Hash for submitResultsCall
Sourceimpl PartialEq for submitResultsCall
impl PartialEq for submitResultsCall
Sourceimpl Serialize for submitResultsCall
impl Serialize for submitResultsCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for submitResultsCall
impl SolCall for submitResultsCall
Sourceconst SIGNATURE: &'static str = "submitResults(uint64,uint64[],bytes[])"
const SIGNATURE: &'static str = "submitResults(uint64,uint64[],bytes[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Array<Uint<64>>, Array<Bytes>)
type Parameters<'a> = (Uint<64>, Array<Uint<64>>, Array<Bytes>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<submitResultsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<submitResultsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = submitResultsReturn
type Return = submitResultsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<submitResultsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<submitResultsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<submitResultsCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> submitResultsCall
fn new<'a>( tuple: <<submitResultsCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> submitResultsCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <submitResultsCall as SolCall>::Token<'_>
fn tokenize(&self) -> <submitResultsCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<submitResultsCall as SolCall>::Return,
) -> <submitResultsCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<submitResultsCall as SolCall>::Return, ) -> <submitResultsCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<submitResultsCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<submitResultsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<submitResultsCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<submitResultsCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for submitResultsCall
impl StructuralPartialEq for submitResultsCall