pub struct terminateServiceForNonPaymentCall {
pub serviceId: u64,
}Expand description
Function with signature terminateServiceForNonPayment(uint64) and selector 0x13d36a66.
function terminateServiceForNonPayment(uint64 serviceId) external;Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for terminateServiceForNonPaymentCall
impl Clone for terminateServiceForNonPaymentCall
Sourcefn clone(&self) -> terminateServiceForNonPaymentCall
fn clone(&self) -> terminateServiceForNonPaymentCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for terminateServiceForNonPaymentCall
impl Default for terminateServiceForNonPaymentCall
Sourcefn default() -> terminateServiceForNonPaymentCall
fn default() -> terminateServiceForNonPaymentCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for terminateServiceForNonPaymentCall
impl<'de> Deserialize<'de> for terminateServiceForNonPaymentCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<terminateServiceForNonPaymentCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<terminateServiceForNonPaymentCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for terminateServiceForNonPaymentCall
impl PartialEq for terminateServiceForNonPaymentCall
Sourcefn eq(&self, other: &terminateServiceForNonPaymentCall) -> bool
fn eq(&self, other: &terminateServiceForNonPaymentCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for terminateServiceForNonPaymentCall
impl Serialize for terminateServiceForNonPaymentCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for terminateServiceForNonPaymentCall
impl SolCall for terminateServiceForNonPaymentCall
Sourceconst SIGNATURE: &'static str = "terminateServiceForNonPayment(uint64)"
const SIGNATURE: &'static str = "terminateServiceForNonPayment(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<terminateServiceForNonPaymentCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<terminateServiceForNonPaymentCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = terminateServiceForNonPaymentReturn
type Return = terminateServiceForNonPaymentReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<terminateServiceForNonPaymentCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<terminateServiceForNonPaymentCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<terminateServiceForNonPaymentCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> terminateServiceForNonPaymentCall
fn new<'a>( tuple: <<terminateServiceForNonPaymentCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> terminateServiceForNonPaymentCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <terminateServiceForNonPaymentCall as SolCall>::Token<'_>
fn tokenize(&self) -> <terminateServiceForNonPaymentCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<terminateServiceForNonPaymentCall as SolCall>::Return,
) -> <terminateServiceForNonPaymentCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<terminateServiceForNonPaymentCall as SolCall>::Return, ) -> <terminateServiceForNonPaymentCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<terminateServiceForNonPaymentCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<terminateServiceForNonPaymentCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<terminateServiceForNonPaymentCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<terminateServiceForNonPaymentCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for terminateServiceForNonPaymentCall
impl StructuralPartialEq for terminateServiceForNonPaymentCall