pub struct updateBlueprintCall {
pub blueprintId: u64,
pub metadataUri: String,
}Expand description
Function with signature updateBlueprint(uint64,string) and selector 0xe538da66.
function updateBlueprint(uint64 blueprintId, string memory metadataUri) external;Fields
blueprintId: u64metadataUri: StringTrait Implementations
Sourceimpl Clone for updateBlueprintCall
impl Clone for updateBlueprintCall
Sourcefn clone(&self) -> updateBlueprintCall
fn clone(&self) -> updateBlueprintCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for updateBlueprintCall
impl Debug for updateBlueprintCall
Sourceimpl Default for updateBlueprintCall
impl Default for updateBlueprintCall
Sourcefn default() -> updateBlueprintCall
fn default() -> updateBlueprintCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for updateBlueprintCall
impl<'de> Deserialize<'de> for updateBlueprintCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<updateBlueprintCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<updateBlueprintCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for updateBlueprintCall
impl Hash for updateBlueprintCall
Sourceimpl PartialEq for updateBlueprintCall
impl PartialEq for updateBlueprintCall
Sourceimpl Serialize for updateBlueprintCall
impl Serialize for updateBlueprintCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for updateBlueprintCall
impl SolCall for updateBlueprintCall
Sourceconst SIGNATURE: &'static str = "updateBlueprint(uint64,string)"
const SIGNATURE: &'static str = "updateBlueprint(uint64,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, String)
type Parameters<'a> = (Uint<64>, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<updateBlueprintCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<updateBlueprintCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = updateBlueprintReturn
type Return = updateBlueprintReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<updateBlueprintCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<updateBlueprintCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<updateBlueprintCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> updateBlueprintCall
fn new<'a>( tuple: <<updateBlueprintCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> updateBlueprintCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <updateBlueprintCall as SolCall>::Token<'_>
fn tokenize(&self) -> <updateBlueprintCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<updateBlueprintCall as SolCall>::Return,
) -> <updateBlueprintCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<updateBlueprintCall as SolCall>::Return, ) -> <updateBlueprintCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<updateBlueprintCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<updateBlueprintCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<updateBlueprintCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<updateBlueprintCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for updateBlueprintCall
impl StructuralPartialEq for updateBlueprintCall