pub struct updateOperatorPreferencesCall {
pub blueprintId: u64,
pub ecdsaPublicKey: Bytes,
pub rpcAddress: String,
}Expand description
Function with signature updateOperatorPreferences(uint64,bytes,string) and selector 0x909eac24.
function updateOperatorPreferences(uint64 blueprintId, bytes memory ecdsaPublicKey, string memory rpcAddress) external;Fields
blueprintId: u64ecdsaPublicKey: BytesrpcAddress: StringTrait Implementations
Sourceimpl Clone for updateOperatorPreferencesCall
impl Clone for updateOperatorPreferencesCall
Sourcefn clone(&self) -> updateOperatorPreferencesCall
fn clone(&self) -> updateOperatorPreferencesCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for updateOperatorPreferencesCall
impl Default for updateOperatorPreferencesCall
Sourcefn default() -> updateOperatorPreferencesCall
fn default() -> updateOperatorPreferencesCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for updateOperatorPreferencesCall
impl<'de> Deserialize<'de> for updateOperatorPreferencesCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<updateOperatorPreferencesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<updateOperatorPreferencesCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for updateOperatorPreferencesCall
impl Hash for updateOperatorPreferencesCall
Sourceimpl PartialEq for updateOperatorPreferencesCall
impl PartialEq for updateOperatorPreferencesCall
Sourcefn eq(&self, other: &updateOperatorPreferencesCall) -> bool
fn eq(&self, other: &updateOperatorPreferencesCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for updateOperatorPreferencesCall
impl Serialize for updateOperatorPreferencesCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for updateOperatorPreferencesCall
impl SolCall for updateOperatorPreferencesCall
Sourceconst SIGNATURE: &'static str = "updateOperatorPreferences(uint64,bytes,string)"
const SIGNATURE: &'static str = "updateOperatorPreferences(uint64,bytes,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Bytes, String)
type Parameters<'a> = (Uint<64>, Bytes, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<updateOperatorPreferencesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<updateOperatorPreferencesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = updateOperatorPreferencesReturn
type Return = updateOperatorPreferencesReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<updateOperatorPreferencesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<updateOperatorPreferencesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<updateOperatorPreferencesCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> updateOperatorPreferencesCall
fn new<'a>( tuple: <<updateOperatorPreferencesCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> updateOperatorPreferencesCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <updateOperatorPreferencesCall as SolCall>::Token<'_>
fn tokenize(&self) -> <updateOperatorPreferencesCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<updateOperatorPreferencesCall as SolCall>::Return,
) -> <updateOperatorPreferencesCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<updateOperatorPreferencesCall as SolCall>::Return, ) -> <updateOperatorPreferencesCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<updateOperatorPreferencesCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<updateOperatorPreferencesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<updateOperatorPreferencesCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<updateOperatorPreferencesCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for updateOperatorPreferencesCall
impl StructuralPartialEq for updateOperatorPreferencesCall