pub struct withdrawRemainingEscrowCall {
pub serviceId: u64,
}Expand description
Function with signature withdrawRemainingEscrow(uint64) and selector 0x9dfb6100.
function withdrawRemainingEscrow(uint64 serviceId) external;Fields
serviceId: u64Trait Implementations
Sourceimpl Clone for withdrawRemainingEscrowCall
impl Clone for withdrawRemainingEscrowCall
Sourcefn clone(&self) -> withdrawRemainingEscrowCall
fn clone(&self) -> withdrawRemainingEscrowCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for withdrawRemainingEscrowCall
impl Debug for withdrawRemainingEscrowCall
Sourceimpl Default for withdrawRemainingEscrowCall
impl Default for withdrawRemainingEscrowCall
Sourcefn default() -> withdrawRemainingEscrowCall
fn default() -> withdrawRemainingEscrowCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for withdrawRemainingEscrowCall
impl<'de> Deserialize<'de> for withdrawRemainingEscrowCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<withdrawRemainingEscrowCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<withdrawRemainingEscrowCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for withdrawRemainingEscrowCall
impl Hash for withdrawRemainingEscrowCall
Sourceimpl Serialize for withdrawRemainingEscrowCall
impl Serialize for withdrawRemainingEscrowCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for withdrawRemainingEscrowCall
impl SolCall for withdrawRemainingEscrowCall
Sourceconst SIGNATURE: &'static str = "withdrawRemainingEscrow(uint64)"
const SIGNATURE: &'static str = "withdrawRemainingEscrow(uint64)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>,)
type Parameters<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<withdrawRemainingEscrowCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<withdrawRemainingEscrowCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = withdrawRemainingEscrowReturn
type Return = withdrawRemainingEscrowReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<withdrawRemainingEscrowCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<withdrawRemainingEscrowCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<withdrawRemainingEscrowCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> withdrawRemainingEscrowCall
fn new<'a>( tuple: <<withdrawRemainingEscrowCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> withdrawRemainingEscrowCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <withdrawRemainingEscrowCall as SolCall>::Token<'_>
fn tokenize(&self) -> <withdrawRemainingEscrowCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<withdrawRemainingEscrowCall as SolCall>::Return,
) -> <withdrawRemainingEscrowCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<withdrawRemainingEscrowCall as SolCall>::Return, ) -> <withdrawRemainingEscrowCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<withdrawRemainingEscrowCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<withdrawRemainingEscrowCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<withdrawRemainingEscrowCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<withdrawRemainingEscrowCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for withdrawRemainingEscrowCall
impl StructuralPartialEq for withdrawRemainingEscrowCall