pub struct canJoinCall {
pub serviceId: u64,
pub operator: Address,
}Expand description
Function with signature canJoin(uint64,address) and selector 0xb47242e8.
function canJoin(uint64 serviceId, address operator) external view returns (bool allowed);Fields
serviceId: u64operator: AddressTrait Implementations
Sourceimpl Clone for canJoinCall
impl Clone for canJoinCall
Sourcefn clone(&self) -> canJoinCall
fn clone(&self) -> canJoinCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for canJoinCall
impl Debug for canJoinCall
Sourceimpl Default for canJoinCall
impl Default for canJoinCall
Sourcefn default() -> canJoinCall
fn default() -> canJoinCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for canJoinCall
impl<'de> Deserialize<'de> for canJoinCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<canJoinCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<canJoinCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for canJoinCall
Sourceimpl Hash for canJoinCall
impl Hash for canJoinCall
Sourceimpl PartialEq for canJoinCall
impl PartialEq for canJoinCall
Sourcefn eq(&self, other: &canJoinCall) -> bool
fn eq(&self, other: &canJoinCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for canJoinCall
impl Serialize for canJoinCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for canJoinCall
impl SolCall for canJoinCall
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<canJoinCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<canJoinCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<canJoinCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<canJoinCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<canJoinCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> canJoinCall
fn new<'a>( tuple: <<canJoinCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> canJoinCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<canJoinCall as SolCall>::Return,
) -> <canJoinCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<canJoinCall as SolCall>::Return, ) -> <canJoinCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<canJoinCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<canJoinCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<canJoinCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<canJoinCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for canJoinCall