pub struct getRequiredResultCountCall {
pub serviceId: u64,
pub jobIndex: u8,
}Expand description
Function with signature getRequiredResultCount(uint64,uint8) and selector 0x4c443e04.
function getRequiredResultCount(uint64 serviceId, uint8 jobIndex) external view returns (uint32 required);Fields
serviceId: u64jobIndex: u8Trait Implementations
Sourceimpl Clone for getRequiredResultCountCall
impl Clone for getRequiredResultCountCall
Sourcefn clone(&self) -> getRequiredResultCountCall
fn clone(&self) -> getRequiredResultCountCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getRequiredResultCountCall
impl Debug for getRequiredResultCountCall
Sourceimpl Default for getRequiredResultCountCall
impl Default for getRequiredResultCountCall
Sourcefn default() -> getRequiredResultCountCall
fn default() -> getRequiredResultCountCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getRequiredResultCountCall
impl<'de> Deserialize<'de> for getRequiredResultCountCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getRequiredResultCountCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getRequiredResultCountCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getRequiredResultCountCall
Sourceimpl Hash for getRequiredResultCountCall
impl Hash for getRequiredResultCountCall
Sourceimpl PartialEq for getRequiredResultCountCall
impl PartialEq for getRequiredResultCountCall
Sourcefn eq(&self, other: &getRequiredResultCountCall) -> bool
fn eq(&self, other: &getRequiredResultCountCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getRequiredResultCountCall
impl Serialize for getRequiredResultCountCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getRequiredResultCountCall
impl SolCall for getRequiredResultCountCall
Sourceconst SIGNATURE: &'static str = "getRequiredResultCount(uint64,uint8)"
const SIGNATURE: &'static str = "getRequiredResultCount(uint64,uint8)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<8>)
type Parameters<'a> = (Uint<64>, Uint<8>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getRequiredResultCountCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getRequiredResultCountCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<32>,)
type ReturnTuple<'a> = (Uint<32>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getRequiredResultCountCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getRequiredResultCountCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getRequiredResultCountCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getRequiredResultCountCall
fn new<'a>( tuple: <<getRequiredResultCountCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getRequiredResultCountCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getRequiredResultCountCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getRequiredResultCountCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getRequiredResultCountCall as SolCall>::Return,
) -> <getRequiredResultCountCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getRequiredResultCountCall as SolCall>::Return, ) -> <getRequiredResultCountCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getRequiredResultCountCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getRequiredResultCountCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getRequiredResultCountCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getRequiredResultCountCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for getRequiredResultCountCall