pub struct onOperatorJoinedCall {
pub serviceId: u64,
pub operator: Address,
pub exposureBps: u16,
}Expand description
Function with signature onOperatorJoined(uint64,address,uint16) and selector 0x9aa26a92.
function onOperatorJoined(uint64 serviceId, address operator, uint16 exposureBps) external;Fields
serviceId: u64operator: AddressexposureBps: u16Trait Implementations
Sourceimpl Clone for onOperatorJoinedCall
impl Clone for onOperatorJoinedCall
Sourcefn clone(&self) -> onOperatorJoinedCall
fn clone(&self) -> onOperatorJoinedCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for onOperatorJoinedCall
impl Debug for onOperatorJoinedCall
Sourceimpl Default for onOperatorJoinedCall
impl Default for onOperatorJoinedCall
Sourcefn default() -> onOperatorJoinedCall
fn default() -> onOperatorJoinedCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for onOperatorJoinedCall
impl<'de> Deserialize<'de> for onOperatorJoinedCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<onOperatorJoinedCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<onOperatorJoinedCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for onOperatorJoinedCall
Sourceimpl Hash for onOperatorJoinedCall
impl Hash for onOperatorJoinedCall
Sourceimpl PartialEq for onOperatorJoinedCall
impl PartialEq for onOperatorJoinedCall
Sourcefn eq(&self, other: &onOperatorJoinedCall) -> bool
fn eq(&self, other: &onOperatorJoinedCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for onOperatorJoinedCall
impl Serialize for onOperatorJoinedCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for onOperatorJoinedCall
impl SolCall for onOperatorJoinedCall
Sourceconst SIGNATURE: &'static str = "onOperatorJoined(uint64,address,uint16)"
const SIGNATURE: &'static str = "onOperatorJoined(uint64,address,uint16)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address, Uint<16>)
type Parameters<'a> = (Uint<64>, Address, Uint<16>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<onOperatorJoinedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<onOperatorJoinedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = onOperatorJoinedReturn
type Return = onOperatorJoinedReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<onOperatorJoinedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<onOperatorJoinedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<onOperatorJoinedCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> onOperatorJoinedCall
fn new<'a>( tuple: <<onOperatorJoinedCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> onOperatorJoinedCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <onOperatorJoinedCall as SolCall>::Token<'_>
fn tokenize(&self) -> <onOperatorJoinedCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<onOperatorJoinedCall as SolCall>::Return,
) -> <onOperatorJoinedCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<onOperatorJoinedCall as SolCall>::Return, ) -> <onOperatorJoinedCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<onOperatorJoinedCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<onOperatorJoinedCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<onOperatorJoinedCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<onOperatorJoinedCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for onOperatorJoinedCall