pub struct requiresAggregationCall {
pub serviceId: u64,
pub jobIndex: u8,
}Expand description
Function with signature requiresAggregation(uint64,uint8) and selector 0x19ed5bb2.
function requiresAggregation(uint64 serviceId, uint8 jobIndex) external view returns (bool required);Fields
serviceId: u64jobIndex: u8Trait Implementations
Sourceimpl Clone for requiresAggregationCall
impl Clone for requiresAggregationCall
Sourcefn clone(&self) -> requiresAggregationCall
fn clone(&self) -> requiresAggregationCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for requiresAggregationCall
impl Debug for requiresAggregationCall
Sourceimpl Default for requiresAggregationCall
impl Default for requiresAggregationCall
Sourcefn default() -> requiresAggregationCall
fn default() -> requiresAggregationCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for requiresAggregationCall
impl<'de> Deserialize<'de> for requiresAggregationCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<requiresAggregationCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<requiresAggregationCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for requiresAggregationCall
Sourceimpl Hash for requiresAggregationCall
impl Hash for requiresAggregationCall
Sourceimpl PartialEq for requiresAggregationCall
impl PartialEq for requiresAggregationCall
Sourcefn eq(&self, other: &requiresAggregationCall) -> bool
fn eq(&self, other: &requiresAggregationCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for requiresAggregationCall
impl Serialize for requiresAggregationCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for requiresAggregationCall
impl SolCall for requiresAggregationCall
Sourceconst SIGNATURE: &'static str = "requiresAggregation(uint64,uint8)"
const SIGNATURE: &'static str = "requiresAggregation(uint64,uint8)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<8>)
type Parameters<'a> = (Uint<64>, Uint<8>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<requiresAggregationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<requiresAggregationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<requiresAggregationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<requiresAggregationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<requiresAggregationCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> requiresAggregationCall
fn new<'a>( tuple: <<requiresAggregationCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> requiresAggregationCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <requiresAggregationCall as SolCall>::Token<'_>
fn tokenize(&self) -> <requiresAggregationCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<requiresAggregationCall as SolCall>::Return,
) -> <requiresAggregationCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<requiresAggregationCall as SolCall>::Return, ) -> <requiresAggregationCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<requiresAggregationCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<requiresAggregationCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<requiresAggregationCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<requiresAggregationCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for requiresAggregationCall