pub struct requiresAggregationReturn {
pub required: bool,
}Expand description
Container type for the return parameters of the requiresAggregation(uint64,uint8) function.
Fields
required: boolTrait Implementations
Sourceimpl Clone for requiresAggregationReturn
impl Clone for requiresAggregationReturn
Sourcefn clone(&self) -> requiresAggregationReturn
fn clone(&self) -> requiresAggregationReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for requiresAggregationReturn
impl Debug for requiresAggregationReturn
Sourceimpl Default for requiresAggregationReturn
impl Default for requiresAggregationReturn
Sourcefn default() -> requiresAggregationReturn
fn default() -> requiresAggregationReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for requiresAggregationReturn
impl<'de> Deserialize<'de> for requiresAggregationReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<requiresAggregationReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<requiresAggregationReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for requiresAggregationReturn
Sourceimpl Hash for requiresAggregationReturn
impl Hash for requiresAggregationReturn
Sourceimpl PartialEq for requiresAggregationReturn
impl PartialEq for requiresAggregationReturn
Sourcefn eq(&self, other: &requiresAggregationReturn) -> bool
fn eq(&self, other: &requiresAggregationReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for requiresAggregationReturn
impl Serialize for requiresAggregationReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for requiresAggregationReturn