pub struct registerServiceOwnerCall {
pub serviceId: u64,
pub owner: Address,
}Expand description
Function with signature registerServiceOwner(uint64,address) and selector 0x05778550.
function registerServiceOwner(uint64 serviceId, address owner) external;Fields
serviceId: u64owner: AddressTrait Implementations
Sourceimpl Clone for registerServiceOwnerCall
impl Clone for registerServiceOwnerCall
Sourcefn clone(&self) -> registerServiceOwnerCall
fn clone(&self) -> registerServiceOwnerCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for registerServiceOwnerCall
impl Debug for registerServiceOwnerCall
Sourceimpl Default for registerServiceOwnerCall
impl Default for registerServiceOwnerCall
Sourcefn default() -> registerServiceOwnerCall
fn default() -> registerServiceOwnerCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for registerServiceOwnerCall
impl<'de> Deserialize<'de> for registerServiceOwnerCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<registerServiceOwnerCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<registerServiceOwnerCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for registerServiceOwnerCall
Sourceimpl Hash for registerServiceOwnerCall
impl Hash for registerServiceOwnerCall
Sourceimpl PartialEq for registerServiceOwnerCall
impl PartialEq for registerServiceOwnerCall
Sourcefn eq(&self, other: ®isterServiceOwnerCall) -> bool
fn eq(&self, other: ®isterServiceOwnerCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for registerServiceOwnerCall
impl Serialize for registerServiceOwnerCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for registerServiceOwnerCall
impl SolCall for registerServiceOwnerCall
Sourceconst SIGNATURE: &'static str = "registerServiceOwner(uint64,address)"
const SIGNATURE: &'static str = "registerServiceOwner(uint64,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address)
type Parameters<'a> = (Uint<64>, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<registerServiceOwnerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<registerServiceOwnerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = registerServiceOwnerReturn
type Return = registerServiceOwnerReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<registerServiceOwnerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<registerServiceOwnerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<registerServiceOwnerCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> registerServiceOwnerCall
fn new<'a>( tuple: <<registerServiceOwnerCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> registerServiceOwnerCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <registerServiceOwnerCall as SolCall>::Token<'_>
fn tokenize(&self) -> <registerServiceOwnerCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<registerServiceOwnerCall as SolCall>::Return,
) -> <registerServiceOwnerCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<registerServiceOwnerCall as SolCall>::Return, ) -> <registerServiceOwnerCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<registerServiceOwnerCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<registerServiceOwnerCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<registerServiceOwnerCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<registerServiceOwnerCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for registerServiceOwnerCall