pub struct getExitConfigReturn {
pub _0: <ExitConfig as SolType>::RustType,
}Expand description
Container type for the return parameters of the getExitConfig(uint64) function.
Fields
_0: <ExitConfig as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getExitConfigReturn
impl Clone for getExitConfigReturn
Sourcefn clone(&self) -> getExitConfigReturn
fn clone(&self) -> getExitConfigReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getExitConfigReturn
impl Debug for getExitConfigReturn
Sourceimpl Default for getExitConfigReturn
impl Default for getExitConfigReturn
Sourcefn default() -> getExitConfigReturn
fn default() -> getExitConfigReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getExitConfigReturn
impl<'de> Deserialize<'de> for getExitConfigReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getExitConfigReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getExitConfigReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getExitConfigReturn
Sourceimpl Hash for getExitConfigReturn
impl Hash for getExitConfigReturn
Sourceimpl PartialEq for getExitConfigReturn
impl PartialEq for getExitConfigReturn
Sourcefn eq(&self, other: &getExitConfigReturn) -> bool
fn eq(&self, other: &getExitConfigReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getExitConfigReturn
impl Serialize for getExitConfigReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getExitConfigReturn