pub struct getExitStatusReturn {
pub _0: <ExitStatus as SolType>::RustType,
}Expand description
Container type for the return parameters of the getExitStatus(uint64,address) function.
Fields
_0: <ExitStatus as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getExitStatusReturn
impl Clone for getExitStatusReturn
Sourcefn clone(&self) -> getExitStatusReturn
fn clone(&self) -> getExitStatusReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getExitStatusReturn
impl Debug for getExitStatusReturn
Sourceimpl Default for getExitStatusReturn
impl Default for getExitStatusReturn
Sourcefn default() -> getExitStatusReturn
fn default() -> getExitStatusReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getExitStatusReturn
impl<'de> Deserialize<'de> for getExitStatusReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getExitStatusReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getExitStatusReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getExitStatusReturn
Sourceimpl Hash for getExitStatusReturn
impl Hash for getExitStatusReturn
Sourceimpl PartialEq for getExitStatusReturn
impl PartialEq for getExitStatusReturn
Sourcefn eq(&self, other: &getExitStatusReturn) -> bool
fn eq(&self, other: &getExitStatusReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getExitStatusReturn
impl Serialize for getExitStatusReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getExitStatusReturn