pub struct getOperatorRegistrationReturn {
pub _0: <OperatorRegistration as SolType>::RustType,
}Expand description
Container type for the return parameters of the getOperatorRegistration(uint64,address) function.
Fields
_0: <OperatorRegistration as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getOperatorRegistrationReturn
impl Clone for getOperatorRegistrationReturn
Sourcefn clone(&self) -> getOperatorRegistrationReturn
fn clone(&self) -> getOperatorRegistrationReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getOperatorRegistrationReturn
impl Default for getOperatorRegistrationReturn
Sourcefn default() -> getOperatorRegistrationReturn
fn default() -> getOperatorRegistrationReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorRegistrationReturn
impl<'de> Deserialize<'de> for getOperatorRegistrationReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorRegistrationReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorRegistrationReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getOperatorRegistrationReturn
Sourceimpl Hash for getOperatorRegistrationReturn
impl Hash for getOperatorRegistrationReturn
Sourceimpl PartialEq for getOperatorRegistrationReturn
impl PartialEq for getOperatorRegistrationReturn
Sourcefn eq(&self, other: &getOperatorRegistrationReturn) -> bool
fn eq(&self, other: &getOperatorRegistrationReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOperatorRegistrationReturn
impl Serialize for getOperatorRegistrationReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getOperatorRegistrationReturn