pub struct getServiceEscrowReturn {
pub _0: <ServiceEscrow as SolType>::RustType,
}Expand description
Container type for the return parameters of the getServiceEscrow(uint64) function.
Fields
_0: <ServiceEscrow as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getServiceEscrowReturn
impl Clone for getServiceEscrowReturn
Sourcefn clone(&self) -> getServiceEscrowReturn
fn clone(&self) -> getServiceEscrowReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getServiceEscrowReturn
impl Debug for getServiceEscrowReturn
Sourceimpl Default for getServiceEscrowReturn
impl Default for getServiceEscrowReturn
Sourcefn default() -> getServiceEscrowReturn
fn default() -> getServiceEscrowReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceEscrowReturn
impl<'de> Deserialize<'de> for getServiceEscrowReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceEscrowReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceEscrowReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getServiceEscrowReturn
Sourceimpl Hash for getServiceEscrowReturn
impl Hash for getServiceEscrowReturn
Sourceimpl PartialEq for getServiceEscrowReturn
impl PartialEq for getServiceEscrowReturn
Sourcefn eq(&self, other: &getServiceEscrowReturn) -> bool
fn eq(&self, other: &getServiceEscrowReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getServiceEscrowReturn
impl Serialize for getServiceEscrowReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getServiceEscrowReturn