pub struct getServiceOperatorReturn {
pub _0: <ServiceOperator as SolType>::RustType,
}Expand description
Container type for the return parameters of the getServiceOperator(uint64,address) function.
Fields
_0: <ServiceOperator as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for getServiceOperatorReturn
impl Clone for getServiceOperatorReturn
Sourcefn clone(&self) -> getServiceOperatorReturn
fn clone(&self) -> getServiceOperatorReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getServiceOperatorReturn
impl Debug for getServiceOperatorReturn
Sourceimpl Default for getServiceOperatorReturn
impl Default for getServiceOperatorReturn
Sourcefn default() -> getServiceOperatorReturn
fn default() -> getServiceOperatorReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceOperatorReturn
impl<'de> Deserialize<'de> for getServiceOperatorReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceOperatorReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceOperatorReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getServiceOperatorReturn
Sourceimpl Hash for getServiceOperatorReturn
impl Hash for getServiceOperatorReturn
Sourceimpl PartialEq for getServiceOperatorReturn
impl PartialEq for getServiceOperatorReturn
Sourcefn eq(&self, other: &getServiceOperatorReturn) -> bool
fn eq(&self, other: &getServiceOperatorReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getServiceOperatorReturn
impl Serialize for getServiceOperatorReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getServiceOperatorReturn