pub struct isServiceActiveReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the isServiceActive(uint64) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for isServiceActiveReturn
impl Clone for isServiceActiveReturn
Sourcefn clone(&self) -> isServiceActiveReturn
fn clone(&self) -> isServiceActiveReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isServiceActiveReturn
impl Debug for isServiceActiveReturn
Sourceimpl Default for isServiceActiveReturn
impl Default for isServiceActiveReturn
Sourcefn default() -> isServiceActiveReturn
fn default() -> isServiceActiveReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isServiceActiveReturn
impl<'de> Deserialize<'de> for isServiceActiveReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isServiceActiveReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isServiceActiveReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for isServiceActiveReturn
Sourceimpl Hash for isServiceActiveReturn
impl Hash for isServiceActiveReturn
Sourceimpl PartialEq for isServiceActiveReturn
impl PartialEq for isServiceActiveReturn
Sourcefn eq(&self, other: &isServiceActiveReturn) -> bool
fn eq(&self, other: &isServiceActiveReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for isServiceActiveReturn
impl Serialize for isServiceActiveReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for isServiceActiveReturn