pub struct isServiceOperatorReturn {
pub _0: bool,
}Expand description
Container type for the return parameters of the isServiceOperator(uint64,address) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for isServiceOperatorReturn
impl Clone for isServiceOperatorReturn
Sourcefn clone(&self) -> isServiceOperatorReturn
fn clone(&self) -> isServiceOperatorReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isServiceOperatorReturn
impl Debug for isServiceOperatorReturn
Sourceimpl Default for isServiceOperatorReturn
impl Default for isServiceOperatorReturn
Sourcefn default() -> isServiceOperatorReturn
fn default() -> isServiceOperatorReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isServiceOperatorReturn
impl<'de> Deserialize<'de> for isServiceOperatorReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isServiceOperatorReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isServiceOperatorReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for isServiceOperatorReturn
Sourceimpl Hash for isServiceOperatorReturn
impl Hash for isServiceOperatorReturn
Sourceimpl PartialEq for isServiceOperatorReturn
impl PartialEq for isServiceOperatorReturn
Sourcefn eq(&self, other: &isServiceOperatorReturn) -> bool
fn eq(&self, other: &isServiceOperatorReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for isServiceOperatorReturn
impl Serialize for isServiceOperatorReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for isServiceOperatorReturn