pub struct registerOperator_1Call {
pub blueprintId: u64,
pub ecdsaPublicKey: Bytes,
pub rpcAddress: String,
}Expand description
Function with signature registerOperator(uint64,bytes,string) and selector 0xd4e1ab7c.
function registerOperator(uint64 blueprintId, bytes memory ecdsaPublicKey, string memory rpcAddress) external;Fields
blueprintId: u64ecdsaPublicKey: BytesrpcAddress: StringTrait Implementations
Sourceimpl Clone for registerOperator_1Call
impl Clone for registerOperator_1Call
Sourcefn clone(&self) -> registerOperator_1Call
fn clone(&self) -> registerOperator_1Call
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for registerOperator_1Call
impl Debug for registerOperator_1Call
Sourceimpl Default for registerOperator_1Call
impl Default for registerOperator_1Call
Sourcefn default() -> registerOperator_1Call
fn default() -> registerOperator_1Call
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for registerOperator_1Call
impl<'de> Deserialize<'de> for registerOperator_1Call
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<registerOperator_1Call, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<registerOperator_1Call, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for registerOperator_1Call
Sourceimpl Hash for registerOperator_1Call
impl Hash for registerOperator_1Call
Sourceimpl PartialEq for registerOperator_1Call
impl PartialEq for registerOperator_1Call
Sourcefn eq(&self, other: ®isterOperator_1Call) -> bool
fn eq(&self, other: ®isterOperator_1Call) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for registerOperator_1Call
impl Serialize for registerOperator_1Call
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for registerOperator_1Call
impl SolCall for registerOperator_1Call
Sourceconst SIGNATURE: &'static str = "registerOperator(uint64,bytes,string)"
const SIGNATURE: &'static str = "registerOperator(uint64,bytes,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Bytes, String)
type Parameters<'a> = (Uint<64>, Bytes, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<registerOperator_1Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<registerOperator_1Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = registerOperator_1Return
type Return = registerOperator_1Return
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<registerOperator_1Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<registerOperator_1Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<registerOperator_1Call as SolCall>::Parameters<'a> as SolType>::RustType,
) -> registerOperator_1Call
fn new<'a>( tuple: <<registerOperator_1Call as SolCall>::Parameters<'a> as SolType>::RustType, ) -> registerOperator_1Call
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <registerOperator_1Call as SolCall>::Token<'_>
fn tokenize(&self) -> <registerOperator_1Call as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<registerOperator_1Call as SolCall>::Return,
) -> <registerOperator_1Call as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<registerOperator_1Call as SolCall>::Return, ) -> <registerOperator_1Call as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<registerOperator_1Call as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<registerOperator_1Call as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<registerOperator_1Call as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<registerOperator_1Call as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for registerOperator_1Call