pub struct submitJobReturn {
pub callId: u64,
}Expand description
Container type for the return parameters of the submitJob(uint64,uint8,bytes) function.
Fields
callId: u64Trait Implementations
Sourceimpl Clone for submitJobReturn
impl Clone for submitJobReturn
Sourcefn clone(&self) -> submitJobReturn
fn clone(&self) -> submitJobReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for submitJobReturn
impl Debug for submitJobReturn
Sourceimpl Default for submitJobReturn
impl Default for submitJobReturn
Sourcefn default() -> submitJobReturn
fn default() -> submitJobReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for submitJobReturn
impl<'de> Deserialize<'de> for submitJobReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<submitJobReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<submitJobReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for submitJobReturn
Sourceimpl Hash for submitJobReturn
impl Hash for submitJobReturn
Sourceimpl PartialEq for submitJobReturn
impl PartialEq for submitJobReturn
Sourcefn eq(&self, other: &submitJobReturn) -> bool
fn eq(&self, other: &submitJobReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for submitJobReturn
impl Serialize for submitJobReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for submitJobReturn