pub struct teeNonceForReturn {
pub _0: FixedBytes<32>,
}Expand description
Container type for the return parameters of the teeNonceFor(uint64) function.
Fields
_0: FixedBytes<32>Trait Implementations
Sourceimpl Clone for teeNonceForReturn
impl Clone for teeNonceForReturn
Sourcefn clone(&self) -> teeNonceForReturn
fn clone(&self) -> teeNonceForReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for teeNonceForReturn
impl Debug for teeNonceForReturn
Sourceimpl Default for teeNonceForReturn
impl Default for teeNonceForReturn
Sourcefn default() -> teeNonceForReturn
fn default() -> teeNonceForReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for teeNonceForReturn
impl<'de> Deserialize<'de> for teeNonceForReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<teeNonceForReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<teeNonceForReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for teeNonceForReturn
Sourceimpl Hash for teeNonceForReturn
impl Hash for teeNonceForReturn
Sourceimpl PartialEq for teeNonceForReturn
impl PartialEq for teeNonceForReturn
Sourcefn eq(&self, other: &teeNonceForReturn) -> bool
fn eq(&self, other: &teeNonceForReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for teeNonceForReturn
impl Serialize for teeNonceForReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for teeNonceForReturn