pub struct getServiceResourceCommitmentHashReturn {
pub _0: FixedBytes<32>,
}Expand description
Container type for the return parameters of the getServiceResourceCommitmentHash(uint64,address) function.
Fields
_0: FixedBytes<32>Trait Implementations
Sourceimpl Clone for getServiceResourceCommitmentHashReturn
impl Clone for getServiceResourceCommitmentHashReturn
Sourcefn clone(&self) -> getServiceResourceCommitmentHashReturn
fn clone(&self) -> getServiceResourceCommitmentHashReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getServiceResourceCommitmentHashReturn
impl Default for getServiceResourceCommitmentHashReturn
Sourcefn default() -> getServiceResourceCommitmentHashReturn
fn default() -> getServiceResourceCommitmentHashReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getServiceResourceCommitmentHashReturn
impl<'de> Deserialize<'de> for getServiceResourceCommitmentHashReturn
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceResourceCommitmentHashReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getServiceResourceCommitmentHashReturn, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getServiceResourceCommitmentHashReturn
Sourceimpl PartialEq for getServiceResourceCommitmentHashReturn
impl PartialEq for getServiceResourceCommitmentHashReturn
Sourcefn eq(&self, other: &getServiceResourceCommitmentHashReturn) -> bool
fn eq(&self, other: &getServiceResourceCommitmentHashReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getServiceResourceCommitmentHashReturn
impl Serialize for getServiceResourceCommitmentHashReturn
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for getServiceResourceCommitmentHashReturn