pub struct ApprovalParams {
pub requestId: u64,
pub securityCommitments: Vec<<AssetSecurityCommitment as SolType>::RustType>,
pub blsPubkey: [Uint<256, 4>; 4],
pub blsPopSignature: [Uint<256, 4>; 2],
pub teeCommitments: Vec<<TeeAttestationCommitment as SolType>::RustType>,
}Expand description
struct ApprovalParams { uint64 requestId; AssetSecurityCommitment[] securityCommitments; uint256[4] blsPubkey; uint256[2] blsPopSignature; TeeAttestationCommitment[] teeCommitments; }Fields
requestId: u64securityCommitments: Vec<<AssetSecurityCommitment as SolType>::RustType>blsPubkey: [Uint<256, 4>; 4]blsPopSignature: [Uint<256, 4>; 2]teeCommitments: Vec<<TeeAttestationCommitment as SolType>::RustType>Trait Implementations
Sourceimpl Clone for ApprovalParams
impl Clone for ApprovalParams
Sourcefn clone(&self) -> ApprovalParams
fn clone(&self) -> ApprovalParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApprovalParams
impl Debug for ApprovalParams
Sourceimpl Default for ApprovalParams
impl Default for ApprovalParams
Sourcefn default() -> ApprovalParams
fn default() -> ApprovalParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ApprovalParams
impl<'de> Deserialize<'de> for ApprovalParams
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ApprovalParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ApprovalParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ApprovalParams
Sourceimpl EventTopic for ApprovalParams
impl EventTopic for ApprovalParams
Sourcefn topic_preimage_length(rust: &<ApprovalParams as SolType>::RustType) -> usize
fn topic_preimage_length(rust: &<ApprovalParams as SolType>::RustType) -> usize
The number of bytes this type occupies in another topic’s preimage,
usually a multiple of 32. Read more
Sourcefn encode_topic_preimage(
rust: &<ApprovalParams as SolType>::RustType,
out: &mut Vec<u8>,
)
fn encode_topic_preimage( rust: &<ApprovalParams as SolType>::RustType, out: &mut Vec<u8>, )
Encodes this type as preimage bytes which are then hashed in
complex types’
encode_topic. Read moreSourcefn encode_topic(rust: &<ApprovalParams as SolType>::RustType) -> WordToken
fn encode_topic(rust: &<ApprovalParams as SolType>::RustType) -> WordToken
Indexed event parameter encoding. Read more
Sourceimpl Hash for ApprovalParams
impl Hash for ApprovalParams
Sourceimpl PartialEq for ApprovalParams
impl PartialEq for ApprovalParams
Sourcefn eq(&self, other: &ApprovalParams) -> bool
fn eq(&self, other: &ApprovalParams) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ApprovalParams
impl Serialize for ApprovalParams
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolStruct for ApprovalParams
impl SolStruct for ApprovalParams
Sourcefn eip712_root_type() -> Cow<'static, str>
fn eip712_root_type() -> Cow<'static, str>
Return the root EIP-712 type. This type is used to construct the
encodeType string.Sourcefn eip712_components() -> Vec<Cow<'static, str>>
fn eip712_components() -> Vec<Cow<'static, str>>
Returns component EIP-712 types. These types are used to construct
the
encodeType string. These are the types of the struct’s fields,
and should not include the root type.Sourcefn eip712_encode_data(&self) -> Vec<u8> ⓘ
fn eip712_encode_data(&self) -> Vec<u8> ⓘ
Encodes this domain using EIP-712
encodeData.Sourcefn eip712_type_hash(&self) -> FixedBytes<32>
fn eip712_type_hash(&self) -> FixedBytes<32>
Calculates the EIP-712
typeHash
for this struct. Read moreSourcefn eip712_hash_struct(&self) -> FixedBytes<32>
fn eip712_hash_struct(&self) -> FixedBytes<32>
Calculates the EIP-712
hashStruct for this value.Sourcefn eip712_signing_hash(&self, domain: &Eip712Domain) -> FixedBytes<32>
fn eip712_signing_hash(&self, domain: &Eip712Domain) -> FixedBytes<32>
Calculate the EIP-712 signing hash
for this struct.
Note that this does not sign the hash, only calculates it. Read more
Sourceimpl SolType for ApprovalParams
impl SolType for ApprovalParams
Sourceconst SOL_NAME: &'static str = <Self as alloy_sol_types::SolStruct>::NAME
const SOL_NAME: &'static str = <Self as alloy_sol_types::SolStruct>::NAME
The name of this type in Solidity.
Sourceconst ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::ENCODED_SIZE
const ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::ENCODED_SIZE
The statically-known ABI-encoded size of the type. Read more
Sourceconst PACKED_ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::PACKED_ENCODED_SIZE
const PACKED_ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::PACKED_ENCODED_SIZE
The statically-known Non-standard Packed Mode ABI-encoded size of the type. Read more
Sourcetype RustType = ApprovalParams
type RustType = ApprovalParams
The corresponding Rust type.
Sourcetype Token<'a> = <(Uint<64>, Array<AssetSecurityCommitment>, FixedArray<Uint<256>, 4>, FixedArray<Uint<256>, 2>, Array<TeeAttestationCommitment>) as SolType>::Token<'a>
type Token<'a> = <(Uint<64>, Array<AssetSecurityCommitment>, FixedArray<Uint<256>, 4>, FixedArray<Uint<256>, 2>, Array<TeeAttestationCommitment>) as SolType>::Token<'a>
The corresponding ABI token type. Read more
Sourcefn valid_token(token: &<ApprovalParams as SolType>::Token<'_>) -> bool
fn valid_token(token: &<ApprovalParams as SolType>::Token<'_>) -> bool
Returns
true if the given token can be detokenized with this type.Sourcefn detokenize(
token: <ApprovalParams as SolType>::Token<'_>,
) -> <ApprovalParams as SolType>::RustType
fn detokenize( token: <ApprovalParams as SolType>::Token<'_>, ) -> <ApprovalParams as SolType>::RustType
Detokenize this type’s value from the given token. Read more
Sourcefn abi_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
Calculate the ABI-encoded size of the data, counting both head and tail
words. For a single-word type this will always be 32.
Sourcefn type_check(token: &Self::Token<'_>) -> Result<(), Error>
fn type_check(token: &Self::Token<'_>) -> Result<(), Error>
Returns an error if the given token cannot be detokenized with this
type.
Sourcefn tokenize<E>(rust: &E) -> Self::Token<'_>where
E: SolTypeValue<Self> + ?Sized,
fn tokenize<E>(rust: &E) -> Self::Token<'_>where
E: SolTypeValue<Self> + ?Sized,
Tokenizes the given value into this type’s token. Read more
Sourcefn eip712_data_word<E>(rust: &E) -> FixedBytes<32>where
E: SolTypeValue<Self> + ?Sized,
fn eip712_data_word<E>(rust: &E) -> FixedBytes<32>where
E: SolTypeValue<Self> + ?Sized,
Encode this data according to EIP-712
encodeData rules, and hash it
if necessary. Read moreSourcefn abi_packed_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_packed_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
Returns the length of this value when ABI-encoded in Non-standard Packed Mode. Read more
Sourcefn abi_encode_packed_to<E>(rust: &E, out: &mut Vec<u8>)where
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed_to<E>(rust: &E, out: &mut Vec<u8>)where
E: SolTypeValue<Self> + ?Sized,
Non-standard Packed Mode ABI encoding. Read more
Sourcefn abi_encode_packed<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Non-standard Packed Mode ABI encoding. Read more
Sourcefn abi_encode<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Tokenizes and ABI-encodes the given value by wrapping it in a
single-element sequence. Read more
Sourcefn abi_encode_params<E>(rust: &E) -> Vec<u8> ⓘ
fn abi_encode_params<E>(rust: &E) -> Vec<u8> ⓘ
Tokenizes and ABI-encodes the given value as function parameters. Read more
Sourcefn abi_encode_sequence<E>(rust: &E) -> Vec<u8> ⓘ
fn abi_encode_sequence<E>(rust: &E) -> Vec<u8> ⓘ
Tokenizes and ABI-encodes the given value as a sequence. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode(data: &[u8]) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as a
single-element sequence. Read more
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as
single-element sequence, with validation. Read more
Sourcefn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as
function parameters. Read more
Sourcefn abi_decode_params_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>
fn abi_decode_params_validate<'de>( data: &'de [u8], ) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as
function parameters, with validation. Read more
Sourceimpl SolValue for ApprovalParams
impl SolValue for ApprovalParams
Sourcetype SolType = ApprovalParams
type SolType = ApprovalParams
The Solidity type that this type corresponds to.
Sourcefn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>
fn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>
Tokenizes the given value into this type’s token. Read more
Sourcefn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Self
fn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Self
Detokenize a value from the given token. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Calculate the ABI-encoded size of the data. Read more
Sourcefn eip712_data_word(&self) -> FixedBytes<32>
fn eip712_data_word(&self) -> FixedBytes<32>
Encode this data according to EIP-712
encodeData rules, and hash it
if necessary. Read moreSourcefn abi_encode_packed_to(&self, out: &mut Vec<u8>)
fn abi_encode_packed_to(&self, out: &mut Vec<u8>)
Non-standard Packed Mode ABI encoding. Read more
Sourcefn abi_encode_params(&self) -> Vec<u8> ⓘ
fn abi_encode_params(&self) -> Vec<u8> ⓘ
Encodes an ABI sequence suitable for function parameters. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI-decode this type from the given data. Read more
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI-decode this type from the given data, with validation. Read more
Sourcefn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>
ABI-decode this type from the given data. Read more
Sourcefn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>
fn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>
ABI-decode this type from the given data, with validation. Read more
impl StructuralPartialEq for ApprovalParams