pub struct BlueprintArchitecture(/* private fields */);Implementations
Sourceimpl BlueprintArchitecture
impl BlueprintArchitecture
Sourcepub const fn from_underlying(value: u8) -> BlueprintArchitecture
pub const fn from_underlying(value: u8) -> BlueprintArchitecture
Convert from the underlying value type.
Sourcepub const fn into_underlying(self) -> u8
pub const fn into_underlying(self) -> u8
Return the underlying value.
Sourcepub fn abi_encode(&self) -> Vec<u8> ⓘ
pub fn abi_encode(&self) -> Vec<u8> ⓘ
Return the single encoding of this value, delegating to the underlying type.
Sourcepub fn abi_encode_packed(&self) -> Vec<u8> ⓘ
pub fn abi_encode_packed(&self) -> Vec<u8> ⓘ
Return the packed encoding of this value, delegating to the underlying type.