pub struct BlueprintSource {
pub kind: <BlueprintSourceKind as SolType>::RustType,
pub container: <ImageRegistrySource as SolType>::RustType,
pub wasm: <WasmSource as SolType>::RustType,
pub native: <NativeSource as SolType>::RustType,
pub testing: <TestingSource as SolType>::RustType,
pub binaries: Vec<<BlueprintBinary as SolType>::RustType>,
}Expand description
struct BlueprintSource { BlueprintSourceKind kind; ImageRegistrySource container; WasmSource wasm; NativeSource native; TestingSource testing; BlueprintBinary[] binaries; }Fields
kind: <BlueprintSourceKind as SolType>::RustTypecontainer: <ImageRegistrySource as SolType>::RustTypewasm: <WasmSource as SolType>::RustTypenative: <NativeSource as SolType>::RustTypetesting: <TestingSource as SolType>::RustTypebinaries: Vec<<BlueprintBinary as SolType>::RustType>Trait Implementations
Sourceimpl Clone for BlueprintSource
impl Clone for BlueprintSource
Sourcefn clone(&self) -> BlueprintSource
fn clone(&self) -> BlueprintSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlueprintSource
impl Debug for BlueprintSource
Sourceimpl Default for BlueprintSource
impl Default for BlueprintSource
Sourcefn default() -> BlueprintSource
fn default() -> BlueprintSource
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BlueprintSource
impl<'de> Deserialize<'de> for BlueprintSource
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BlueprintSource, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BlueprintSource, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EventTopic for BlueprintSource
impl EventTopic for BlueprintSource
Sourcefn topic_preimage_length(rust: &<BlueprintSource as SolType>::RustType) -> usize
fn topic_preimage_length(rust: &<BlueprintSource as SolType>::RustType) -> usize
The number of bytes this type occupies in another topic’s preimage,
usually a multiple of 32. Read more
Sourcefn encode_topic_preimage(
rust: &<BlueprintSource as SolType>::RustType,
out: &mut Vec<u8>,
)
fn encode_topic_preimage( rust: &<BlueprintSource as SolType>::RustType, out: &mut Vec<u8>, )
Encodes this type as preimage bytes which are then hashed in
complex types’
encode_topic. Read moreSourcefn encode_topic(rust: &<BlueprintSource as SolType>::RustType) -> WordToken
fn encode_topic(rust: &<BlueprintSource as SolType>::RustType) -> WordToken
Indexed event parameter encoding. Read more
Sourceimpl Hash for BlueprintSource
impl Hash for BlueprintSource
Sourceimpl PartialEq for BlueprintSource
impl PartialEq for BlueprintSource
Sourceimpl Serialize for BlueprintSource
impl Serialize for BlueprintSource
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolStruct for BlueprintSource
impl SolStruct for BlueprintSource
Sourcefn eip712_root_type() -> Cow<'static, str>
fn eip712_root_type() -> Cow<'static, str>
Return the root EIP-712 type. This type is used to construct the
encodeType string.Sourcefn eip712_components() -> Vec<Cow<'static, str>>
fn eip712_components() -> Vec<Cow<'static, str>>
Returns component EIP-712 types. These types are used to construct
the
encodeType string. These are the types of the struct’s fields,
and should not include the root type.Sourcefn eip712_encode_data(&self) -> Vec<u8> ⓘ
fn eip712_encode_data(&self) -> Vec<u8> ⓘ
Encodes this domain using EIP-712
encodeData.Sourcefn eip712_type_hash(&self) -> FixedBytes<32>
fn eip712_type_hash(&self) -> FixedBytes<32>
Calculates the EIP-712
typeHash
for this struct. Read moreSourcefn eip712_hash_struct(&self) -> FixedBytes<32>
fn eip712_hash_struct(&self) -> FixedBytes<32>
Calculates the EIP-712
hashStruct for this value.Sourcefn eip712_signing_hash(&self, domain: &Eip712Domain) -> FixedBytes<32>
fn eip712_signing_hash(&self, domain: &Eip712Domain) -> FixedBytes<32>
Calculate the EIP-712 signing hash
for this struct.
Note that this does not sign the hash, only calculates it. Read more
Sourceimpl SolType for BlueprintSource
impl SolType for BlueprintSource
Sourceconst SOL_NAME: &'static str = <Self as alloy_sol_types::SolStruct>::NAME
const SOL_NAME: &'static str = <Self as alloy_sol_types::SolStruct>::NAME
The name of this type in Solidity.
Sourceconst ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::ENCODED_SIZE
const ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::ENCODED_SIZE
The statically-known ABI-encoded size of the type. Read more
Sourceconst PACKED_ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::PACKED_ENCODED_SIZE
const PACKED_ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::PACKED_ENCODED_SIZE
The statically-known Non-standard Packed Mode ABI-encoded size of the type. Read more
Sourcetype RustType = BlueprintSource
type RustType = BlueprintSource
The corresponding Rust type.
Sourcetype Token<'a> = <(BlueprintSourceKind, ImageRegistrySource, WasmSource, NativeSource, TestingSource, Array<BlueprintBinary>) as SolType>::Token<'a>
type Token<'a> = <(BlueprintSourceKind, ImageRegistrySource, WasmSource, NativeSource, TestingSource, Array<BlueprintBinary>) as SolType>::Token<'a>
The corresponding ABI token type. Read more
Sourcefn valid_token(token: &<BlueprintSource as SolType>::Token<'_>) -> bool
fn valid_token(token: &<BlueprintSource as SolType>::Token<'_>) -> bool
Returns
true if the given token can be detokenized with this type.Sourcefn detokenize(
token: <BlueprintSource as SolType>::Token<'_>,
) -> <BlueprintSource as SolType>::RustType
fn detokenize( token: <BlueprintSource as SolType>::Token<'_>, ) -> <BlueprintSource as SolType>::RustType
Detokenize this type’s value from the given token. Read more
Sourcefn abi_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
Calculate the ABI-encoded size of the data, counting both head and tail
words. For a single-word type this will always be 32.
Sourcefn type_check(token: &Self::Token<'_>) -> Result<(), Error>
fn type_check(token: &Self::Token<'_>) -> Result<(), Error>
Returns an error if the given token cannot be detokenized with this
type.
Sourcefn tokenize<E>(rust: &E) -> Self::Token<'_>where
E: SolTypeValue<Self> + ?Sized,
fn tokenize<E>(rust: &E) -> Self::Token<'_>where
E: SolTypeValue<Self> + ?Sized,
Tokenizes the given value into this type’s token. Read more
Sourcefn eip712_data_word<E>(rust: &E) -> FixedBytes<32>where
E: SolTypeValue<Self> + ?Sized,
fn eip712_data_word<E>(rust: &E) -> FixedBytes<32>where
E: SolTypeValue<Self> + ?Sized,
Encode this data according to EIP-712
encodeData rules, and hash it
if necessary. Read moreSourcefn abi_packed_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_packed_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
Returns the length of this value when ABI-encoded in Non-standard Packed Mode. Read more
Sourcefn abi_encode_packed_to<E>(rust: &E, out: &mut Vec<u8>)where
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed_to<E>(rust: &E, out: &mut Vec<u8>)where
E: SolTypeValue<Self> + ?Sized,
Non-standard Packed Mode ABI encoding. Read more
Sourcefn abi_encode_packed<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Non-standard Packed Mode ABI encoding. Read more
Sourcefn abi_encode<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Tokenizes and ABI-encodes the given value by wrapping it in a
single-element sequence. Read more
Sourcefn abi_encode_params<E>(rust: &E) -> Vec<u8> ⓘ
fn abi_encode_params<E>(rust: &E) -> Vec<u8> ⓘ
Tokenizes and ABI-encodes the given value as function parameters. Read more
Sourcefn abi_encode_sequence<E>(rust: &E) -> Vec<u8> ⓘ
fn abi_encode_sequence<E>(rust: &E) -> Vec<u8> ⓘ
Tokenizes and ABI-encodes the given value as a sequence. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode(data: &[u8]) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as a
single-element sequence. Read more
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as
single-element sequence, with validation. Read more
Sourcefn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as
function parameters. Read more
Sourcefn abi_decode_params_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>
fn abi_decode_params_validate<'de>( data: &'de [u8], ) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as
function parameters, with validation. Read more
Sourceimpl SolValue for BlueprintSource
impl SolValue for BlueprintSource
Sourcetype SolType = BlueprintSource
type SolType = BlueprintSource
The Solidity type that this type corresponds to.
Sourcefn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>
fn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>
Tokenizes the given value into this type’s token. Read more
Sourcefn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Self
fn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Self
Detokenize a value from the given token. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Calculate the ABI-encoded size of the data. Read more
Sourcefn eip712_data_word(&self) -> FixedBytes<32>
fn eip712_data_word(&self) -> FixedBytes<32>
Encode this data according to EIP-712
encodeData rules, and hash it
if necessary. Read moreSourcefn abi_encode_packed_to(&self, out: &mut Vec<u8>)
fn abi_encode_packed_to(&self, out: &mut Vec<u8>)
Non-standard Packed Mode ABI encoding. Read more
Sourcefn abi_encode_params(&self) -> Vec<u8> ⓘ
fn abi_encode_params(&self) -> Vec<u8> ⓘ
Encodes an ABI sequence suitable for function parameters. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI-decode this type from the given data. Read more
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI-decode this type from the given data, with validation. Read more
Sourcefn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>
ABI-decode this type from the given data. Read more
Sourcefn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>
fn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>
ABI-decode this type from the given data, with validation. Read more
impl Eq for BlueprintSource
impl StructuralPartialEq for BlueprintSource