ServiceStatus

Struct ServiceStatus 

pub struct ServiceStatus(/* private fields */);

Implementations

Source

impl ServiceStatus

pub const NAME: &'static str = "@ name"

The Solidity type name.

pub const fn from_underlying(value: u8) -> ServiceStatus

Convert from the underlying value type.

pub const fn into_underlying(self) -> u8

Return the underlying value.

pub fn abi_encode(&self) -> Vec<u8>

Return the single encoding of this value, delegating to the underlying type.

pub fn abi_encode_packed(&self) -> Vec<u8>

Return the packed encoding of this value, delegating to the underlying type.