pub struct TypesInstance<P, N = Ethereum> { /* private fields */ }Expand description
A Types instance.
Contains type-safe methods for interacting with an on-chain instance of the
Types contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P, N> TypesInstance<P, N>
Instantiation and getters/setters.
impl<P, N> TypesInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> TypesInstance<P, N>
pub const fn new(address: Address, __provider: P) -> TypesInstance<P, N>
Creates a new wrapper around an on-chain Types contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourcepub fn at(self, address: Address) -> TypesInstance<P, N>
pub fn at(self, address: Address) -> TypesInstance<P, N>
Sets the address and returns self.
Sourceimpl<P, N> TypesInstance<&P, N>where
P: Clone,
impl<P, N> TypesInstance<&P, N>where
P: Clone,
Sourcepub fn with_cloned_provider(self) -> TypesInstance<P, N>
pub fn with_cloned_provider(self) -> TypesInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P, N> TypesInstance<P, N>
Function calls.
impl<P, N> TypesInstance<P, N>
Function calls.
Sourcepub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourceimpl<P, N> TypesInstance<P, N>
Event filters.
impl<P, N> TypesInstance<P, N>
Event filters.
Sourcepub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
pub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.