pub struct AddressEmptyCode {
pub target: Address,
}Expand description
Custom error with signature AddressEmptyCode(address) and selector 0x9996b315.
error AddressEmptyCode(address target);Fields
target: AddressTrait Implementations
Sourceimpl Clone for AddressEmptyCode
impl Clone for AddressEmptyCode
Sourcefn clone(&self) -> AddressEmptyCode
fn clone(&self) -> AddressEmptyCode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddressEmptyCode
impl Debug for AddressEmptyCode
Sourceimpl Default for AddressEmptyCode
impl Default for AddressEmptyCode
Sourcefn default() -> AddressEmptyCode
fn default() -> AddressEmptyCode
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AddressEmptyCode
impl<'de> Deserialize<'de> for AddressEmptyCode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AddressEmptyCode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AddressEmptyCode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AddressEmptyCode
Sourceimpl Hash for AddressEmptyCode
impl Hash for AddressEmptyCode
Sourceimpl PartialEq for AddressEmptyCode
impl PartialEq for AddressEmptyCode
Sourcefn eq(&self, other: &AddressEmptyCode) -> bool
fn eq(&self, other: &AddressEmptyCode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AddressEmptyCode
impl Serialize for AddressEmptyCode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolError for AddressEmptyCode
impl SolError for AddressEmptyCode
Sourcetype Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<AddressEmptyCode as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<AddressEmptyCode as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(
tuple: <<AddressEmptyCode as SolError>::Parameters<'a> as SolType>::RustType,
) -> AddressEmptyCode
fn new<'a>( tuple: <<AddressEmptyCode as SolError>::Parameters<'a> as SolType>::RustType, ) -> AddressEmptyCode
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <AddressEmptyCode as SolError>::Token<'_>
fn tokenize(&self) -> <AddressEmptyCode as SolError>::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<AddressEmptyCode, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<AddressEmptyCode, Error>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl StructuralPartialEq for AddressEmptyCode