pub struct InvalidInitialization;Expand description
Custom error with signature InvalidInitialization() and selector 0xf92ee8a9.
error InvalidInitialization();Trait Implementations
Sourceimpl Clone for InvalidInitialization
impl Clone for InvalidInitialization
Sourcefn clone(&self) -> InvalidInitialization
fn clone(&self) -> InvalidInitialization
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvalidInitialization
impl Debug for InvalidInitialization
Sourceimpl Default for InvalidInitialization
impl Default for InvalidInitialization
Sourcefn default() -> InvalidInitialization
fn default() -> InvalidInitialization
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InvalidInitialization
impl<'de> Deserialize<'de> for InvalidInitialization
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<InvalidInitialization, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<InvalidInitialization, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InvalidInitialization
Sourceimpl Hash for InvalidInitialization
impl Hash for InvalidInitialization
Sourceimpl PartialEq for InvalidInitialization
impl PartialEq for InvalidInitialization
Sourcefn eq(&self, other: &InvalidInitialization) -> bool
fn eq(&self, other: &InvalidInitialization) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InvalidInitialization
impl Serialize for InvalidInitialization
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolError for InvalidInitialization
impl SolError for InvalidInitialization
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<InvalidInitialization as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<InvalidInitialization as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(
tuple: <<InvalidInitialization as SolError>::Parameters<'a> as SolType>::RustType,
) -> InvalidInitialization
fn new<'a>( tuple: <<InvalidInitialization as SolError>::Parameters<'a> as SolType>::RustType, ) -> InvalidInitialization
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <InvalidInitialization as SolError>::Token<'_>
fn tokenize(&self) -> <InvalidInitialization as SolError>::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<InvalidInitialization, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<InvalidInitialization, Error>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl StructuralPartialEq for InvalidInitialization