pub struct NotInitializing;Expand description
Custom error with signature NotInitializing() and selector 0xd7e6bcf8.
error NotInitializing();Trait Implementations
Sourceimpl Clone for NotInitializing
impl Clone for NotInitializing
Sourcefn clone(&self) -> NotInitializing
fn clone(&self) -> NotInitializing
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotInitializing
impl Debug for NotInitializing
Sourceimpl Default for NotInitializing
impl Default for NotInitializing
Sourcefn default() -> NotInitializing
fn default() -> NotInitializing
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NotInitializing
impl<'de> Deserialize<'de> for NotInitializing
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<NotInitializing, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<NotInitializing, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NotInitializing
Sourceimpl Hash for NotInitializing
impl Hash for NotInitializing
Sourceimpl PartialEq for NotInitializing
impl PartialEq for NotInitializing
Sourcefn eq(&self, other: &NotInitializing) -> bool
fn eq(&self, other: &NotInitializing) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NotInitializing
impl Serialize for NotInitializing
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolError for NotInitializing
impl SolError for NotInitializing
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<NotInitializing as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<NotInitializing as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(
tuple: <<NotInitializing as SolError>::Parameters<'a> as SolType>::RustType,
) -> NotInitializing
fn new<'a>( tuple: <<NotInitializing as SolError>::Parameters<'a> as SolType>::RustType, ) -> NotInitializing
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <NotInitializing as SolError>::Token<'_>
fn tokenize(&self) -> <NotInitializing as SolError>::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<NotInitializing, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<NotInitializing, Error>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl StructuralPartialEq for NotInitializing