pub struct currentRoundCall;Expand description
Function with signature currentRound() and selector 0x8a19c8bc.
function currentRound() external view returns (uint64);Trait Implementations
Sourceimpl Clone for currentRoundCall
impl Clone for currentRoundCall
Sourcefn clone(&self) -> currentRoundCall
fn clone(&self) -> currentRoundCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for currentRoundCall
impl Debug for currentRoundCall
Sourceimpl Default for currentRoundCall
impl Default for currentRoundCall
Sourcefn default() -> currentRoundCall
fn default() -> currentRoundCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for currentRoundCall
impl<'de> Deserialize<'de> for currentRoundCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<currentRoundCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<currentRoundCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for currentRoundCall
Sourceimpl Hash for currentRoundCall
impl Hash for currentRoundCall
Sourceimpl PartialEq for currentRoundCall
impl PartialEq for currentRoundCall
Sourcefn eq(&self, other: ¤tRoundCall) -> bool
fn eq(&self, other: ¤tRoundCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for currentRoundCall
impl Serialize for currentRoundCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for currentRoundCall
impl SolCall for currentRoundCall
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<currentRoundCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<currentRoundCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<currentRoundCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<currentRoundCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<currentRoundCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> currentRoundCall
fn new<'a>( tuple: <<currentRoundCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> currentRoundCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<currentRoundCall as SolCall>::Return,
) -> <currentRoundCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<currentRoundCall as SolCall>::Return, ) -> <currentRoundCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<currentRoundCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<currentRoundCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<currentRoundCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<currentRoundCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for currentRoundCall