pub struct getOperatorSlashFactorCall {
pub operator: Address,
pub assetHash: FixedBytes<32>,
}Expand description
Function with signature getOperatorSlashFactor(address,bytes32) and selector 0x12d91c88.
function getOperatorSlashFactor(address operator, bytes32 assetHash) external view returns (uint256);Fields
operator: AddressassetHash: FixedBytes<32>Trait Implementations
Sourceimpl Clone for getOperatorSlashFactorCall
impl Clone for getOperatorSlashFactorCall
Sourcefn clone(&self) -> getOperatorSlashFactorCall
fn clone(&self) -> getOperatorSlashFactorCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getOperatorSlashFactorCall
impl Debug for getOperatorSlashFactorCall
Sourceimpl Default for getOperatorSlashFactorCall
impl Default for getOperatorSlashFactorCall
Sourcefn default() -> getOperatorSlashFactorCall
fn default() -> getOperatorSlashFactorCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getOperatorSlashFactorCall
impl<'de> Deserialize<'de> for getOperatorSlashFactorCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorSlashFactorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getOperatorSlashFactorCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for getOperatorSlashFactorCall
Sourceimpl Hash for getOperatorSlashFactorCall
impl Hash for getOperatorSlashFactorCall
Sourceimpl PartialEq for getOperatorSlashFactorCall
impl PartialEq for getOperatorSlashFactorCall
Sourcefn eq(&self, other: &getOperatorSlashFactorCall) -> bool
fn eq(&self, other: &getOperatorSlashFactorCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getOperatorSlashFactorCall
impl Serialize for getOperatorSlashFactorCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getOperatorSlashFactorCall
impl SolCall for getOperatorSlashFactorCall
Sourceconst SIGNATURE: &'static str = "getOperatorSlashFactor(address,bytes32)"
const SIGNATURE: &'static str = "getOperatorSlashFactor(address,bytes32)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, FixedBytes<32>)
type Parameters<'a> = (Address, FixedBytes<32>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getOperatorSlashFactorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getOperatorSlashFactorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getOperatorSlashFactorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getOperatorSlashFactorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getOperatorSlashFactorCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getOperatorSlashFactorCall
fn new<'a>( tuple: <<getOperatorSlashFactorCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getOperatorSlashFactorCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getOperatorSlashFactorCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getOperatorSlashFactorCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getOperatorSlashFactorCall as SolCall>::Return,
) -> <getOperatorSlashFactorCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getOperatorSlashFactorCall as SolCall>::Return, ) -> <getOperatorSlashFactorCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getOperatorSlashFactorCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getOperatorSlashFactorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getOperatorSlashFactorCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getOperatorSlashFactorCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for getOperatorSlashFactorCall