pub struct initializeCall {
pub admin: Address,
pub nativeMinOperatorStake: Uint<256, 4>,
pub nativeMinDelegation: Uint<256, 4>,
pub _operatorCommissionBps: u16,
}Expand description
Function with signature initialize(address,uint256,uint256,uint16) and selector 0xcbb6d6bd.
function initialize(address admin, uint256 nativeMinOperatorStake, uint256 nativeMinDelegation, uint16 _operatorCommissionBps) external;Fields
admin: AddressnativeMinOperatorStake: Uint<256, 4>nativeMinDelegation: Uint<256, 4>_operatorCommissionBps: u16Trait Implementations
Sourceimpl Clone for initializeCall
impl Clone for initializeCall
Sourcefn clone(&self) -> initializeCall
fn clone(&self) -> initializeCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for initializeCall
impl Debug for initializeCall
Sourceimpl Default for initializeCall
impl Default for initializeCall
Sourcefn default() -> initializeCall
fn default() -> initializeCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for initializeCall
impl<'de> Deserialize<'de> for initializeCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<initializeCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<initializeCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for initializeCall
Sourceimpl Hash for initializeCall
impl Hash for initializeCall
Sourceimpl PartialEq for initializeCall
impl PartialEq for initializeCall
Sourcefn eq(&self, other: &initializeCall) -> bool
fn eq(&self, other: &initializeCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for initializeCall
impl Serialize for initializeCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for initializeCall
impl SolCall for initializeCall
Sourceconst SIGNATURE: &'static str = "initialize(address,uint256,uint256,uint16)"
const SIGNATURE: &'static str = "initialize(address,uint256,uint256,uint16)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<256>, Uint<256>, Uint<16>)
type Parameters<'a> = (Address, Uint<256>, Uint<256>, Uint<16>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<initializeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<initializeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = initializeReturn
type Return = initializeReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<initializeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<initializeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<initializeCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> initializeCall
fn new<'a>( tuple: <<initializeCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> initializeCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(
ret: &<initializeCall as SolCall>::Return,
) -> <initializeCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<initializeCall as SolCall>::Return, ) -> <initializeCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<initializeCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<initializeCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<initializeCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<initializeCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for initializeCall