pub struct IBlueprintServiceManagerInstance<P, N = Ethereum> { /* private fields */ }Expand description
A IBlueprintServiceManager instance.
Contains type-safe methods for interacting with an on-chain instance of the
IBlueprintServiceManager contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P, N> IBlueprintServiceManagerInstance<P, N>
Instantiation and getters/setters.
impl<P, N> IBlueprintServiceManagerInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(
address: Address,
__provider: P,
) -> IBlueprintServiceManagerInstance<P, N>
pub const fn new( address: Address, __provider: P, ) -> IBlueprintServiceManagerInstance<P, N>
Creates a new wrapper around an on-chain IBlueprintServiceManager contract instance.
See the wrapper’s documentation for more details.
Sourcepub async fn deploy(
__provider: P,
) -> Result<IBlueprintServiceManagerInstance<P, N>, Error>
pub async fn deploy( __provider: P, ) -> Result<IBlueprintServiceManagerInstance<P, N>, Error>
Deploys this contract using the given provider and constructor arguments, if any.
Returns a new instance of the contract, if the deployment was successful.
For more fine-grained control over the deployment process, use deploy_builder instead.
Sourcepub fn deploy_builder(__provider: P) -> CallBuilder<P, (), N>
pub fn deploy_builder(__provider: P) -> CallBuilder<P, (), N>
Creates a RawCallBuilder for deploying this contract using the given provider
and constructor arguments, if any.
This is a simple wrapper around creating a RawCallBuilder with the data set to
the bytecode concatenated with the constructor’s ABI-encoded arguments.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourcepub fn at(self, address: Address) -> IBlueprintServiceManagerInstance<P, N>
pub fn at(self, address: Address) -> IBlueprintServiceManagerInstance<P, N>
Sets the address and returns self.
Sourceimpl<P, N> IBlueprintServiceManagerInstance<&P, N>where
P: Clone,
impl<P, N> IBlueprintServiceManagerInstance<&P, N>where
P: Clone,
Sourcepub fn with_cloned_provider(self) -> IBlueprintServiceManagerInstance<P, N>
pub fn with_cloned_provider(self) -> IBlueprintServiceManagerInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P, N> IBlueprintServiceManagerInstance<P, N>
Function calls.
impl<P, N> IBlueprintServiceManagerInstance<P, N>
Function calls.
Sourcepub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn canJoin(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<canJoinCall>, N>
pub fn canJoin( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<canJoinCall>, N>
Creates a new call builder for the [canJoin] function.
Sourcepub fn canLeave(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<canLeaveCall>, N>
pub fn canLeave( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<canLeaveCall>, N>
Creates a new call builder for the [canLeave] function.
Sourcepub fn computeBillAdjustmentBps(
&self,
serviceId: u64,
periodStart: u64,
periodEnd: u64,
) -> CallBuilder<&P, PhantomData<computeBillAdjustmentBpsCall>, N>
pub fn computeBillAdjustmentBps( &self, serviceId: u64, periodStart: u64, periodEnd: u64, ) -> CallBuilder<&P, PhantomData<computeBillAdjustmentBpsCall>, N>
Creates a new call builder for the [computeBillAdjustmentBps] function.
Sourcepub fn forceRemoveAllowsBelowMin(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<forceRemoveAllowsBelowMinCall>, N>
pub fn forceRemoveAllowsBelowMin( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<forceRemoveAllowsBelowMinCall>, N>
Creates a new call builder for the [forceRemoveAllowsBelowMin] function.
Sourcepub fn getAggregationThreshold(
&self,
serviceId: u64,
jobIndex: u8,
) -> CallBuilder<&P, PhantomData<getAggregationThresholdCall>, N>
pub fn getAggregationThreshold( &self, serviceId: u64, jobIndex: u8, ) -> CallBuilder<&P, PhantomData<getAggregationThresholdCall>, N>
Creates a new call builder for the [getAggregationThreshold] function.
Sourcepub fn getExitConfig(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getExitConfigCall>, N>
pub fn getExitConfig( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getExitConfigCall>, N>
Creates a new call builder for the [getExitConfig] function.
Sourcepub fn getHeartbeatInterval(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getHeartbeatIntervalCall>, N>
pub fn getHeartbeatInterval( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getHeartbeatIntervalCall>, N>
Creates a new call builder for the [getHeartbeatInterval] function.
Sourcepub fn getHeartbeatThreshold(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getHeartbeatThresholdCall>, N>
pub fn getHeartbeatThreshold( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getHeartbeatThresholdCall>, N>
Creates a new call builder for the [getHeartbeatThreshold] function.
Sourcepub fn getMinOperatorStake(
&self,
) -> CallBuilder<&P, PhantomData<getMinOperatorStakeCall>, N>
pub fn getMinOperatorStake( &self, ) -> CallBuilder<&P, PhantomData<getMinOperatorStakeCall>, N>
Creates a new call builder for the [getMinOperatorStake] function.
Sourcepub fn getNonPaymentTerminationPolicy(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getNonPaymentTerminationPolicyCall>, N>
pub fn getNonPaymentTerminationPolicy( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getNonPaymentTerminationPolicyCall>, N>
Creates a new call builder for the [getNonPaymentTerminationPolicy] function.
Sourcepub fn getRequiredResultCount(
&self,
serviceId: u64,
jobIndex: u8,
) -> CallBuilder<&P, PhantomData<getRequiredResultCountCall>, N>
pub fn getRequiredResultCount( &self, serviceId: u64, jobIndex: u8, ) -> CallBuilder<&P, PhantomData<getRequiredResultCountCall>, N>
Creates a new call builder for the [getRequiredResultCount] function.
Sourcepub fn getSlashingWindow(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getSlashingWindowCall>, N>
pub fn getSlashingWindow( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getSlashingWindowCall>, N>
Creates a new call builder for the [getSlashingWindow] function.
Sourcepub fn onAggregatedResult(
&self,
serviceId: u64,
job: u8,
jobCallId: u64,
output: Bytes,
signerBitmap: Uint<256, 4>,
aggregatedSignature: [Uint<256, 4>; 2],
aggregatedPubkey: [Uint<256, 4>; 4],
) -> CallBuilder<&P, PhantomData<onAggregatedResultCall>, N>
pub fn onAggregatedResult( &self, serviceId: u64, job: u8, jobCallId: u64, output: Bytes, signerBitmap: Uint<256, 4>, aggregatedSignature: [Uint<256, 4>; 2], aggregatedPubkey: [Uint<256, 4>; 4], ) -> CallBuilder<&P, PhantomData<onAggregatedResultCall>, N>
Creates a new call builder for the [onAggregatedResult] function.
Sourcepub fn onApprove(
&self,
operator: Address,
requestId: u64,
stakingPercent: u8,
) -> CallBuilder<&P, PhantomData<onApproveCall>, N>
pub fn onApprove( &self, operator: Address, requestId: u64, stakingPercent: u8, ) -> CallBuilder<&P, PhantomData<onApproveCall>, N>
Creates a new call builder for the [onApprove] function.
Sourcepub fn onBlueprintCreated(
&self,
blueprintId: u64,
owner: Address,
tangleCore: Address,
) -> CallBuilder<&P, PhantomData<onBlueprintCreatedCall>, N>
pub fn onBlueprintCreated( &self, blueprintId: u64, owner: Address, tangleCore: Address, ) -> CallBuilder<&P, PhantomData<onBlueprintCreatedCall>, N>
Creates a new call builder for the [onBlueprintCreated] function.
Sourcepub fn onExitCanceled(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<onExitCanceledCall>, N>
pub fn onExitCanceled( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<onExitCanceledCall>, N>
Creates a new call builder for the [onExitCanceled] function.
Sourcepub fn onExitScheduled(
&self,
serviceId: u64,
operator: Address,
executeAfter: u64,
) -> CallBuilder<&P, PhantomData<onExitScheduledCall>, N>
pub fn onExitScheduled( &self, serviceId: u64, operator: Address, executeAfter: u64, ) -> CallBuilder<&P, PhantomData<onExitScheduledCall>, N>
Creates a new call builder for the [onExitScheduled] function.
Sourcepub fn onJobCall(
&self,
serviceId: u64,
job: u8,
jobCallId: u64,
inputs: Bytes,
) -> CallBuilder<&P, PhantomData<onJobCallCall>, N>
pub fn onJobCall( &self, serviceId: u64, job: u8, jobCallId: u64, inputs: Bytes, ) -> CallBuilder<&P, PhantomData<onJobCallCall>, N>
Creates a new call builder for the [onJobCall] function.
Sourcepub fn onJobResult(
&self,
serviceId: u64,
job: u8,
jobCallId: u64,
operator: Address,
inputs: Bytes,
outputs: Bytes,
) -> CallBuilder<&P, PhantomData<onJobResultCall>, N>
pub fn onJobResult( &self, serviceId: u64, job: u8, jobCallId: u64, operator: Address, inputs: Bytes, outputs: Bytes, ) -> CallBuilder<&P, PhantomData<onJobResultCall>, N>
Creates a new call builder for the [onJobResult] function.
Sourcepub fn onOperatorJoined(
&self,
serviceId: u64,
operator: Address,
exposureBps: u16,
) -> CallBuilder<&P, PhantomData<onOperatorJoinedCall>, N>
pub fn onOperatorJoined( &self, serviceId: u64, operator: Address, exposureBps: u16, ) -> CallBuilder<&P, PhantomData<onOperatorJoinedCall>, N>
Creates a new call builder for the [onOperatorJoined] function.
Sourcepub fn onOperatorLeft(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<onOperatorLeftCall>, N>
pub fn onOperatorLeft( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<onOperatorLeftCall>, N>
Creates a new call builder for the [onOperatorLeft] function.
Sourcepub fn onRegister(
&self,
operator: Address,
registrationInputs: Bytes,
) -> CallBuilder<&P, PhantomData<onRegisterCall>, N>
pub fn onRegister( &self, operator: Address, registrationInputs: Bytes, ) -> CallBuilder<&P, PhantomData<onRegisterCall>, N>
Creates a new call builder for the [onRegister] function.
Sourcepub fn onReject(
&self,
operator: Address,
requestId: u64,
) -> CallBuilder<&P, PhantomData<onRejectCall>, N>
pub fn onReject( &self, operator: Address, requestId: u64, ) -> CallBuilder<&P, PhantomData<onRejectCall>, N>
Creates a new call builder for the [onReject] function.
Sourcepub fn onRequest(
&self,
requestId: u64,
requester: Address,
operators: Vec<Address>,
requestInputs: Bytes,
ttl: u64,
paymentAsset: Address,
paymentAmount: Uint<256, 4>,
) -> CallBuilder<&P, PhantomData<onRequestCall>, N>
pub fn onRequest( &self, requestId: u64, requester: Address, operators: Vec<Address>, requestInputs: Bytes, ttl: u64, paymentAsset: Address, paymentAmount: Uint<256, 4>, ) -> CallBuilder<&P, PhantomData<onRequestCall>, N>
Creates a new call builder for the [onRequest] function.
Sourcepub fn onServiceInitialized(
&self,
blueprintId: u64,
requestId: u64,
serviceId: u64,
owner: Address,
permittedCallers: Vec<Address>,
ttl: u64,
) -> CallBuilder<&P, PhantomData<onServiceInitializedCall>, N>
pub fn onServiceInitialized( &self, blueprintId: u64, requestId: u64, serviceId: u64, owner: Address, permittedCallers: Vec<Address>, ttl: u64, ) -> CallBuilder<&P, PhantomData<onServiceInitializedCall>, N>
Creates a new call builder for the [onServiceInitialized] function.
Sourcepub fn onServiceTermination(
&self,
serviceId: u64,
owner: Address,
) -> CallBuilder<&P, PhantomData<onServiceTerminationCall>, N>
pub fn onServiceTermination( &self, serviceId: u64, owner: Address, ) -> CallBuilder<&P, PhantomData<onServiceTerminationCall>, N>
Creates a new call builder for the [onServiceTermination] function.
Sourcepub fn onSlash(
&self,
serviceId: u64,
offender: Bytes,
slashPercent: u8,
) -> CallBuilder<&P, PhantomData<onSlashCall>, N>
pub fn onSlash( &self, serviceId: u64, offender: Bytes, slashPercent: u8, ) -> CallBuilder<&P, PhantomData<onSlashCall>, N>
Creates a new call builder for the [onSlash] function.
Sourcepub fn onUnappliedSlash(
&self,
serviceId: u64,
offender: Bytes,
slashPercent: u8,
) -> CallBuilder<&P, PhantomData<onUnappliedSlashCall>, N>
pub fn onUnappliedSlash( &self, serviceId: u64, offender: Bytes, slashPercent: u8, ) -> CallBuilder<&P, PhantomData<onUnappliedSlashCall>, N>
Creates a new call builder for the [onUnappliedSlash] function.
Sourcepub fn onUnregister(
&self,
operator: Address,
) -> CallBuilder<&P, PhantomData<onUnregisterCall>, N>
pub fn onUnregister( &self, operator: Address, ) -> CallBuilder<&P, PhantomData<onUnregisterCall>, N>
Creates a new call builder for the [onUnregister] function.
Sourcepub fn onUpdatePreferences(
&self,
operator: Address,
newPreferences: Bytes,
) -> CallBuilder<&P, PhantomData<onUpdatePreferencesCall>, N>
pub fn onUpdatePreferences( &self, operator: Address, newPreferences: Bytes, ) -> CallBuilder<&P, PhantomData<onUpdatePreferencesCall>, N>
Creates a new call builder for the [onUpdatePreferences] function.
Sourcepub fn queryDeveloperPaymentAddress(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<queryDeveloperPaymentAddressCall>, N>
pub fn queryDeveloperPaymentAddress( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<queryDeveloperPaymentAddressCall>, N>
Creates a new call builder for the [queryDeveloperPaymentAddress] function.
Sourcepub fn queryDisputeOrigin(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<queryDisputeOriginCall>, N>
pub fn queryDisputeOrigin( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<queryDisputeOriginCall>, N>
Creates a new call builder for the [queryDisputeOrigin] function.
Sourcepub fn queryIsPaymentAssetAllowed(
&self,
serviceId: u64,
asset: Address,
) -> CallBuilder<&P, PhantomData<queryIsPaymentAssetAllowedCall>, N>
pub fn queryIsPaymentAssetAllowed( &self, serviceId: u64, asset: Address, ) -> CallBuilder<&P, PhantomData<queryIsPaymentAssetAllowedCall>, N>
Creates a new call builder for the [queryIsPaymentAssetAllowed] function.
Sourcepub fn querySlashingOrigin(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<querySlashingOriginCall>, N>
pub fn querySlashingOrigin( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<querySlashingOriginCall>, N>
Creates a new call builder for the [querySlashingOrigin] function.
Sourcepub fn requiresAggregation(
&self,
serviceId: u64,
jobIndex: u8,
) -> CallBuilder<&P, PhantomData<requiresAggregationCall>, N>
pub fn requiresAggregation( &self, serviceId: u64, jobIndex: u8, ) -> CallBuilder<&P, PhantomData<requiresAggregationCall>, N>
Creates a new call builder for the [requiresAggregation] function.
Sourceimpl<P, N> IBlueprintServiceManagerInstance<P, N>
Event filters.
impl<P, N> IBlueprintServiceManagerInstance<P, N>
Event filters.
Sourcepub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
pub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.