pub struct ITangleInstance<P, N = Ethereum> { /* private fields */ }Expand description
A ITangle instance.
Contains type-safe methods for interacting with an on-chain instance of the
ITangle contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P, N> ITangleInstance<P, N>
Instantiation and getters/setters.
impl<P, N> ITangleInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> ITangleInstance<P, N>
pub const fn new(address: Address, __provider: P) -> ITangleInstance<P, N>
Creates a new wrapper around an on-chain ITangle contract instance.
See the wrapper’s documentation for more details.
Sourcepub async fn deploy(__provider: P) -> Result<ITangleInstance<P, N>, Error>
pub async fn deploy(__provider: P) -> Result<ITangleInstance<P, N>, Error>
Deploys this contract using the given provider and constructor arguments, if any.
Returns a new instance of the contract, if the deployment was successful.
For more fine-grained control over the deployment process, use deploy_builder instead.
Sourcepub fn deploy_builder(__provider: P) -> CallBuilder<P, (), N>
pub fn deploy_builder(__provider: P) -> CallBuilder<P, (), N>
Creates a RawCallBuilder for deploying this contract using the given provider
and constructor arguments, if any.
This is a simple wrapper around creating a RawCallBuilder with the data set to
the bytecode concatenated with the constructor’s ABI-encoded arguments.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourcepub fn at(self, address: Address) -> ITangleInstance<P, N>
pub fn at(self, address: Address) -> ITangleInstance<P, N>
Sets the address and returns self.
Sourceimpl<P, N> ITangleInstance<&P, N>where
P: Clone,
impl<P, N> ITangleInstance<&P, N>where
P: Clone,
Sourcepub fn with_cloned_provider(self) -> ITangleInstance<P, N>
pub fn with_cloned_provider(self) -> ITangleInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P, N> ITangleInstance<P, N>
Function calls.
impl<P, N> ITangleInstance<P, N>
Function calls.
Sourcepub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn addPermittedCaller(
&self,
serviceId: u64,
caller: Address,
) -> CallBuilder<&P, PhantomData<addPermittedCallerCall>, N>
pub fn addPermittedCaller( &self, serviceId: u64, caller: Address, ) -> CallBuilder<&P, PhantomData<addPermittedCallerCall>, N>
Creates a new call builder for the [addPermittedCaller] function.
Sourcepub fn approveService(
&self,
requestId: u64,
stakingPercent: u8,
) -> CallBuilder<&P, PhantomData<approveServiceCall>, N>
pub fn approveService( &self, requestId: u64, stakingPercent: u8, ) -> CallBuilder<&P, PhantomData<approveServiceCall>, N>
Creates a new call builder for the [approveService] function.
Sourcepub fn approveServiceWithBls(
&self,
requestId: u64,
stakingPercent: u8,
blsPubkey: [Uint<256, 4>; 4],
) -> CallBuilder<&P, PhantomData<approveServiceWithBlsCall>, N>
pub fn approveServiceWithBls( &self, requestId: u64, stakingPercent: u8, blsPubkey: [Uint<256, 4>; 4], ) -> CallBuilder<&P, PhantomData<approveServiceWithBlsCall>, N>
Creates a new call builder for the [approveServiceWithBls] function.
Sourcepub fn approveServiceWithCommitments(
&self,
requestId: u64,
commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>,
) -> CallBuilder<&P, PhantomData<approveServiceWithCommitmentsCall>, N>
pub fn approveServiceWithCommitments( &self, requestId: u64, commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>, ) -> CallBuilder<&P, PhantomData<approveServiceWithCommitmentsCall>, N>
Creates a new call builder for the [approveServiceWithCommitments] function.
Sourcepub fn approveServiceWithCommitmentsAndBls(
&self,
requestId: u64,
commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>,
blsPubkey: [Uint<256, 4>; 4],
) -> CallBuilder<&P, PhantomData<approveServiceWithCommitmentsAndBlsCall>, N>
pub fn approveServiceWithCommitmentsAndBls( &self, requestId: u64, commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>, blsPubkey: [Uint<256, 4>; 4], ) -> CallBuilder<&P, PhantomData<approveServiceWithCommitmentsAndBlsCall>, N>
Creates a new call builder for the [approveServiceWithCommitmentsAndBls] function.
Sourcepub fn billSubscription(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<billSubscriptionCall>, N>
pub fn billSubscription( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<billSubscriptionCall>, N>
Creates a new call builder for the [billSubscription] function.
Sourcepub fn billSubscriptionBatch(
&self,
serviceIds: Vec<u64>,
) -> CallBuilder<&P, PhantomData<billSubscriptionBatchCall>, N>
pub fn billSubscriptionBatch( &self, serviceIds: Vec<u64>, ) -> CallBuilder<&P, PhantomData<billSubscriptionBatchCall>, N>
Creates a new call builder for the [billSubscriptionBatch] function.
Sourcepub fn blueprintCount(
&self,
) -> CallBuilder<&P, PhantomData<blueprintCountCall>, N>
pub fn blueprintCount( &self, ) -> CallBuilder<&P, PhantomData<blueprintCountCall>, N>
Creates a new call builder for the [blueprintCount] function.
Sourcepub fn blueprintMasterRevision(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<blueprintMasterRevisionCall>, N>
pub fn blueprintMasterRevision( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<blueprintMasterRevisionCall>, N>
Creates a new call builder for the [blueprintMasterRevision] function.
Sourcepub fn blueprintMetadata(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<blueprintMetadataCall>, N>
pub fn blueprintMetadata( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<blueprintMetadataCall>, N>
Creates a new call builder for the [blueprintMetadata] function.
Sourcepub fn blueprintOperatorCount(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<blueprintOperatorCountCall>, N>
pub fn blueprintOperatorCount( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<blueprintOperatorCountCall>, N>
Creates a new call builder for the [blueprintOperatorCount] function.
Sourcepub fn blueprintSources(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<blueprintSourcesCall>, N>
pub fn blueprintSources( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<blueprintSourcesCall>, N>
Creates a new call builder for the [blueprintSources] function.
Sourcepub fn blueprintSupportedMemberships(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<blueprintSupportedMembershipsCall>, N>
pub fn blueprintSupportedMemberships( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<blueprintSupportedMembershipsCall>, N>
Creates a new call builder for the [blueprintSupportedMemberships] function.
Sourcepub fn canScheduleExit(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<canScheduleExitCall>, N>
pub fn canScheduleExit( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<canScheduleExitCall>, N>
Creates a new call builder for the [canScheduleExit] function.
Sourcepub fn cancelExit(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<cancelExitCall>, N>
pub fn cancelExit( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<cancelExitCall>, N>
Creates a new call builder for the [cancelExit] function.
Sourcepub fn claimRewards_0(
&self,
) -> CallBuilder<&P, PhantomData<claimRewards_0Call>, N>
pub fn claimRewards_0( &self, ) -> CallBuilder<&P, PhantomData<claimRewards_0Call>, N>
Creates a new call builder for the [claimRewards_0] function.
Sourcepub fn claimRewards_1(
&self,
token: Address,
) -> CallBuilder<&P, PhantomData<claimRewards_1Call>, N>
pub fn claimRewards_1( &self, token: Address, ) -> CallBuilder<&P, PhantomData<claimRewards_1Call>, N>
Creates a new call builder for the [claimRewards_1] function.
Sourcepub fn claimRewardsAll(
&self,
) -> CallBuilder<&P, PhantomData<claimRewardsAllCall>, N>
pub fn claimRewardsAll( &self, ) -> CallBuilder<&P, PhantomData<claimRewardsAllCall>, N>
Creates a new call builder for the [claimRewardsAll] function.
Sourcepub fn claimRewardsBatch(
&self,
tokens: Vec<Address>,
) -> CallBuilder<&P, PhantomData<claimRewardsBatchCall>, N>
pub fn claimRewardsBatch( &self, tokens: Vec<Address>, ) -> CallBuilder<&P, PhantomData<claimRewardsBatchCall>, N>
Creates a new call builder for the [claimRewardsBatch] function.
Sourcepub fn createBlueprint(
&self,
definition: <BlueprintDefinition as SolType>::RustType,
) -> CallBuilder<&P, PhantomData<createBlueprintCall>, N>
pub fn createBlueprint( &self, definition: <BlueprintDefinition as SolType>::RustType, ) -> CallBuilder<&P, PhantomData<createBlueprintCall>, N>
Creates a new call builder for the [createBlueprint] function.
Sourcepub fn createServiceFromQuotes(
&self,
blueprintId: u64,
quotes: Vec<<SignedQuote as SolType>::RustType>,
config: Bytes,
permittedCallers: Vec<Address>,
ttl: u64,
) -> CallBuilder<&P, PhantomData<createServiceFromQuotesCall>, N>
pub fn createServiceFromQuotes( &self, blueprintId: u64, quotes: Vec<<SignedQuote as SolType>::RustType>, config: Bytes, permittedCallers: Vec<Address>, ttl: u64, ) -> CallBuilder<&P, PhantomData<createServiceFromQuotesCall>, N>
Creates a new call builder for the [createServiceFromQuotes] function.
Sourcepub fn deactivateBlueprint(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<deactivateBlueprintCall>, N>
pub fn deactivateBlueprint( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<deactivateBlueprintCall>, N>
Creates a new call builder for the [deactivateBlueprint] function.
Sourcepub fn executeExit(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<executeExitCall>, N>
pub fn executeExit( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<executeExitCall>, N>
Creates a new call builder for the [executeExit] function.
Sourcepub fn extendServiceFromQuotes(
&self,
serviceId: u64,
quotes: Vec<<SignedQuote as SolType>::RustType>,
extensionDuration: u64,
) -> CallBuilder<&P, PhantomData<extendServiceFromQuotesCall>, N>
pub fn extendServiceFromQuotes( &self, serviceId: u64, quotes: Vec<<SignedQuote as SolType>::RustType>, extensionDuration: u64, ) -> CallBuilder<&P, PhantomData<extendServiceFromQuotesCall>, N>
Creates a new call builder for the [extendServiceFromQuotes] function.
Sourcepub fn forceExit(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<forceExitCall>, N>
pub fn forceExit( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<forceExitCall>, N>
Creates a new call builder for the [forceExit] function.
Sourcepub fn forceRemoveOperator(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<forceRemoveOperatorCall>, N>
pub fn forceRemoveOperator( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<forceRemoveOperatorCall>, N>
Creates a new call builder for the [forceRemoveOperator] function.
Sourcepub fn fundService(
&self,
serviceId: u64,
amount: Uint<256, 4>,
) -> CallBuilder<&P, PhantomData<fundServiceCall>, N>
pub fn fundService( &self, serviceId: u64, amount: Uint<256, 4>, ) -> CallBuilder<&P, PhantomData<fundServiceCall>, N>
Creates a new call builder for the [fundService] function.
Sourcepub fn getBillableServices(
&self,
serviceIds: Vec<u64>,
) -> CallBuilder<&P, PhantomData<getBillableServicesCall>, N>
pub fn getBillableServices( &self, serviceIds: Vec<u64>, ) -> CallBuilder<&P, PhantomData<getBillableServicesCall>, N>
Creates a new call builder for the [getBillableServices] function.
Sourcepub fn getBlueprint(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<getBlueprintCall>, N>
pub fn getBlueprint( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<getBlueprintCall>, N>
Creates a new call builder for the [getBlueprint] function.
Sourcepub fn getBlueprintConfig(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<getBlueprintConfigCall>, N>
pub fn getBlueprintConfig( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<getBlueprintConfigCall>, N>
Creates a new call builder for the [getBlueprintConfig] function.
Sourcepub fn getBlueprintDefinition(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<getBlueprintDefinitionCall>, N>
pub fn getBlueprintDefinition( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<getBlueprintDefinitionCall>, N>
Creates a new call builder for the [getBlueprintDefinition] function.
Sourcepub fn getBlueprintResourceRequirements(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<getBlueprintResourceRequirementsCall>, N>
pub fn getBlueprintResourceRequirements( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<getBlueprintResourceRequirementsCall>, N>
Creates a new call builder for the [getBlueprintResourceRequirements] function.
Sourcepub fn getExitConfig(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getExitConfigCall>, N>
pub fn getExitConfig( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getExitConfigCall>, N>
Creates a new call builder for the [getExitConfig] function.
Sourcepub fn getExitRequest(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getExitRequestCall>, N>
pub fn getExitRequest( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getExitRequestCall>, N>
Creates a new call builder for the [getExitRequest] function.
Sourcepub fn getExitStatus(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getExitStatusCall>, N>
pub fn getExitStatus( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getExitStatusCall>, N>
Creates a new call builder for the [getExitStatus] function.
Sourcepub fn getJobCall(
&self,
serviceId: u64,
callId: u64,
) -> CallBuilder<&P, PhantomData<getJobCallCall>, N>
pub fn getJobCall( &self, serviceId: u64, callId: u64, ) -> CallBuilder<&P, PhantomData<getJobCallCall>, N>
Creates a new call builder for the [getJobCall] function.
Sourcepub fn getJobEventRate(
&self,
blueprintId: u64,
jobIndex: u8,
) -> CallBuilder<&P, PhantomData<getJobEventRateCall>, N>
pub fn getJobEventRate( &self, blueprintId: u64, jobIndex: u8, ) -> CallBuilder<&P, PhantomData<getJobEventRateCall>, N>
Creates a new call builder for the [getJobEventRate] function.
Sourcepub fn getJobQuotedOperators(
&self,
serviceId: u64,
callId: u64,
) -> CallBuilder<&P, PhantomData<getJobQuotedOperatorsCall>, N>
pub fn getJobQuotedOperators( &self, serviceId: u64, callId: u64, ) -> CallBuilder<&P, PhantomData<getJobQuotedOperatorsCall>, N>
Creates a new call builder for the [getJobQuotedOperators] function.
Sourcepub fn getJobQuotedPrice(
&self,
serviceId: u64,
callId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getJobQuotedPriceCall>, N>
pub fn getJobQuotedPrice( &self, serviceId: u64, callId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getJobQuotedPriceCall>, N>
Creates a new call builder for the [getJobQuotedPrice] function.
Sourcepub fn getOperatorBlsPubkey(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getOperatorBlsPubkeyCall>, N>
pub fn getOperatorBlsPubkey( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getOperatorBlsPubkeyCall>, N>
Creates a new call builder for the [getOperatorBlsPubkey] function.
Sourcepub fn getOperatorPreferences(
&self,
blueprintId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getOperatorPreferencesCall>, N>
pub fn getOperatorPreferences( &self, blueprintId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getOperatorPreferencesCall>, N>
Creates a new call builder for the [getOperatorPreferences] function.
Sourcepub fn getOperatorPublicKey(
&self,
blueprintId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getOperatorPublicKeyCall>, N>
pub fn getOperatorPublicKey( &self, blueprintId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getOperatorPublicKeyCall>, N>
Creates a new call builder for the [getOperatorPublicKey] function.
Sourcepub fn getOperatorRegistration(
&self,
blueprintId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getOperatorRegistrationCall>, N>
pub fn getOperatorRegistration( &self, blueprintId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getOperatorRegistrationCall>, N>
Creates a new call builder for the [getOperatorRegistration] function.
Sourcepub fn getOperatorTotalActiveServices(
&self,
operator: Address,
) -> CallBuilder<&P, PhantomData<getOperatorTotalActiveServicesCall>, N>
pub fn getOperatorTotalActiveServices( &self, operator: Address, ) -> CallBuilder<&P, PhantomData<getOperatorTotalActiveServicesCall>, N>
Creates a new call builder for the [getOperatorTotalActiveServices] function.
Sourcepub fn getService(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getServiceCall>, N>
pub fn getService( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getServiceCall>, N>
Creates a new call builder for the [getService] function.
Sourcepub fn getServiceEscrow(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getServiceEscrowCall>, N>
pub fn getServiceEscrow( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getServiceEscrowCall>, N>
Creates a new call builder for the [getServiceEscrow] function.
Sourcepub fn getServiceOperator(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getServiceOperatorCall>, N>
pub fn getServiceOperator( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getServiceOperatorCall>, N>
Creates a new call builder for the [getServiceOperator] function.
Sourcepub fn getServiceOperators(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getServiceOperatorsCall>, N>
pub fn getServiceOperators( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getServiceOperatorsCall>, N>
Creates a new call builder for the [getServiceOperators] function.
Sourcepub fn getServiceRequest(
&self,
requestId: u64,
) -> CallBuilder<&P, PhantomData<getServiceRequestCall>, N>
pub fn getServiceRequest( &self, requestId: u64, ) -> CallBuilder<&P, PhantomData<getServiceRequestCall>, N>
Creates a new call builder for the [getServiceRequest] function.
Sourcepub fn getServiceRequestResourceRequirements(
&self,
requestId: u64,
) -> CallBuilder<&P, PhantomData<getServiceRequestResourceRequirementsCall>, N>
pub fn getServiceRequestResourceRequirements( &self, requestId: u64, ) -> CallBuilder<&P, PhantomData<getServiceRequestResourceRequirementsCall>, N>
Creates a new call builder for the [getServiceRequestResourceRequirements] function.
Sourcepub fn getServiceRequestSecurityCommitments(
&self,
requestId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getServiceRequestSecurityCommitmentsCall>, N>
pub fn getServiceRequestSecurityCommitments( &self, requestId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getServiceRequestSecurityCommitmentsCall>, N>
Creates a new call builder for the [getServiceRequestSecurityCommitments] function.
Sourcepub fn getServiceRequestSecurityRequirements(
&self,
requestId: u64,
) -> CallBuilder<&P, PhantomData<getServiceRequestSecurityRequirementsCall>, N>
pub fn getServiceRequestSecurityRequirements( &self, requestId: u64, ) -> CallBuilder<&P, PhantomData<getServiceRequestSecurityRequirementsCall>, N>
Creates a new call builder for the [getServiceRequestSecurityRequirements] function.
Sourcepub fn getServiceResourceCommitmentHash(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getServiceResourceCommitmentHashCall>, N>
pub fn getServiceResourceCommitmentHash( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getServiceResourceCommitmentHashCall>, N>
Creates a new call builder for the [getServiceResourceCommitmentHash] function.
Sourcepub fn getServiceSecurityCommitments(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<getServiceSecurityCommitmentsCall>, N>
pub fn getServiceSecurityCommitments( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<getServiceSecurityCommitmentsCall>, N>
Creates a new call builder for the [getServiceSecurityCommitments] function.
Sourcepub fn getServiceSecurityRequirements(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<getServiceSecurityRequirementsCall>, N>
pub fn getServiceSecurityRequirements( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<getServiceSecurityRequirementsCall>, N>
Creates a new call builder for the [getServiceSecurityRequirements] function.
Sourcepub fn isOperatorRegistered(
&self,
blueprintId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<isOperatorRegisteredCall>, N>
pub fn isOperatorRegistered( &self, blueprintId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<isOperatorRegisteredCall>, N>
Creates a new call builder for the [isOperatorRegistered] function.
Sourcepub fn isPermittedCaller(
&self,
serviceId: u64,
caller: Address,
) -> CallBuilder<&P, PhantomData<isPermittedCallerCall>, N>
pub fn isPermittedCaller( &self, serviceId: u64, caller: Address, ) -> CallBuilder<&P, PhantomData<isPermittedCallerCall>, N>
Creates a new call builder for the [isPermittedCaller] function.
Sourcepub fn isServiceActive(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<isServiceActiveCall>, N>
pub fn isServiceActive( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<isServiceActiveCall>, N>
Creates a new call builder for the [isServiceActive] function.
Sourcepub fn isServiceOperator(
&self,
serviceId: u64,
operator: Address,
) -> CallBuilder<&P, PhantomData<isServiceOperatorCall>, N>
pub fn isServiceOperator( &self, serviceId: u64, operator: Address, ) -> CallBuilder<&P, PhantomData<isServiceOperatorCall>, N>
Creates a new call builder for the [isServiceOperator] function.
Sourcepub fn joinService(
&self,
serviceId: u64,
exposureBps: u16,
) -> CallBuilder<&P, PhantomData<joinServiceCall>, N>
pub fn joinService( &self, serviceId: u64, exposureBps: u16, ) -> CallBuilder<&P, PhantomData<joinServiceCall>, N>
Creates a new call builder for the [joinService] function.
Sourcepub fn joinServiceWithCommitments(
&self,
serviceId: u64,
exposureBps: u16,
commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>,
) -> CallBuilder<&P, PhantomData<joinServiceWithCommitmentsCall>, N>
pub fn joinServiceWithCommitments( &self, serviceId: u64, exposureBps: u16, commitments: Vec<<AssetSecurityCommitment as SolType>::RustType>, ) -> CallBuilder<&P, PhantomData<joinServiceWithCommitmentsCall>, N>
Creates a new call builder for the [joinServiceWithCommitments] function.
Sourcepub fn leaveService(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<leaveServiceCall>, N>
pub fn leaveService( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<leaveServiceCall>, N>
Creates a new call builder for the [leaveService] function.
Sourcepub fn pendingRewards_0(
&self,
account: Address,
) -> CallBuilder<&P, PhantomData<pendingRewards_0Call>, N>
pub fn pendingRewards_0( &self, account: Address, ) -> CallBuilder<&P, PhantomData<pendingRewards_0Call>, N>
Creates a new call builder for the [pendingRewards_0] function.
Sourcepub fn pendingRewards_1(
&self,
account: Address,
token: Address,
) -> CallBuilder<&P, PhantomData<pendingRewards_1Call>, N>
pub fn pendingRewards_1( &self, account: Address, token: Address, ) -> CallBuilder<&P, PhantomData<pendingRewards_1Call>, N>
Creates a new call builder for the [pendingRewards_1] function.
Sourcepub fn preRegister(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<preRegisterCall>, N>
pub fn preRegister( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<preRegisterCall>, N>
Creates a new call builder for the [preRegister] function.
Sourcepub fn registerOperator_0(
&self,
blueprintId: u64,
ecdsaPublicKey: Bytes,
rpcAddress: String,
registrationInputs: Bytes,
) -> CallBuilder<&P, PhantomData<registerOperator_0Call>, N>
pub fn registerOperator_0( &self, blueprintId: u64, ecdsaPublicKey: Bytes, rpcAddress: String, registrationInputs: Bytes, ) -> CallBuilder<&P, PhantomData<registerOperator_0Call>, N>
Creates a new call builder for the [registerOperator_0] function.
Sourcepub fn registerOperator_1(
&self,
blueprintId: u64,
ecdsaPublicKey: Bytes,
rpcAddress: String,
) -> CallBuilder<&P, PhantomData<registerOperator_1Call>, N>
pub fn registerOperator_1( &self, blueprintId: u64, ecdsaPublicKey: Bytes, rpcAddress: String, ) -> CallBuilder<&P, PhantomData<registerOperator_1Call>, N>
Creates a new call builder for the [registerOperator_1] function.
Sourcepub fn rejectService(
&self,
requestId: u64,
) -> CallBuilder<&P, PhantomData<rejectServiceCall>, N>
pub fn rejectService( &self, requestId: u64, ) -> CallBuilder<&P, PhantomData<rejectServiceCall>, N>
Creates a new call builder for the [rejectService] function.
Sourcepub fn removePermittedCaller(
&self,
serviceId: u64,
caller: Address,
) -> CallBuilder<&P, PhantomData<removePermittedCallerCall>, N>
pub fn removePermittedCaller( &self, serviceId: u64, caller: Address, ) -> CallBuilder<&P, PhantomData<removePermittedCallerCall>, N>
Creates a new call builder for the [removePermittedCaller] function.
Sourcepub fn requestService(
&self,
blueprintId: u64,
operators: Vec<Address>,
config: Bytes,
permittedCallers: Vec<Address>,
ttl: u64,
paymentToken: Address,
paymentAmount: Uint<256, 4>,
confidentiality: <ConfidentialityPolicy as SolType>::RustType,
) -> CallBuilder<&P, PhantomData<requestServiceCall>, N>
pub fn requestService( &self, blueprintId: u64, operators: Vec<Address>, config: Bytes, permittedCallers: Vec<Address>, ttl: u64, paymentToken: Address, paymentAmount: Uint<256, 4>, confidentiality: <ConfidentialityPolicy as SolType>::RustType, ) -> CallBuilder<&P, PhantomData<requestServiceCall>, N>
Creates a new call builder for the [requestService] function.
Sourcepub fn requestServiceWithExposure(
&self,
blueprintId: u64,
operators: Vec<Address>,
exposureBps: Vec<u16>,
config: Bytes,
permittedCallers: Vec<Address>,
ttl: u64,
paymentToken: Address,
paymentAmount: Uint<256, 4>,
confidentiality: <ConfidentialityPolicy as SolType>::RustType,
) -> CallBuilder<&P, PhantomData<requestServiceWithExposureCall>, N>
pub fn requestServiceWithExposure( &self, blueprintId: u64, operators: Vec<Address>, exposureBps: Vec<u16>, config: Bytes, permittedCallers: Vec<Address>, ttl: u64, paymentToken: Address, paymentAmount: Uint<256, 4>, confidentiality: <ConfidentialityPolicy as SolType>::RustType, ) -> CallBuilder<&P, PhantomData<requestServiceWithExposureCall>, N>
Creates a new call builder for the [requestServiceWithExposure] function.
Sourcepub fn requestServiceWithSecurity(
&self,
blueprintId: u64,
operators: Vec<Address>,
securityRequirements: Vec<<AssetSecurityRequirement as SolType>::RustType>,
config: Bytes,
permittedCallers: Vec<Address>,
ttl: u64,
paymentToken: Address,
paymentAmount: Uint<256, 4>,
confidentiality: <ConfidentialityPolicy as SolType>::RustType,
) -> CallBuilder<&P, PhantomData<requestServiceWithSecurityCall>, N>
pub fn requestServiceWithSecurity( &self, blueprintId: u64, operators: Vec<Address>, securityRequirements: Vec<<AssetSecurityRequirement as SolType>::RustType>, config: Bytes, permittedCallers: Vec<Address>, ttl: u64, paymentToken: Address, paymentAmount: Uint<256, 4>, confidentiality: <ConfidentialityPolicy as SolType>::RustType, ) -> CallBuilder<&P, PhantomData<requestServiceWithSecurityCall>, N>
Creates a new call builder for the [requestServiceWithSecurity] function.
Sourcepub fn rewardTokens(
&self,
account: Address,
) -> CallBuilder<&P, PhantomData<rewardTokensCall>, N>
pub fn rewardTokens( &self, account: Address, ) -> CallBuilder<&P, PhantomData<rewardTokensCall>, N>
Creates a new call builder for the [rewardTokens] function.
Sourcepub fn scheduleExit(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<scheduleExitCall>, N>
pub fn scheduleExit( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<scheduleExitCall>, N>
Creates a new call builder for the [scheduleExit] function.
Sourcepub fn serviceCount(&self) -> CallBuilder<&P, PhantomData<serviceCountCall>, N>
pub fn serviceCount(&self) -> CallBuilder<&P, PhantomData<serviceCountCall>, N>
Creates a new call builder for the [serviceCount] function.
Sourcepub fn setBlueprintResourceRequirements(
&self,
blueprintId: u64,
requirements: Vec<<ResourceCommitment as SolType>::RustType>,
) -> CallBuilder<&P, PhantomData<setBlueprintResourceRequirementsCall>, N>
pub fn setBlueprintResourceRequirements( &self, blueprintId: u64, requirements: Vec<<ResourceCommitment as SolType>::RustType>, ) -> CallBuilder<&P, PhantomData<setBlueprintResourceRequirementsCall>, N>
Creates a new call builder for the [setBlueprintResourceRequirements] function.
Sourcepub fn setJobEventRates(
&self,
blueprintId: u64,
jobIndexes: Vec<u8>,
rates: Vec<Uint<256, 4>>,
) -> CallBuilder<&P, PhantomData<setJobEventRatesCall>, N>
pub fn setJobEventRates( &self, blueprintId: u64, jobIndexes: Vec<u8>, rates: Vec<Uint<256, 4>>, ) -> CallBuilder<&P, PhantomData<setJobEventRatesCall>, N>
Creates a new call builder for the [setJobEventRates] function.
Sourcepub fn submitAggregatedResult(
&self,
serviceId: u64,
callId: u64,
output: Bytes,
signerBitmap: Uint<256, 4>,
aggregatedSignature: [Uint<256, 4>; 2],
aggregatedPubkey: [Uint<256, 4>; 4],
) -> CallBuilder<&P, PhantomData<submitAggregatedResultCall>, N>
pub fn submitAggregatedResult( &self, serviceId: u64, callId: u64, output: Bytes, signerBitmap: Uint<256, 4>, aggregatedSignature: [Uint<256, 4>; 2], aggregatedPubkey: [Uint<256, 4>; 4], ) -> CallBuilder<&P, PhantomData<submitAggregatedResultCall>, N>
Creates a new call builder for the [submitAggregatedResult] function.
Sourcepub fn submitJob(
&self,
serviceId: u64,
jobIndex: u8,
inputs: Bytes,
) -> CallBuilder<&P, PhantomData<submitJobCall>, N>
pub fn submitJob( &self, serviceId: u64, jobIndex: u8, inputs: Bytes, ) -> CallBuilder<&P, PhantomData<submitJobCall>, N>
Creates a new call builder for the [submitJob] function.
Sourcepub fn submitJobFromQuote(
&self,
serviceId: u64,
jobIndex: u8,
inputs: Bytes,
quotes: Vec<<SignedJobQuote as SolType>::RustType>,
) -> CallBuilder<&P, PhantomData<submitJobFromQuoteCall>, N>
pub fn submitJobFromQuote( &self, serviceId: u64, jobIndex: u8, inputs: Bytes, quotes: Vec<<SignedJobQuote as SolType>::RustType>, ) -> CallBuilder<&P, PhantomData<submitJobFromQuoteCall>, N>
Creates a new call builder for the [submitJobFromQuote] function.
Sourcepub fn submitResult(
&self,
serviceId: u64,
callId: u64,
result: Bytes,
) -> CallBuilder<&P, PhantomData<submitResultCall>, N>
pub fn submitResult( &self, serviceId: u64, callId: u64, result: Bytes, ) -> CallBuilder<&P, PhantomData<submitResultCall>, N>
Creates a new call builder for the [submitResult] function.
Sourcepub fn submitResults(
&self,
serviceId: u64,
callIds: Vec<u64>,
results: Vec<Bytes>,
) -> CallBuilder<&P, PhantomData<submitResultsCall>, N>
pub fn submitResults( &self, serviceId: u64, callIds: Vec<u64>, results: Vec<Bytes>, ) -> CallBuilder<&P, PhantomData<submitResultsCall>, N>
Creates a new call builder for the [submitResults] function.
Sourcepub fn terminateService(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<terminateServiceCall>, N>
pub fn terminateService( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<terminateServiceCall>, N>
Creates a new call builder for the [terminateService] function.
Sourcepub fn terminateServiceForNonPayment(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<terminateServiceForNonPaymentCall>, N>
pub fn terminateServiceForNonPayment( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<terminateServiceForNonPaymentCall>, N>
Creates a new call builder for the [terminateServiceForNonPayment] function.
Sourcepub fn transferBlueprint(
&self,
blueprintId: u64,
newOwner: Address,
) -> CallBuilder<&P, PhantomData<transferBlueprintCall>, N>
pub fn transferBlueprint( &self, blueprintId: u64, newOwner: Address, ) -> CallBuilder<&P, PhantomData<transferBlueprintCall>, N>
Creates a new call builder for the [transferBlueprint] function.
Sourcepub fn unregisterOperator(
&self,
blueprintId: u64,
) -> CallBuilder<&P, PhantomData<unregisterOperatorCall>, N>
pub fn unregisterOperator( &self, blueprintId: u64, ) -> CallBuilder<&P, PhantomData<unregisterOperatorCall>, N>
Creates a new call builder for the [unregisterOperator] function.
Sourcepub fn updateBlueprint(
&self,
blueprintId: u64,
metadataUri: String,
) -> CallBuilder<&P, PhantomData<updateBlueprintCall>, N>
pub fn updateBlueprint( &self, blueprintId: u64, metadataUri: String, ) -> CallBuilder<&P, PhantomData<updateBlueprintCall>, N>
Creates a new call builder for the [updateBlueprint] function.
Sourcepub fn updateOperatorPreferences(
&self,
blueprintId: u64,
ecdsaPublicKey: Bytes,
rpcAddress: String,
) -> CallBuilder<&P, PhantomData<updateOperatorPreferencesCall>, N>
pub fn updateOperatorPreferences( &self, blueprintId: u64, ecdsaPublicKey: Bytes, rpcAddress: String, ) -> CallBuilder<&P, PhantomData<updateOperatorPreferencesCall>, N>
Creates a new call builder for the [updateOperatorPreferences] function.
Sourcepub fn withdrawRemainingEscrow(
&self,
serviceId: u64,
) -> CallBuilder<&P, PhantomData<withdrawRemainingEscrowCall>, N>
pub fn withdrawRemainingEscrow( &self, serviceId: u64, ) -> CallBuilder<&P, PhantomData<withdrawRemainingEscrowCall>, N>
Creates a new call builder for the [withdrawRemainingEscrow] function.
Sourceimpl<P, N> ITangleInstance<P, N>
Event filters.
impl<P, N> ITangleInstance<P, N>
Event filters.
Sourcepub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
pub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn BlueprintCreated_filter(&self) -> Event<&P, BlueprintCreated, N>
pub fn BlueprintCreated_filter(&self) -> Event<&P, BlueprintCreated, N>
Creates a new event filter for the BlueprintCreated event.
Sourcepub fn BlueprintDeactivated_filter(&self) -> Event<&P, BlueprintDeactivated, N>
pub fn BlueprintDeactivated_filter(&self) -> Event<&P, BlueprintDeactivated, N>
Creates a new event filter for the BlueprintDeactivated event.
Sourcepub fn BlueprintResourceRequirementsSet_filter(
&self,
) -> Event<&P, BlueprintResourceRequirementsSet, N>
pub fn BlueprintResourceRequirementsSet_filter( &self, ) -> Event<&P, BlueprintResourceRequirementsSet, N>
Creates a new event filter for the BlueprintResourceRequirementsSet event.
Sourcepub fn BlueprintTransferred_filter(&self) -> Event<&P, BlueprintTransferred, N>
pub fn BlueprintTransferred_filter(&self) -> Event<&P, BlueprintTransferred, N>
Creates a new event filter for the BlueprintTransferred event.
Sourcepub fn BlueprintUpdated_filter(&self) -> Event<&P, BlueprintUpdated, N>
pub fn BlueprintUpdated_filter(&self) -> Event<&P, BlueprintUpdated, N>
Creates a new event filter for the BlueprintUpdated event.
Sourcepub fn JobCompleted_filter(&self) -> Event<&P, JobCompleted, N>
pub fn JobCompleted_filter(&self) -> Event<&P, JobCompleted, N>
Creates a new event filter for the JobCompleted event.
Sourcepub fn JobResultSubmitted_filter(&self) -> Event<&P, JobResultSubmitted, N>
pub fn JobResultSubmitted_filter(&self) -> Event<&P, JobResultSubmitted, N>
Creates a new event filter for the JobResultSubmitted event.
Sourcepub fn JobSubmitted_filter(&self) -> Event<&P, JobSubmitted, N>
pub fn JobSubmitted_filter(&self) -> Event<&P, JobSubmitted, N>
Creates a new event filter for the JobSubmitted event.
Sourcepub fn JobSubmittedFromQuote_filter(
&self,
) -> Event<&P, JobSubmittedFromQuote, N>
pub fn JobSubmittedFromQuote_filter( &self, ) -> Event<&P, JobSubmittedFromQuote, N>
Creates a new event filter for the JobSubmittedFromQuote event.
Sourcepub fn OperatorJoinedService_filter(
&self,
) -> Event<&P, OperatorJoinedService, N>
pub fn OperatorJoinedService_filter( &self, ) -> Event<&P, OperatorJoinedService, N>
Creates a new event filter for the OperatorJoinedService event.
Sourcepub fn OperatorLeftService_filter(&self) -> Event<&P, OperatorLeftService, N>
pub fn OperatorLeftService_filter(&self) -> Event<&P, OperatorLeftService, N>
Creates a new event filter for the OperatorLeftService event.
Sourcepub fn OperatorPreferencesUpdated_filter(
&self,
) -> Event<&P, OperatorPreferencesUpdated, N>
pub fn OperatorPreferencesUpdated_filter( &self, ) -> Event<&P, OperatorPreferencesUpdated, N>
Creates a new event filter for the OperatorPreferencesUpdated event.
Sourcepub fn OperatorRegistered_filter(&self) -> Event<&P, OperatorRegistered, N>
pub fn OperatorRegistered_filter(&self) -> Event<&P, OperatorRegistered, N>
Creates a new event filter for the OperatorRegistered event.
Sourcepub fn OperatorRewardAccrued_filter(
&self,
) -> Event<&P, OperatorRewardAccrued, N>
pub fn OperatorRewardAccrued_filter( &self, ) -> Event<&P, OperatorRewardAccrued, N>
Creates a new event filter for the OperatorRewardAccrued event.
Sourcepub fn OperatorUnregistered_filter(&self) -> Event<&P, OperatorUnregistered, N>
pub fn OperatorUnregistered_filter(&self) -> Event<&P, OperatorUnregistered, N>
Creates a new event filter for the OperatorUnregistered event.
Sourcepub fn PaymentDistributed_filter(&self) -> Event<&P, PaymentDistributed, N>
pub fn PaymentDistributed_filter(&self) -> Event<&P, PaymentDistributed, N>
Creates a new event filter for the PaymentDistributed event.
Sourcepub fn RewardsClaimed_filter(&self) -> Event<&P, RewardsClaimed, N>
pub fn RewardsClaimed_filter(&self) -> Event<&P, RewardsClaimed, N>
Creates a new event filter for the RewardsClaimed event.
Sourcepub fn ServiceActivated_filter(&self) -> Event<&P, ServiceActivated, N>
pub fn ServiceActivated_filter(&self) -> Event<&P, ServiceActivated, N>
Creates a new event filter for the ServiceActivated event.
Sourcepub fn ServiceApproved_filter(&self) -> Event<&P, ServiceApproved, N>
pub fn ServiceApproved_filter(&self) -> Event<&P, ServiceApproved, N>
Creates a new event filter for the ServiceApproved event.
Sourcepub fn ServiceRejected_filter(&self) -> Event<&P, ServiceRejected, N>
pub fn ServiceRejected_filter(&self) -> Event<&P, ServiceRejected, N>
Creates a new event filter for the ServiceRejected event.
Sourcepub fn ServiceRequested_filter(&self) -> Event<&P, ServiceRequested, N>
pub fn ServiceRequested_filter(&self) -> Event<&P, ServiceRequested, N>
Creates a new event filter for the ServiceRequested event.
Sourcepub fn ServiceRequestedWithSecurity_filter(
&self,
) -> Event<&P, ServiceRequestedWithSecurity, N>
pub fn ServiceRequestedWithSecurity_filter( &self, ) -> Event<&P, ServiceRequestedWithSecurity, N>
Creates a new event filter for the ServiceRequestedWithSecurity event.
Sourcepub fn ServiceTerminated_filter(&self) -> Event<&P, ServiceTerminated, N>
pub fn ServiceTerminated_filter(&self) -> Event<&P, ServiceTerminated, N>
Creates a new event filter for the ServiceTerminated event.
Sourcepub fn ServiceTerminatedForNonPayment_filter(
&self,
) -> Event<&P, ServiceTerminatedForNonPayment, N>
pub fn ServiceTerminatedForNonPayment_filter( &self, ) -> Event<&P, ServiceTerminatedForNonPayment, N>
Creates a new event filter for the ServiceTerminatedForNonPayment event.
Sourcepub fn SubscriptionBilled_filter(&self) -> Event<&P, SubscriptionBilled, N>
pub fn SubscriptionBilled_filter(&self) -> Event<&P, SubscriptionBilled, N>
Creates a new event filter for the SubscriptionBilled event.